@@ -203,48 +203,83 @@ def write_db(container, testdata):
     logger.warning('Exit write_db()')
 
 
+# def send_email(html_content):
+#     logger.warning('Enter send_email()')
+#     from sendgrid import SendGridAPIClient
+#     logger.warning('Sending email...')
+#
+#     data = {
+#         "personalizations": [
+#             {
+#                 "to": [],
+#                 "subject": "Test results of Azure CLI"
+#             }
+#         ],
+#         "from": {
+#             "email": "azclibot@microsoft.com"
+#         },
+#         "content": [
+#             {
+#                 "type": "text/html",
+#                 "value": html_content
+#             }
+#         ]
+#     }
+#
+#     if REQUESTED_FOR_EMAIL != '':
+#         data['personalizations'][0]['to'].append({'email': REQUESTED_FOR_EMAIL})
+#     if USER_TARGET == '' and USER_REPO == 'https://github.com/Azure/azure-cli.git' and USER_BRANCH == 'dev' and USER_LIVE == '--live' and REQUESTED_FOR_EMAIL == '':
+#         data['personalizations'][0]['to'].append({'email': 'AzPyCLI@microsoft.com'})
+#         data['personalizations'][0]['to'].append({'email': 'antcliTest@microsoft.com'})
+#     logger.warning(data)
+#
+#     sendgrid_key = sys.argv[1]
+#     sg = SendGridAPIClient(sendgrid_key)
+#     response = sg.send(data)
+#     logger.warning(response.status_code)
+#     logger.warning(response.body)
+#     logger.warning(response.headers)
+#     logger.warning('Exit send_email()')
+
+
 def send_email(html_content):
-    logger.warning('Enter send_email()')
-
-    from sendgrid import SendGridAPIClient
     logger.warning('Sending email...')
-    # message = Mail(
-    #     from_email='azclibot@microsoft.com',
-    #     to_emails='AzPyCLI@microsoft.com',
-    #     subject='Test results of Azure CLI',
-    #     html_content=get_content())
-    data = {
-        "personalizations": [
-            {
-                "to": [],
-                "subject": "Test results of Azure CLI"
-            }
-        ],
-        "from": {
-            "email": "azclibot@microsoft.com"
-        },
-        "content": [
-            {
-                "type": "text/html",
-                "value": html_content
-            }
-        ]
-    }
+    from azure.communication.email import EmailClient, EmailAddress, EmailContent, EmailMessage, EmailRecipients
+
+    client = EmailClient.from_connection_string(SENDGRID_KEY);
+    content = EmailContent(
+        subject="Test results of Azure CLI",
+        html=html_content,
+    )
+
+    recipients = ''
+
     if REQUESTED_FOR_EMAIL != '':
-        data['personalizations'][0]['to'].append({'email': REQUESTED_FOR_EMAIL})
-    if USER_TARGET == '' and USER_REPO == 'https://github.com/Azure/azure-cli.git' and USER_BRANCH == 'dev' and USER_LIVE == '--live' and REQUESTED_FOR_EMAIL == '':
-        data['personalizations'][0]['to'].append({'email': 'AzPyCLI@microsoft.com'})
-        data['personalizations'][0]['to'].append({'email': 'antcliTest@microsoft.com'})
-    logger.warning(data)
+        recipients = EmailRecipients(
+            to=[
+                EmailAddress(email=REQUESTED_FOR_EMAIL),
+            ]
+        )
+    # TODO: USER_TARGET == 'all'
+    elif USER_TARGET == '' and USER_REPO == 'https://github.com/Azure/azure-cli.git' and USER_BRANCH == 'dev' and USER_LIVE == '--live' and REQUESTED_FOR_EMAIL == '':
+        recipients = EmailRecipients(
+            to=[
+                EmailAddress(email="AzPyCLI@microsoft.com"),
+                EmailAddress(email="antcliTest@microsoft.com"),
+            ]
+        )
 
-    sendgrid_key = sys.argv[1]
-    sg = SendGridAPIClient(sendgrid_key)
-    response = sg.send(data)
-    logger.warning(response.status_code)
-    logger.warning(response.body)
-    logger.warning(response.headers)
+    if recipients:
+        message = EmailMessage(sender="DoNotReply@561634e2-1674-4377-9975-10a9197437d7.azurecomm.net",
+                               content=content,
+                               recipients=recipients)
 
-    logger.warning('Exit send_email()')
+        response = client.send(message)
+        status = client.get_send_status(response.message_id)
+        print(status)
+        logger.warning('Finish sending email')
+    else:
+        logger.warning('No recipients, skip sending email')
 
 
 def get_content(container, testdata):
