@@ -134,6 +134,7 @@ class CommandRecommender():  # pylint: disable=too-few-public-methods
         api_url = 'https://app.aladdin.microsoft.com/api/v1.0/suggestions'
         correlation_id = telemetry._session.correlation_id  # pylint: disable=protected-access
         subscription_id = telemetry._get_azure_subscription_id()  # pylint: disable=protected-access
+        event_id = telemetry._session.event_id  # pylint: disable=protected-access
         # Used for DDOS protection and rate limiting
         user_id = telemetry._get_user_azure_id()  # pylint: disable=protected-access
         hashed_user_id = hashlib.sha256(user_id.encode('utf-8')).hexdigest()
@@ -152,6 +153,8 @@ class CommandRecommender():  # pylint: disable=too-few-public-methods
                 context['correlationId'] = correlation_id
             if subscription_id:
                 context['subscriptionId'] = subscription_id
+            if event_id:
+                context['eventId'] = event_id
 
         parameters = self._normalize_parameters(self.parameters)
         parameters = [item for item in set(parameters) if item not in ['--debug', '--verbose', '--only-show-errors']]
@@ -335,6 +338,7 @@ class CommandRecommender():  # pylint: disable=too-few-public-methods
             1. CLI context is missing
             2. In air-gapped clouds
             3. In testing environments
+            4. In autocomplete mode
 
         :return: whether Aladdin service need to be disabled or not
         :type: bool
@@ -354,6 +358,9 @@ class CommandRecommender():  # pylint: disable=too-few-public-methods
         if self.cli_ctx.__class__.__name__ == 'DummyCli':
             return True
 
+        if self.cli_ctx.data['completer_active']:
+            return True
+
         return False
 
     def _normalize_parameters(self, args):
