@@ -7,7 +7,7 @@ import tempfile
 import unittest
 import shutil
 import hashlib
-import mock
+from unittest import mock
 import sys
 
 from azure.cli.core.util import CLIError
@@ -332,19 +332,19 @@ class TestExtensionCommands(unittest.TestCase):
 
     def test_list_available_extensions_default(self):
         with mock.patch('azure.cli.core.extension.operations.get_index_extensions', autospec=True) as c:
-            list_available_extensions()
-            c.assert_called_once_with(None)
+            list_available_extensions(cli_ctx=self.cmd.cli_ctx)
+            c.assert_called_once_with(None, self.cmd.cli_ctx)
 
     def test_list_available_extensions_operations_index_url(self):
         with mock.patch('azure.cli.core.extension.operations.get_index_extensions', autospec=True) as c:
             index_url = 'http://contoso.com'
-            list_available_extensions(index_url=index_url)
-            c.assert_called_once_with(index_url)
+            list_available_extensions(index_url=index_url, cli_ctx=self.cmd.cli_ctx)
+            c.assert_called_once_with(index_url, self.cmd.cli_ctx)
 
     def test_list_available_extensions_show_details(self):
         with mock.patch('azure.cli.core.extension.operations.get_index_extensions', autospec=True) as c:
-            list_available_extensions(show_details=True)
-            c.assert_called_once_with(None)
+            list_available_extensions(show_details=True, cli_ctx=self.cmd.cli_ctx)
+            c.assert_called_once_with(None, self.cmd.cli_ctx)
 
     def test_list_available_extensions_no_show_details(self):
         sample_index_extensions = {
@@ -364,7 +364,7 @@ class TestExtensionCommands(unittest.TestCase):
                 }}]
         }
         with mock.patch('azure.cli.core.extension.operations.get_index_extensions', return_value=sample_index_extensions):
-            res = list_available_extensions()
+            res = list_available_extensions(cli_ctx=self.cmd.cli_ctx)
             self.assertIsInstance(res, list)
             self.assertEqual(len(res), len(sample_index_extensions))
             self.assertEqual(res[0]['name'], 'test_sample_extension1')
@@ -373,7 +373,7 @@ class TestExtensionCommands(unittest.TestCase):
             self.assertEqual(res[0]['preview'], False)
             self.assertEqual(res[0]['experimental'], False)
         with mock.patch('azure.cli.core.extension.operations.get_index_extensions', return_value=sample_index_extensions):
-            res = list_available_extensions()
+            res = list_available_extensions(cli_ctx=self.cmd.cli_ctx)
             self.assertIsInstance(res, list)
             self.assertEqual(len(res), len(sample_index_extensions))
             self.assertEqual(res[1]['name'], 'test_sample_extension2')
@@ -393,7 +393,7 @@ class TestExtensionCommands(unittest.TestCase):
                 }}]
         }
         with mock.patch('azure.cli.core.extension.operations.get_index_extensions', return_value=sample_index_extensions):
-            res = list_available_extensions()
+            res = list_available_extensions(cli_ctx=self.cmd.cli_ctx)
             self.assertIsInstance(res, list)
             self.assertEqual(len(res), 0)
 
