@@ -8,14 +8,15 @@ from collections import namedtuple
 import os
 import sys
 import unittest
-import mock
+from unittest import mock
 import tempfile
 import json
 
 from azure.cli.core.util import \
     (get_file_json, truncate_text, shell_safe_json_parse, b64_to_hex, hash_string, random_string,
      open_page_in_browser, can_launch_browser, handle_exception, ConfiguredDefaultSetter, send_raw_request,
-     should_disable_connection_verify, parse_proxy_resource_id, get_az_user_agent, get_az_rest_user_agent)
+     should_disable_connection_verify, parse_proxy_resource_id, get_az_user_agent, get_az_rest_user_agent,
+     _get_parent_proc_name, is_wsl)
 from azure.cli.core.mock import DummyCli
 
 
@@ -150,54 +151,62 @@ class TestUtils(unittest.TestCase):
 
     @mock.patch('webbrowser.open', autospec=True)
     @mock.patch('subprocess.Popen', autospec=True)
-    def test_open_page_in_browser(self, sunprocess_open_mock, webbrowser_open_mock):
+    def test_open_page_in_browser(self, subprocess_open_mock, webbrowser_open_mock):
         platform = sys.platform.lower()
         open_page_in_browser('http://foo')
-        if platform == 'darwin':
-            sunprocess_open_mock.assert_called_once_with(['open', 'http://foo'])
+        if is_wsl():
+            subprocess_open_mock.assert_called_once_with(['powershell.exe', '-NoProfile',
+                                                          '-Command', 'Start-Process "http://foo"'])
+        elif platform == 'darwin':
+            subprocess_open_mock.assert_called_once_with(['open', 'http://foo'])
         else:
             webbrowser_open_mock.assert_called_once_with('http://foo', 2)
 
+    @mock.patch('shutil.which', autospec=True)
     @mock.patch('azure.cli.core.util._get_platform_info', autospec=True)
     @mock.patch('webbrowser.get', autospec=True)
-    def test_can_launch_browser(self, webbrowser_get_mock, get_platform_mock):
-        # WSL is always fine
-        get_platform_mock.return_value = ('linux', '4.4.0-17134-microsoft')
-        result = can_launch_browser()
-        self.assertTrue(result)
+    def test_can_launch_browser(self, webbrowser_get_mock, get_platform_mock, which_mock):
+        import webbrowser
 
-        # windows is always fine
+        # Windows is always fine
         get_platform_mock.return_value = ('windows', '10')
-        result = can_launch_browser()
-        self.assertTrue(result)
+        assert can_launch_browser()
 
-        # osx is always fine
+        # MacOS is always fine
         get_platform_mock.return_value = ('darwin', '10')
-        result = can_launch_browser()
-        self.assertTrue(result)
+        assert can_launch_browser()
 
-        # now tests linux
-        with mock.patch('os.environ', autospec=True) as env_mock:
-            # when no GUI, return false
-            get_platform_mock.return_value = ('linux', '4.15.0-1014-azure')
-            env_mock.get.return_value = None
-            result = can_launch_browser()
-            self.assertFalse(result)
+        # Real linux with browser
+        get_platform_mock.return_value = ('linux', '4.15.0-1014-azure')
+        browser_mock = mock.MagicMock()
+        browser_mock.name = 'www-browser'
+        webbrowser_get_mock.return_value = browser_mock
+        assert can_launch_browser()
 
-            # when there is gui, and browser is a good one, return True
-            browser_mock = mock.MagicMock()
-            browser_mock.name = 'goodone'
-            env_mock.get.return_value = 'foo'
-            result = can_launch_browser()
-            self.assertTrue(result)
+        # Real linux without browser
+        get_platform_mock.return_value = ('linux', '4.15.0-1014-azure')
+        webbrowser_get_mock.side_effect = webbrowser.Error
+        assert not can_launch_browser()
 
-            # when there is gui, but the browser is text mode, return False
-            browser_mock = mock.MagicMock()
-            browser_mock.name = 'www-browser'
-            webbrowser_get_mock.return_value = browser_mock
-            env_mock.get.return_value = 'foo'
-            result = can_launch_browser()
-            self.assertFalse(result)
+        # WSL Linux with www-browser
+        get_platform_mock.return_value = ('linux', '5.10.16.3-microsoft-standard-WSL2')
+        browser_mock = mock.MagicMock()
+        browser_mock.name = 'www-browser'
+        webbrowser_get_mock.return_value = browser_mock
+        assert can_launch_browser()
+
+        # WSL Linux without www-browser, but with powershell.exe
+        get_platform_mock.return_value = ('linux', '5.10.16.3-microsoft-standard-WSL2')
+        webbrowser_get_mock.side_effect = webbrowser.Error
+        which_mock.return_value = True
+        assert can_launch_browser()
+
+        # Docker container on WSL 2 can't launch browser
+        get_platform_mock.return_value = ('linux', '5.10.16.3-microsoft-standard-WSL2')
+        import webbrowser
+        webbrowser_get_mock.side_effect = webbrowser.Error
+        which_mock.return_value = False
+        assert not can_launch_browser()
 
     def test_configured_default_setter(self):
         config = mock.MagicMock()
@@ -267,20 +276,20 @@ class TestUtils(unittest.TestCase):
                          generated_client_request_id_name=None)
 
         get_raw_token_mock.assert_not_called()
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertEqual(request.method, 'PUT')
         self.assertEqual(request.url, 'https://myaccount.blob.core.windows.net/mycontainer/myblob?timeout=30&sv=2019-02-02&srt=s&ss=bf')
         self.assertEqual(request.body, '{"b1": "v1"}')
         # Verify no Authorization header
         self.assertDictEqual(dict(request.headers), expected_header)
-        self.assertEqual(send_mock.call_args.kwargs["verify"], not should_disable_connection_verify())
+        self.assertEqual(send_mock.call_args[1]["verify"], not should_disable_connection_verify())
 
         # Test Authorization header is skipped
         send_raw_request(cli_ctx, 'GET', full_arm_rest_url, body=test_body, skip_authorization_header=True,
                          generated_client_request_id_name=None)
 
         get_raw_token_mock.assert_not_called()
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertDictEqual(dict(request.headers), expected_header)
 
         # Test Authorization header is already provided
@@ -289,7 +298,7 @@ class TestUtils(unittest.TestCase):
                          generated_client_request_id_name=None)
 
         get_raw_token_mock.assert_not_called()
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertDictEqual(dict(request.headers), {**expected_header, 'Authorization': 'Basic ABCDE'})
 
         # Test Authorization header is auto appended
@@ -298,7 +307,7 @@ class TestUtils(unittest.TestCase):
                          generated_client_request_id_name=None)
 
         get_raw_token_mock.assert_called_with(mock.ANY, test_arm_active_directory_resource_id, subscription=subscription_id)
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertDictEqual(dict(request.headers), expected_header_with_auth)
 
         # Test ARM Subscriptions - List
@@ -308,7 +317,7 @@ class TestUtils(unittest.TestCase):
                          generated_client_request_id_name=None)
 
         get_raw_token_mock.assert_called_with(mock.ANY, test_arm_active_directory_resource_id)
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertEqual(request.url, test_arm_endpoint.rstrip('/') + '/subscriptions?api-version=2020-01-01')
         self.assertDictEqual(dict(request.headers), expected_header_with_auth)
 
@@ -319,7 +328,7 @@ class TestUtils(unittest.TestCase):
                          generated_client_request_id_name=None)
 
         get_raw_token_mock.assert_called_with(mock.ANY, test_arm_active_directory_resource_id)
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertEqual(request.url, test_arm_endpoint.rstrip('/') + '/tenants?api-version=2020-01-01')
         self.assertDictEqual(dict(request.headers), expected_header_with_auth)
 
@@ -329,7 +338,7 @@ class TestUtils(unittest.TestCase):
                          generated_client_request_id_name=None)
 
         get_raw_token_mock.assert_called_with(mock.ANY, test_arm_active_directory_resource_id, subscription=subscription_id)
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertEqual(request.url, full_arm_rest_url)
         self.assertDictEqual(dict(request.headers), expected_header_with_auth)
 
@@ -338,7 +347,7 @@ class TestUtils(unittest.TestCase):
         send_raw_request(cli_ctx, 'GET', full_arm_rest_url)
 
         get_raw_token_mock.assert_called_with(mock.ANY, test_arm_active_directory_resource_id, subscription=subscription_id)
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertEqual(request.url, full_arm_rest_url)
 
         # Test full ARM URL with port
@@ -348,7 +357,7 @@ class TestUtils(unittest.TestCase):
         send_raw_request(cli_ctx, 'GET', full_arm_rest_url_with_port)
 
         get_raw_token_mock.assert_called_with(mock.ANY, test_arm_active_directory_resource_id, subscription=subscription_id)
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertEqual(request.url, 'https://management.azure.com:443/subscriptions/00000001-0000-0000-0000-000000000000/resourcegroups/02?api-version=2019-07-01')
 
         # Test non-ARM APIs
@@ -357,7 +366,7 @@ class TestUtils(unittest.TestCase):
         url = 'https://graph.windows.net/00000002-0000-0000-0000-000000000000/applications/00000003-0000-0000-0000-000000000000?api-version=1.6'
         send_raw_request(cli_ctx, 'PATCH', url, body=test_body, generated_client_request_id_name=None)
         get_raw_token_mock.assert_called_with(mock.ANY, 'https://graph.windows.net/')
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertEqual(request.method, 'PATCH')
         self.assertEqual(request.url, url)
 
@@ -365,7 +374,7 @@ class TestUtils(unittest.TestCase):
         url = 'https://graph.microsoft.com/beta/appRoleAssignments/01'
         send_raw_request(cli_ctx, 'PATCH', url, body=test_body, generated_client_request_id_name=None)
         get_raw_token_mock.assert_called_with(mock.ANY, 'https://graph.microsoft.com/')
-        request = send_mock.call_args.args[1]
+        request = send_mock.call_args[0][1]
         self.assertEqual(request.method, 'PATCH')
         self.assertEqual(request.url, url)
 
@@ -374,43 +383,43 @@ class TestUtils(unittest.TestCase):
             send_raw_request(cli_ctx, 'GET', full_arm_rest_url, headers={'user-agent=ARG-UA'})
 
             get_raw_token_mock.assert_called_with(mock.ANY, test_arm_active_directory_resource_id, subscription=subscription_id)
-            request = send_mock.call_args.args[1]
+            request = send_mock.call_args[0][1]
             self.assertEqual(request.headers['User-Agent'], get_az_rest_user_agent() + ' env-ua ARG-UA')
 
-    def test_scopes_to_resource(self):
-        from azure.cli.core.util import scopes_to_resource
-        # scopes as a list
-        self.assertEqual(scopes_to_resource(['https://management.core.windows.net//.default']),
-                         'https://management.core.windows.net/')
-        # scopes as a tuple
-        self.assertEqual(scopes_to_resource(('https://storage.azure.com/.default',)),
-                         'https://storage.azure.com')
+    @mock.patch("psutil.Process")
+    def test_get_parent_proc_name(self, mock_process_type):
+        process = mock_process_type.return_value
+        parent1 = process.parent.return_value
+        parent2 = parent1.parent.return_value
+        parent3 = parent2.parent.return_value
 
-        # resource with trailing slash
-        self.assertEqual(scopes_to_resource(('https://management.azure.com//.default',)),
-                         'https://management.azure.com/')
-        self.assertEqual(scopes_to_resource(['https://datalake.azure.net//.default']),
-                         'https://datalake.azure.net/')
+        # Windows, in a virtual env, launched by pwsh.exe
+        process.name.return_value = "python.exe"
+        parent1.name.return_value = "python.exe"
+        parent2.name.return_value = "cmd.exe"
+        parent3.name.return_value = "pwsh.exe"
+        self.assertEqual(_get_parent_proc_name(), "pwsh.exe")
 
-        # resource without trailing slash
-        self.assertEqual(scopes_to_resource(('https://managedhsm.azure.com/.default',)),
-                         'https://managedhsm.azure.com')
+        # Windows, in a virtual env, launched by powershell.exe
+        parent3.name.return_value = "powershell.exe"
+        self.assertEqual(_get_parent_proc_name(), "powershell.exe")
 
-    def test_resource_to_scopes(self):
-        from azure.cli.core.util import resource_to_scopes
-        # resource converted to a scopes list
-        self.assertEqual(resource_to_scopes('https://management.core.windows.net/'),
-                         ['https://management.core.windows.net//.default'])
+        # Windows, launched by cmd.exe
+        parent1.name.return_value = "cmd.exe"
+        parent2.name.return_value = "explorer.exe"
+        self.assertEqual(_get_parent_proc_name(), "cmd.exe")
 
-        # resource with trailing slash
-        self.assertEqual(resource_to_scopes('https://management.azure.com/'),
-                         ['https://management.azure.com//.default'])
-        self.assertEqual(resource_to_scopes('https://datalake.azure.net/'),
-                         ['https://datalake.azure.net//.default'])
+        # Linux, launched by bash
+        process.name.return_value = "python"
+        parent1.name.return_value = "bash"
+        parent2.name.return_value = "init"
+        self.assertEqual(_get_parent_proc_name(), "bash")
 
-        # resource without trailing slash
-        self.assertEqual(resource_to_scopes('https://managedhsm.azure.com'),
-                         ['https://managedhsm.azure.com/.default'])
+        # Linux, launched by pwsh, launched by bash
+        process.name.return_value = "python"
+        parent1.name.return_value = "pwsh"
+        parent2.name.return_value = "bash"
+        self.assertEqual(_get_parent_proc_name(), "pwsh")
 
 
 class TestBase64ToHex(unittest.TestCase):
@@ -452,7 +461,7 @@ class TestHandleException(unittest.TestCase):
 
         # test behavior
         self.assertTrue(mock_logger_error.called)
-        self.assertIn(err_msg, mock_logger_error.call_args.args[0])
+        self.assertIn(err_msg, mock_logger_error.call_args[0][0])
         self.assertEqual(ex_result, 1)
 
     @mock.patch('azure.cli.core.azclierror.logger.error', autospec=True)
@@ -470,7 +479,7 @@ class TestHandleException(unittest.TestCase):
 
         # test behavior
         self.assertTrue(mock_logger_error.called)
-        self.assertIn(mock_cloud_error.args[0], mock_logger_error.call_args.args[0])
+        self.assertIn(mock_cloud_error.args[0], mock_logger_error.call_args[0][0])
         self.assertEqual(ex_result, 1)
 
     @mock.patch('azure.cli.core.azclierror.logger.error', autospec=True)
@@ -487,8 +496,8 @@ class TestHandleException(unittest.TestCase):
 
         # test behavior
         self.assertTrue(mock_logger_error.called)
-        self.assertIn(err_msg, mock_logger_error.call_args.args[0])
-        self.assertIn(err_code, mock_logger_error.call_args.args[0])
+        self.assertIn(err_msg, mock_logger_error.call_args[0][0])
+        self.assertIn(err_code, mock_logger_error.call_args[0][0])
         self.assertEqual(ex_result, 1)
 
     @mock.patch('azure.cli.core.azclierror.logger.error', autospec=True)
@@ -508,7 +517,7 @@ class TestHandleException(unittest.TestCase):
 
         # test behavior
         self.assertTrue(mock_logger_error.called)
-        self.assertIn(expected_message, mock_logger_error.call_args.args[0])
+        self.assertIn(expected_message, mock_logger_error.call_args[0][0])
         self.assertEqual(ex_result, 1)
 
     @mock.patch('azure.cli.core.azclierror.logger.error', autospec=True)
@@ -526,7 +535,7 @@ class TestHandleException(unittest.TestCase):
 
         # test behavior
         self.assertTrue(mock_logger_error.called)
-        self.assertIn(str(mock.call(mock_http_error).args[0]), mock_logger_error.call_args.args[0])
+        self.assertIs(str(mock_http_error), mock_logger_error.call_args[0][0])
         self.assertEqual(ex_result, 1)
 
     @mock.patch('azure.cli.core.azclierror.logger.error', autospec=True)
@@ -543,7 +552,7 @@ class TestHandleException(unittest.TestCase):
 
         # test behavior
         self.assertTrue(mock_logger_error.called)
-        self.assertIn(str(mock.call(mock_http_error).args[0]), mock_logger_error.call_args.args[0])
+        self.assertIn(str(mock_http_error), mock_logger_error.call_args[0][0])
         self.assertEqual(ex_result, 1)
 
     @staticmethod
