@@ -215,7 +215,7 @@ class KeyVaultPreparer(NoTrafficRecordingPreparer, SingleValueReplacer):
 class ManagedHSMPreparer(NoTrafficRecordingPreparer, SingleValueReplacer):
     def __init__(self, certs_path, name_prefix='clitest', location='uksouth', key='hsm', name_len=24,
                  parameter_name='managed_hsm', resource_group_parameter_name='resource_group',
-                 administrators=None, additional_params=None):
+                 administrators=None, roles=[], additional_params=None):
         super(ManagedHSMPreparer, self).__init__(name_prefix, name_len)
         self.cli_ctx = get_dummy_cli()
         self.location = location
@@ -224,6 +224,7 @@ class ManagedHSMPreparer(NoTrafficRecordingPreparer, SingleValueReplacer):
         self.key = key
         self.certs_path = certs_path
         self.administrators = administrators
+        self.roles = roles
         self.additional_params = additional_params
 
     def create_resource(self, name, **kwargs):
@@ -243,6 +244,10 @@ class ManagedHSMPreparer(NoTrafficRecordingPreparer, SingleValueReplacer):
             security_domain = os.path.join(self.certs_path, f'{name}-SD.json').replace('\\', '\\\\')
             activate_template = f'az keyvault security-domain download --hsm-name {name} --sd-wrapping-keys {cert0} {cert1} {cert2} --sd-quorum 2 --security-domain-file {security_domain}'
             self.live_only_execute(self.cli_ctx, activate_template)
+        if self.roles:
+            for role in self.roles:
+                role_assignment_template = f'az keyvault role assignment create --hsm-name {name} --role "{role}" --assignee {administrators} --scope "/"'
+                self.live_only_execute(self.cli_ctx, role_assignment_template)
         self.test_class_instance.kwargs[self.key] = name
         return {self.parameter_name: name}
 
