@@ -15,7 +15,6 @@ CLASSIFIERS = [
     'Intended Audience :: Developers',
     'Programming Language :: Python',
     'Programming Language :: Python :: 3',
-    'Programming Language :: Python :: 3.6',
     'Programming Language :: Python :: 3.7',
     'Programming Language :: Python :: 3.8',
     'Programming Language :: Python :: 3.9',
@@ -24,9 +23,9 @@ CLASSIFIERS = [
 ]
 
 DEPENDENCIES = [
+    'ConfigArgParse>=0.12.0',
     'jmespath',
     'vcrpy>=1.10.3',
-    'azure-devtools==1.2.0',
     'pytest'
 ]
 
@@ -47,7 +46,8 @@ setup(
     zip_safe=False,
     classifiers=CLASSIFIERS,
     packages=[
-        'azure.cli.testsdk'
+        'azure.cli.testsdk',
+        'azure.cli.testsdk.scenario_tests',
     ],
     install_requires=DEPENDENCIES
 )
