@@ -6,7 +6,9 @@
 from collections import OrderedDict
 from datetime import datetime
 from knack.log import get_logger
-
+from ._constants import (
+    REF_KEY
+)
 
 logger = get_logger(__name__)
 
@@ -132,7 +134,7 @@ def connected_registry_list_output_format(result):
 
 def list_referrers_output_format(result):
     manifests = []
-    for manifest in result['references']:
+    for manifest in result[REF_KEY]:
         manifests.append(OrderedDict([
             ('Digest', _get_value(manifest, 'digest')),
             ('ArtifactType', _get_value(manifest, 'artifactType')),
