@@ -102,81 +102,81 @@ class AmsStreamingEndpointsTests(ScenarioTest):
 
         self.cmd('az ams streaming-endpoint delete -g {rg} -a {amsname} -n {streamingEndpointName}')
 
-    @ResourceGroupPreparer()
-    @StorageAccountPreparer(parameter_name='storage_account_for_create')
-    def test_ams_streaming_endpoint_update(self, storage_account_for_create):
-        if sys.version_info.major == 2:  # azure-cli/issues/9386
-            return
-        amsname = self.create_random_name(prefix='ams', length=12)
-        streaming_endpoint_name = self.create_random_name(prefix="strep", length=11)
-
-        self.kwargs.update({
-            'amsname': amsname,
-            'storageAccount': storage_account_for_create,
-            'location': 'australiaeast',
-            'streamingEndpointName': streaming_endpoint_name,
-            'cdnProvider': 'StandardVerizon',
-            'cdnProfile': 'testProfile',
-            'description': 'test streaming description',
-            'maxCacheAge': 11,
-            'scaleUnits': 5,
-            'tags': 'foo=bar',
-            'clientAccessPolicy': self._normalize_filename(_get_test_data_file('clientAccessPolicy.xml')),
-            'crossDomainPolicy': self._normalize_filename(_get_test_data_file('crossDomainPolicy.xml')),
-            'ip': '4.4.4.4'
-        })
-
-        self.cmd('az ams account create -n {amsname} -g {rg} --storage-account {storageAccount} -l {location}')
-
-        self.cmd('az ams streaming-endpoint create -g {rg} -a {amsname} -n {streamingEndpointName} --cdn-provider {cdnProvider} --cdn-profile {cdnProfile} --description "{description}" --max-cache-age {maxCacheAge} --scale-units {scaleUnits} --tags "{tags}" --client-access-policy @"{clientAccessPolicy}" --cross-domain-policy @"{crossDomainPolicy}"', checks=[
-            self.check('name', '{streamingEndpointName}'),
-            self.check('resourceGroup', '{rg}'),
-            self.check('location', 'Australia East'),
-            self.check('cdnProvider', '{cdnProvider}'),
-            self.check('cdnProfile', '{cdnProfile}'),
-            self.check('description', '{description}'),
-            self.check('maxCacheAge', '{maxCacheAge}'),
-            self.check('scaleUnits', '{scaleUnits}'),
-            self.check('length(tags)', 1)
-        ])
-
-        with self.assertRaises(CLIError):
-            self.cmd('az ams streaming-endpoint update -g {rg} -a {amsname} -n {streamingEndpointName} --add access_control.ip.allow {ip}')
-
-        self.kwargs.update({
-            'streamingEndpointName': streaming_endpoint_name,
-            'cdnProvider': 'PremiumVerizon',
-            'cdnProfile': 'testProfile2',
-            'description': 'test streaming description2',
-            'maxCacheAge': 9,
-            'tags': 'foo2=bar2 foo3=bar3',
-            'clientAccessPolicy': self._normalize_filename(_get_test_data_file('clientAccessPolicy.xml')),
-            'crossDomainPolicy': self._normalize_filename(_get_test_data_file('crossDomainPolicy.xml')),
-            'ips': '1.1.1.1 2.2.2.2 192.168.0.0/28'
-        })
-
-        self.cmd('az ams streaming-endpoint update -g {rg} -a {amsname} -n {streamingEndpointName} --cdn-provider {cdnProvider} --cdn-profile {cdnProfile} --description "{description}" --max-cache-age {maxCacheAge} --tags {tags} --client-access-policy @"{clientAccessPolicy}" --cross-domain-policy @"{crossDomainPolicy}"', checks=[
-            self.check('name', '{streamingEndpointName}'),
-            self.check('cdnProvider', '{cdnProvider}'),
-            self.check('cdnProfile', '{cdnProfile}'),
-            self.check('description', '{description}'),
-            self.check('maxCacheAge', '{maxCacheAge}'),
-            self.check('length(tags)', 2)
-        ])
-
-        self.cmd('az ams streaming-endpoint update -g {rg} -a {amsname} -n {streamingEndpointName} --ips {ips} --disable-cdn')
-
-        self.cmd('az ams streaming-endpoint show -g {rg} -a {amsname} -n {streamingEndpointName}', checks=[
-            self.check('name', '{streamingEndpointName}'),
-            self.check('cdnProvider', None),
-            self.check('cdnProfile', ''),
-            self.check('cdnEnabled', False),
-            self.check('length(accessControl.ip.allow)', 3),
-            self.check('accessControl.ip.allow[2].address', '192.168.0.0'),
-            self.check('accessControl.ip.allow[2].subnetPrefixLength', '28')
-        ])
-
-        self.cmd('az ams streaming-endpoint delete -g {rg} -a {amsname} -n {streamingEndpointName}')
+    # @ResourceGroupPreparer()
+    # @StorageAccountPreparer(parameter_name='storage_account_for_create')
+    # def test_ams_streaming_endpoint_update(self, storage_account_for_create):
+    #     if sys.version_info.major == 2:  # azure-cli/issues/9386
+    #         return
+    #     amsname = self.create_random_name(prefix='ams', length=12)
+    #     streaming_endpoint_name = self.create_random_name(prefix="strep", length=11)
+    #
+    #     self.kwargs.update({
+    #         'amsname': amsname,
+    #         'storageAccount': storage_account_for_create,
+    #         'location': 'australiaeast',
+    #         'streamingEndpointName': streaming_endpoint_name,
+    #         'cdnProvider': 'StandardVerizon',
+    #         'cdnProfile': 'testProfile',
+    #         'description': 'test streaming description',
+    #         'maxCacheAge': 11,
+    #         'scaleUnits': 5,
+    #         'tags': 'foo=bar',
+    #         'clientAccessPolicy': self._normalize_filename(_get_test_data_file('clientAccessPolicy.xml')),
+    #         'crossDomainPolicy': self._normalize_filename(_get_test_data_file('crossDomainPolicy.xml')),
+    #         'ip': '4.4.4.4'
+    #     })
+    #
+    #     self.cmd('az ams account create -n {amsname} -g {rg} --storage-account {storageAccount} -l {location}')
+    #
+    #     self.cmd('az ams streaming-endpoint create -g {rg} -a {amsname} -n {streamingEndpointName} --cdn-provider {cdnProvider} --cdn-profile {cdnProfile} --description "{description}" --max-cache-age {maxCacheAge} --scale-units {scaleUnits} --tags "{tags}" --client-access-policy @"{clientAccessPolicy}" --cross-domain-policy @"{crossDomainPolicy}"', checks=[
+    #         self.check('name', '{streamingEndpointName}'),
+    #         self.check('resourceGroup', '{rg}'),
+    #         self.check('location', 'Australia East'),
+    #         self.check('cdnProvider', '{cdnProvider}'),
+    #         self.check('cdnProfile', '{cdnProfile}'),
+    #         self.check('description', '{description}'),
+    #         self.check('maxCacheAge', '{maxCacheAge}'),
+    #         self.check('scaleUnits', '{scaleUnits}'),
+    #         self.check('length(tags)', 1)
+    #     ])
+    #
+    #     with self.assertRaises(CLIError):
+    #         self.cmd('az ams streaming-endpoint update -g {rg} -a {amsname} -n {streamingEndpointName} --add access_control.ip.allow {ip}')
+    #
+    #     self.kwargs.update({
+    #         'streamingEndpointName': streaming_endpoint_name,
+    #         'cdnProvider': 'PremiumVerizon',
+    #         'cdnProfile': 'testProfile2',
+    #         'description': 'test streaming description2',
+    #         'maxCacheAge': 9,
+    #         'tags': 'foo2=bar2 foo3=bar3',
+    #         'clientAccessPolicy': self._normalize_filename(_get_test_data_file('clientAccessPolicy.xml')),
+    #         'crossDomainPolicy': self._normalize_filename(_get_test_data_file('crossDomainPolicy.xml')),
+    #         'ips': '1.1.1.1 2.2.2.2 192.168.0.0/28'
+    #     })
+    #
+    #     self.cmd('az ams streaming-endpoint update -g {rg} -a {amsname} -n {streamingEndpointName} --cdn-provider {cdnProvider} --cdn-profile {cdnProfile} --description "{description}" --max-cache-age {maxCacheAge} --tags {tags} --client-access-policy @"{clientAccessPolicy}" --cross-domain-policy @"{crossDomainPolicy}"', checks=[
+    #         self.check('name', '{streamingEndpointName}'),
+    #         self.check('cdnProvider', '{cdnProvider}'),
+    #         self.check('cdnProfile', '{cdnProfile}'),
+    #         self.check('description', '{description}'),
+    #         self.check('maxCacheAge', '{maxCacheAge}'),
+    #         self.check('length(tags)', 2)
+    #     ])
+    #
+    #     self.cmd('az ams streaming-endpoint update -g {rg} -a {amsname} -n {streamingEndpointName} --ips {ips} --disable-cdn')
+    #
+    #     self.cmd('az ams streaming-endpoint show -g {rg} -a {amsname} -n {streamingEndpointName}', checks=[
+    #         self.check('name', '{streamingEndpointName}'),
+    #         self.check('cdnProvider', None),
+    #         self.check('cdnProfile', ''),
+    #         self.check('cdnEnabled', False),
+    #         self.check('length(accessControl.ip.allow)', 3),
+    #         self.check('accessControl.ip.allow[2].address', '192.168.0.0'),
+    #         self.check('accessControl.ip.allow[2].subnetPrefixLength', '28')
+    #     ])
+    #
+    #     self.cmd('az ams streaming-endpoint delete -g {rg} -a {amsname} -n {streamingEndpointName}')
 
     @ResourceGroupPreparer()
     @StorageAccountPreparer(parameter_name='storage_account_for_create')
@@ -454,6 +454,40 @@ class AmsStreamingEndpointsTests(ScenarioTest):
             self.check('length(@)', 2)
         ])
 
+    @ResourceGroupPreparer()
+    @StorageAccountPreparer(parameter_name='storage_account_for_create')
+    def test_ams_streaming_endpoint_get_skus(self, storage_account_for_create):
+        amsname = self.create_random_name(prefix='ams', length=12)
+        streaming_endpoint_name = self.create_random_name(prefix="strep", length=11)
+
+        self.kwargs.update({
+            'amsname': amsname,
+            'storageAccount': storage_account_for_create,
+            'location': 'canadacentral',
+            'streamingEndpointName': streaming_endpoint_name,
+            'scaleUnits': 6,
+        })
+
+        self.cmd('az ams account create -n {amsname} -g {rg} --storage-account {storageAccount} -l {location}')
+
+        self.cmd(
+            'az ams streaming-endpoint create -g {rg} -a {amsname} -n {streamingEndpointName} --scale-units {scaleUnits}',
+            checks=[
+                self.check('name', '{streamingEndpointName}'),
+                self.check('resourceGroup', '{rg}'),
+                self.check('location', 'Canada Central'),
+                self.check('scaleUnits', '{scaleUnits}')
+            ])
+
+        self.cmd('az ams streaming-endpoint get-skus -g {rg} -a {amsname} -n {streamingEndpointName}',
+                 checks=[
+                     self.check('value[0].capacity.default', '1'),
+                     self.check('value[0].sku.name', 'Premium')
+                 ])
+
+        self.cmd('az ams streaming-endpoint delete -g {rg} -a {amsname} -n {streamingEndpointName}')
+
+
 # Helper functions
 
     def _normalize_filename(cmd, string):
