@@ -10,7 +10,7 @@ from azure.cli.core.commands import CliCommandType
 from azure.cli.command_modules.apim._format import (service_output_format)
 from azure.cli.command_modules.apim._client_factory import (cf_service, cf_api, cf_product, cf_nv, cf_apiops,
                                                             cf_apirelease, cf_apirevision, cf_apiversionset,
-                                                            cf_apischema)
+                                                            cf_apischema, cf_ds)
 
 
 def load_command_table(self, _):
@@ -59,6 +59,11 @@ def load_command_table(self, _):
         client_factory=cf_apiversionset
     )
 
+    apids_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.apimanagement.operations#DeletedServicesOperations.{}',
+        client_factory=cf_ds
+    )
+
     # pylint: disable=line-too-long
     with self.command_group('apim', service_sdk) as g:
         g.custom_command('create', 'apim_create', supports_no_wait=True,
@@ -118,6 +123,7 @@ def load_command_table(self, _):
         g.custom_command('delete', 'apim_nv_delete', confirmation=True)
         g.custom_command('show-secret', 'apim_nv_show_secret')
         g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='apim_nv_update')
+        g.wait_command('wait')
 
     with self.command_group('apim api operation', apiops_sdk) as g:
         g.custom_command('list', 'apim_api_operation_list')
@@ -143,3 +149,8 @@ def load_command_table(self, _):
         g.custom_command('create', 'apim_api_vs_create')
         g.generic_update_command('update', custom_func_name='apim_api_vs_update')
         g.custom_command('delete', 'apim_api_vs_delete')
+
+    with self.command_group('apim deletedservice', apids_sdk) as g:
+        g.custom_command('list', 'apim_ds_list')
+        g.custom_show_command('show', 'apim_ds_get')
+        g.custom_command('purge', 'apim_ds_purge')
