@@ -38,6 +38,10 @@ def featurefilter_entry_format(result):
     return _output_format(result, _featurefilter_entry_format_group)
 
 
+def configstore_replica_output_format(result):
+    return _output_format(result, _configstore_replica_format_group)
+
+
 def _output_format(result, format_group):
     if 'value' in result and isinstance(result['value'], list):
         result = result['value']
@@ -77,6 +81,17 @@ def _deleted_configstore_format_group(item):
     ])
 
 
+def _configstore_replica_format_group(item):
+    return OrderedDict([
+        ('CREATION DATE', _format_datetime(_get_value(item, 'systemData', 'createdAt'))),
+        ('ENDPOINT', _get_value(item, 'endpoint')),
+        ('LOCATION', _get_value(item, 'location')),
+        ('NAME', _get_value(item, 'name')),
+        ('PROVISIONING STATE', _get_value(item, 'provisioningState')),
+        ('RESOURCE GROUP', _get_value(item, 'resourceGroup'))
+    ])
+
+
 def _configstore_identity_format_group(item):
     return OrderedDict([
         ('PRINCIPAL ID', _format_datetime(_get_value(item, 'principalId'))),
