@@ -12,7 +12,7 @@ import copy
 
 from knack.log import get_logger
 from knack.util import CLIError
-from azure.cli.core.azclierror import RequiredArgumentMissingError
+import azure.cli.core.azclierror as CLIErrors
 
 from azure.appconfiguration import (ConfigurationSetting,
                                     ResourceReadOnlyError)
@@ -49,7 +49,7 @@ def set_feature(cmd,
                 auth_mode="key",
                 endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
 
     key = FeatureFlagConstants.FEATURE_FLAG_PREFIX + feature if key is None else key
     feature = key[len(FeatureFlagConstants.FEATURE_FLAG_PREFIX):] if feature is None else feature
@@ -82,7 +82,7 @@ def set_feature(cmd,
         except ResourceNotFoundError:
             logger.debug("Feature flag '%s' with label '%s' not found. A new feature flag will be created.", feature, label)
         except HttpResponseError as exception:
-            raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
         try:
             # if kv exists and only content-type is wrong, we can force correct it by updating the kv
@@ -141,7 +141,7 @@ def set_feature(cmd,
                 logger.debug('Retrying setting %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError("Failed to set the feature flag '{}' due to a conflicting operation.".format(feature))
@@ -157,7 +157,7 @@ def delete_feature(cmd,
                    auth_mode="key",
                    endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -193,7 +193,7 @@ def delete_feature(cmd,
             exception_messages.append(exception)
         except HttpResponseError as ex:
             exception_messages.append(str(ex))
-            raise CLIError('Delete operation failed. The following error(s) occurred:\n' + json.dumps(exception_messages, indent=2, ensure_ascii=False))
+            raise CLIErrors.AzureResponseError('Delete operation failed. The following error(s) occurred:\n' + json.dumps(exception_messages, indent=2, ensure_ascii=False))
 
     # Log errors if partially succeeded
     if exception_messages:
@@ -201,7 +201,7 @@ def delete_feature(cmd,
             logger.error('Delete operation partially failed. The following error(s) occurred:\n%s\n',
                          json.dumps(exception_messages, indent=2, ensure_ascii=False))
         else:
-            raise CLIError('Delete operation failed. \n' + json.dumps(exception_messages, indent=2, ensure_ascii=False))
+            raise CLIErrors.AzureResponseError('Delete operation failed. \n' + json.dumps(exception_messages, indent=2, ensure_ascii=False))
 
     # Convert result list of KeyValue to list of FeatureFlag
     deleted_ff = []
@@ -222,7 +222,7 @@ def show_feature(cmd,
                  auth_mode="key",
                  endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -235,7 +235,7 @@ def show_feature(cmd,
     try:
         config_setting = azconfig_client.get_configuration_setting(key=key, label=label)
         if config_setting is None or config_setting.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-            raise CLIError("The feature flag does not exist.")
+            raise CLIErrors.ResourceNotFoundError("The feature flag does not exist.")
 
         retrieved_kv = convert_configurationsetting_to_keyvalue(config_setting)
         feature_flag = map_keyvalue_to_featureflag(keyvalue=retrieved_kv, show_conditions=True)
@@ -252,9 +252,9 @@ def show_feature(cmd,
             return partial_featureflag
         return feature_flag
     except ResourceNotFoundError:
-        raise CLIError("Feature '{}' with label '{}' does not exist.".format(feature, label))
+        raise CLIErrors.ResourceNotFoundError("Feature '{}' with label '{}' does not exist.".format(feature, label))
     except HttpResponseError as exception:
-        raise CLIError(str(exception))
+        raise CLIErrors.AzureResponseError(str(exception))
 
 
 def list_feature(cmd,
@@ -327,7 +327,7 @@ def lock_feature(cmd,
                  auth_mode="key",
                  endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -343,12 +343,12 @@ def lock_feature(cmd,
         try:
             retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
         except ResourceNotFoundError:
-            raise CLIError("Feature '{}' with label '{}' does not exist.".format(feature, label))
+            raise CLIErrors.ResourceNotFoundError("Feature '{}' with label '{}' does not exist.".format(feature, label))
         except HttpResponseError as exception:
-            raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
         if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-            raise CLIError("The feature '{}' you are trying to lock does not exist.".format(feature))
+            raise CLIErrors.ResourceNotFoundError("The feature '{}' you are trying to lock does not exist.".format(feature))
 
         confirmation_message = "Are you sure you want to lock the feature '{}' with label '{}'".format(feature, label)
         user_confirmation(confirmation_message, yes)
@@ -362,7 +362,7 @@ def lock_feature(cmd,
                 logger.debug('Retrying lock operation %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError("Failed to lock the feature '{}' with label '{}' due to a conflicting operation.".format(feature, label))
@@ -378,7 +378,7 @@ def unlock_feature(cmd,
                    auth_mode="key",
                    endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -394,12 +394,12 @@ def unlock_feature(cmd,
         try:
             retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
         except ResourceNotFoundError:
-            raise CLIError("Feature '{}' with label '{}' does not exist.".format(feature, label))
+            raise CLIErrors.ResourceNotFoundError("Feature '{}' with label '{}' does not exist.".format(feature, label))
         except HttpResponseError as exception:
-            raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
         if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-            raise CLIError("The feature '{}' you are trying to unlock does not exist.".format(feature))
+            raise CLIErrors.ResourceNotFoundError("The feature '{}' you are trying to unlock does not exist.".format(feature))
 
         confirmation_message = "Are you sure you want to unlock the feature '{}' with label '{}'".format(feature, label)
         user_confirmation(confirmation_message, yes)
@@ -413,7 +413,7 @@ def unlock_feature(cmd,
                 logger.debug('Retrying unlock operation %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError("Failed to unlock the feature '{}' with label '{}' due to a conflicting operation.".format(feature, label))
@@ -429,7 +429,7 @@ def enable_feature(cmd,
                    auth_mode="key",
                    endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -445,13 +445,13 @@ def enable_feature(cmd,
         try:
             retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
         except ResourceNotFoundError:
-            raise CLIError("Feature flag '{}' with label '{}' not found.".format(feature, label))
+            raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
-            raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
         try:
             if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-                raise CLIError("The feature flag {} does not exist.".format(feature))
+                raise CLIErrors.ResourceNotFoundError("The feature flag {} does not exist.".format(feature))
 
             # we make sure that value retrieved is a valid json and only has the fields supported by backend.
             # if it's invalid, we catch appropriate exception that contains
@@ -475,7 +475,7 @@ def enable_feature(cmd,
                 logger.debug('Retrying feature enable operation %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError("Failed to enable the feature flag '{}' due to a conflicting operation.".format(feature))
@@ -491,7 +491,7 @@ def disable_feature(cmd,
                     auth_mode="key",
                     endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -507,13 +507,13 @@ def disable_feature(cmd,
         try:
             retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
         except ResourceNotFoundError:
-            raise CLIError("Feature flag '{}' with label '{}' not found.".format(feature, label))
+            raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
-            raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
         try:
             if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-                raise CLIError("The feature flag {} does not exist.".format(feature))
+                raise CLIErrors.ResourceNotFoundError("The feature flag {} does not exist.".format(feature))
 
             # we make sure that value retrieved is a valid json and only has the fields supported by backend.
             # if it's invalid, we catch appropriate exception that contains
@@ -537,7 +537,7 @@ def disable_feature(cmd,
                 logger.debug('Retrying feature disable operation %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError("Failed to disable the feature flag '{}' due to a conflicting operation.".format(feature))
@@ -559,7 +559,7 @@ def add_filter(cmd,
                auth_mode="key",
                endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -583,13 +583,13 @@ def add_filter(cmd,
         try:
             retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
         except ResourceNotFoundError:
-            raise CLIError("Feature flag '{}' with label '{}' not found.".format(feature, label))
+            raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
-            raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
         try:
             if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-                raise CLIError(
+                raise CLIErrors.ResourceNotFoundError(
                     "The feature flag {} does not exist.".format(feature))
 
             # we make sure that value retrieved is a valid json and only has the fields supported by backend.
@@ -626,7 +626,7 @@ def add_filter(cmd,
                 logger.debug('Retrying filter add operation %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError(
@@ -648,7 +648,7 @@ def update_filter(cmd,
     if auth_mode is None:
         auth_mode = "key"
     if key is None and feature is None:
-        raise RequiredArgumentMissingError(
+        raise CLIErrors.RequiredArgumentMissingError(
             "Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning(
@@ -676,15 +676,15 @@ def update_filter(cmd,
             retrieved_kv = azconfig_client.get_configuration_setting(
                 key=key, label=label)
         except ResourceNotFoundError:
-            raise CLIError(
+            raise CLIErrors.ResourceNotFoundError(
                 "Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
-            raise CLIError(
+            raise CLIErrors.AzureResponseError(
                 "Failed to retrieve feature flags from config store. " + str(exception))
 
         try:
             if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-                raise CLIError(
+                raise CLIErrors.ResourceNotFoundError(
                     "The feature flag {} does not exist.".format(feature))
 
             # we make sure that value retrieved is a valid json and only has the fields supported by backend.
@@ -758,7 +758,7 @@ def update_filter(cmd,
                     'Retrying filter update operation %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError(
@@ -778,7 +778,7 @@ def delete_filter(cmd,
                   auth_mode="key",
                   endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -795,7 +795,7 @@ def delete_filter(cmd,
         return __clear_filter(azconfig_client, feature, label, yes)
 
     if filter_name is None:
-        raise CLIError("Cannot delete filters because filter name is missing. To delete all filters, run the command again with --all option.")
+        raise CLIErrors.RequiredArgumentMissingError("Cannot delete filters because filter name is missing. To delete all filters, run the command again with --all option.")
 
     retry_times = 3
     retry_interval = 1
@@ -803,13 +803,13 @@ def delete_filter(cmd,
         try:
             retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
         except ResourceNotFoundError:
-            raise CLIError("Feature flag '{}' with label '{}' not found.".format(feature, label))
+            raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
-            raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
         try:
             if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-                raise CLIError(
+                raise CLIErrors.ResourceNotFoundError(
                     "The feature flag {} does not exist.".format(feature))
 
             # we make sure that value retrieved is a valid json and only has the fields supported by backend.
@@ -876,7 +876,7 @@ def delete_filter(cmd,
                 logger.debug('Retrying deleting feature filter operation %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError(
@@ -896,7 +896,7 @@ def show_filter(cmd,
                 auth_mode="key",
                 endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -912,13 +912,13 @@ def show_filter(cmd,
     try:
         retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
     except ResourceNotFoundError:
-        raise CLIError("Feature flag '{}' with label '{}' not found.".format(feature, label))
+        raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
     except HttpResponseError as exception:
-        raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+        raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
     try:
         if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-            raise CLIError(
+            raise CLIErrors.ResourceNotFoundError(
                 "The feature flag {} does not exist.".format(feature))
 
         # we make sure that value retrieved is a valid json and only has the fields supported by backend.
@@ -962,7 +962,7 @@ def list_filter(cmd,
                 auth_mode="key",
                 endpoint=None):
     if key is None and feature is None:
-        raise RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
+        raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
         logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
 
@@ -975,13 +975,13 @@ def list_filter(cmd,
     try:
         retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
     except ResourceNotFoundError:
-        raise CLIError("Feature flag '{}' with label '{}' not found.".format(feature, label))
+        raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
     except HttpResponseError as exception:
-        raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+        raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
     try:
         if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-            raise CLIError(
+            raise CLIErrors.ResourceNotFoundError(
                 "The feature flag {} does not exist.".format(feature))
 
         # we make sure that value retrieved is a valid json and only has the fields supported by backend.
@@ -1016,13 +1016,13 @@ def __clear_filter(azconfig_client,
         try:
             retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
         except ResourceNotFoundError:
-            raise CLIError("Feature flag '{}' with label '{}' not found.".format(feature, label))
+            raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
-            raise CLIError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
 
         try:
             if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
-                raise CLIError(
+                raise CLIErrors.ResourceNotFoundError(
                     "The feature flag {} does not exist.".format(feature))
 
             # we make sure that value retrieved is a valid json and only has the fields supported by backend.
@@ -1058,7 +1058,7 @@ def __clear_filter(azconfig_client,
                 logger.debug('Retrying feature enable operation %s times with exception: concurrent setting operations', i + 1)
                 time.sleep(retry_interval)
             else:
-                raise CLIError(str(exception))
+                raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError(
@@ -1124,7 +1124,7 @@ def __list_all_keyvalues(azconfig_client,
     try:
         configsetting_iterable = azconfig_client.list_configuration_settings(key_filter=key_filter, label_filter=label)
     except HttpResponseError as exception:
-        raise CLIError('Failed to read feature flag(s) that match the specified feature and label. ' + str(exception))
+        raise CLIErrors.AzureResponseError('Failed to read feature flag(s) that match the specified feature and label. ' + str(exception))
 
     try:
         retrieved_kv = [convert_configurationsetting_to_keyvalue(x) for x in configsetting_iterable]
