@@ -42,9 +42,15 @@ def dns_client_factory(cli_ctx, api_version=None, **_):
 
 
 def providers_client_factory(cli_ctx):
-    from azure.mgmt.resource import ResourceManagementClient
+    from azure.cli.core.profiles import ResourceType
     from azure.cli.core.commands.client_factory import get_mgmt_service_client
-    return get_mgmt_service_client(cli_ctx, ResourceManagementClient).providers
+    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_RESOURCE_RESOURCES).providers
+
+
+def customlocation_client_factory(cli_ctx, api_version=None, **_):
+    from azure.cli.core.profiles import ResourceType
+    from azure.cli.core.commands.client_factory import get_mgmt_service_client
+    return get_mgmt_service_client(cli_ctx, ResourceType.MGMT_CUSTOMLOCATION, api_version=api_version)
 
 
 def cf_plans(cli_ctx, _):
