@@ -97,21 +97,37 @@ def delete_appserviceenvironment(cmd, name, resource_group_name=None, no_wait=Fa
 
 
 def update_appserviceenvironment(cmd, name, resource_group_name=None, front_end_scale_factor=None,
-                                 front_end_sku=None, allow_new_private_endpoint_connections=None, no_wait=False):
+                                 front_end_sku=None, allow_new_private_endpoint_connections=None,
+                                 allow_incoming_ftp_connections=None, allow_remote_debugging=None,
+                                 no_wait=False):
     ase_client = _get_ase_client_factory(cmd.cli_ctx)
     if resource_group_name is None:
         resource_group_name = _get_resource_group_name_from_ase(ase_client, name)
     ase_def = ase_client.get(resource_group_name, name)
     if ase_def.kind.lower() == 'asev3':
-        if allow_new_private_endpoint_connections is not None:
-            ase_networking_conf = ase_client.get_ase_v3_networking_configuration(resource_group_name, name)
+        ase_networking_conf = ase_client.get_ase_v3_networking_configuration(resource_group_name, name)
+        config_update = False
+        if front_end_scale_factor is not None or front_end_sku is not None:
+            raise ValidationError('No updates were applied. The version of ASE may not be applicable to this update.')
+        if allow_remote_debugging is not None or allow_incoming_ftp_connections is not None \
+           or allow_new_private_endpoint_connections is not None:
+            if ase_networking_conf.remote_debug_enabled != allow_remote_debugging:
+                ase_networking_conf.remote_debug_enabled = allow_remote_debugging
+                config_update = True
+            if ase_networking_conf.ftp_enabled != allow_incoming_ftp_connections:
+                ase_networking_conf.ftp_enabled = allow_incoming_ftp_connections
+                config_update = True
             if ase_networking_conf.allow_new_private_endpoint_connections != allow_new_private_endpoint_connections:
                 ase_networking_conf.allow_new_private_endpoint_connections = allow_new_private_endpoint_connections
-                return ase_client.update_ase_networking_configuration(resource_group_name=resource_group_name,
-                                                                      name=name,
-                                                                      ase_networking_configuration=ase_networking_conf)
-            return ase_networking_conf
+                config_update = True
+        if config_update:
+            return ase_client.update_ase_networking_configuration(resource_group_name=resource_group_name,
+                                                                  name=name,
+                                                                  ase_networking_configuration=ase_networking_conf)
     elif ase_def.kind.lower() == 'asev2':
+        if allow_new_private_endpoint_connections is not None or allow_incoming_ftp_connections is not None or \
+           allow_remote_debugging is not None:
+            raise ValidationError('No updates were applied. The version of ASE may not be applicable to this update.')
         if front_end_scale_factor is not None or front_end_sku is not None:
             worker_sku = _map_worker_sku(front_end_sku)
             ase_def.internal_load_balancing_mode = None  # Workaround issue with flag enums in Swagger
@@ -122,7 +138,44 @@ def update_appserviceenvironment(cmd, name, resource_group_name=None, front_end_
 
             return sdk_no_wait(no_wait, ase_client.begin_create_or_update, resource_group_name=resource_group_name,
                                name=name, hosting_environment_envelope=ase_def)
-    logger.warning('No updates were applied. The version of ASE may not be applicable to this update.')
+    raise ValidationError('No updates were applied. The version of ASE may not be applicable to this update.')
+
+
+def upgrade_appserviceenvironment(cmd, name, resource_group_name=None, no_wait=False):
+    ase_client = _get_ase_client_factory(cmd.cli_ctx)
+    if resource_group_name is None:
+        resource_group_name = _get_resource_group_name_from_ase(ase_client, name)
+    ase_def = ase_client.get(resource_group_name, name)
+    if ase_def.kind.lower() == 'asev3':
+        if ase_def.upgrade_preference == "Manual":
+            if ase_def.upgrade_availability == "Ready":
+                sdk_no_wait(no_wait, ase_client.begin_upgrade,
+                            resource_group_name=resource_group_name, name=name)
+            else:
+                raise ValidationError('An upgrade is not available for your ASEv3.')
+        else:
+            raise ValidationError('Upgrade preference in ASEv3 must be set to manual, please check \
+https://learn.microsoft.com/azure/app-service/environment/how-to-upgrade-preference for more information.')
+    else:
+        raise ValidationError('No upgrade has been applied. This version of ASE not support upgrade.')
+
+
+def send_test_notification_appserviceenvironment(cmd, name, resource_group_name=None):
+    ase_client = _get_ase_client_factory(cmd.cli_ctx)
+    if resource_group_name is None:
+        resource_group_name = _get_resource_group_name_from_ase(ase_client, name)
+    ase_def = ase_client.get(resource_group_name, name)
+    if ase_def.kind.lower() == 'asev3':
+        if ase_def.upgrade_preference == "Manual":
+            ase_client.test_upgrade_available_notification(resource_group_name=resource_group_name,
+                                                           name=name)
+            logger.info('The test notification is being processed.')
+        else:
+            raise ValidationError('Upgrade preference in ASEv3 must be set to manual, please check \
+https://learn.microsoft.com/azure/app-service/environment/how-to-upgrade-preference for more information.')
+    else:
+        raise ValidationError('The test notification has not been processed. \
+This version of ASE does not support test notification.')
 
 
 def list_appserviceenvironment_addresses(cmd, name, resource_group_name=None):
