@@ -9,6 +9,8 @@
 import json
 import unittest
 import jmespath
+from azure.cli.core.azclierror import (ResourceNotFoundError, ArgumentUsageError, InvalidArgumentValueError,
+                                       MutuallyExclusiveArgumentError)
 from azure.cli.testsdk import (ScenarioTest, ResourceGroupPreparer, JMESPathCheck, StorageAccountPreparer)
 from knack.cli import CLIError
 from knack.log import get_logger
@@ -148,10 +150,6 @@ class FunctionAppAccessRestrictionScenarioTest(ScenarioTest):
             JMESPathCheck('subnets[0].serviceEndpoints', None)
         ])
 
-        # Subnet name cannot be provided without vNet name - only when subnet refers to full subnet resource id
-        with self.assertRaisesRegexp(CLIError, "Usage error: --subnet ID | --subnet NAME --vnet-name NAME"):
-            self.cmd('functionapp config access-restriction add -g {rg} -n {app_name} --rule-name vnet-integration --action Allow --subnet endpoint-subnet --priority 150')
-
         self.cmd('functionapp config access-restriction add -g {rg} -n {app_name} --rule-name vnet-integration --action Allow --vnet-name {vnet_name} --subnet endpoint-subnet --priority 150', checks=[
             JMESPathCheck('length(@)', 2),
             JMESPathCheck('[0].name', 'vnet-integration'),
@@ -232,6 +230,7 @@ class FunctionAppAccessRestrictionScenarioTest(ScenarioTest):
             JMESPathCheck('[0].action', 'Allow')
         ])
 
+    @unittest.skip("Function app slot shouldn't use webapp")
     @ResourceGroupPreparer(parameter_name_for_location='location', location=WINDOWS_ASP_LOCATION_WEBAPP)
     @StorageAccountPreparer()
     def test_functionapp_access_restriction_slot(self, resource_group, location):
