@@ -51,10 +51,11 @@ class WebAppUpE2ETests(ScenarioTest):
             JMESPathCheck('resourceGroup', resource_group)
         ])
 
-        self.cmd('webapp config show', checks=[
-            JMESPathCheck('linuxFxVersion', 'NODE|12-lts'),
+        config = self.cmd('webapp config show', checks=[
             JMESPathCheck('tags.cli', 'None'),
-        ])
+        ]).get_output_in_json()
+
+        self.assertIn("node", config.get("linuxFxVersion", "").lower())
 
         self.cmd('webapp config appsettings list', checks=[
             JMESPathCheck('[0].name', 'SCM_DO_BUILD_DURING_DEPLOYMENT'),
@@ -137,7 +138,7 @@ class WebAppUpE2ETests(ScenarioTest):
         self.assertTrue(result['name'].startswith(webapp_name))
         self.assertTrue(result['src_path'].replace(
             os.sep + os.sep, os.sep), up_working_dir)
-        self.assertEqual(result['runtime_version'].lower(), 'node|12-lts')
+        self.assertIn("node|", result['runtime_version'].lower())
         self.assertEqual(result['os'].lower(), 'linux')
 
         # test the full E2E operation works
@@ -154,10 +155,10 @@ class WebAppUpE2ETests(ScenarioTest):
             JMESPathCheck('resourceGroup', resource_group)
         ])
 
-        self.cmd('webapp config show', checks=[
-            JMESPathCheck('linuxFxVersion', 'NODE|12-lts'),
+        config = self.cmd('webapp config show', checks=[
             JMESPathCheck('tags.cli', 'None'),
-        ])
+        ]).get_output_in_json()
+        self.assertIn("node", config.get("linuxFxVersion", "").lower())
 
         self.cmd('webapp config appsettings list', checks=[
             JMESPathCheck('[0].name', 'SCM_DO_BUILD_DURING_DEPLOYMENT'),
@@ -671,7 +672,7 @@ class WebAppUpE2ETests(ScenarioTest):
         self.assertTrue(result['name'].startswith(webapp_name))
         self.assertTrue(result['src_path'].replace(
             os.sep + os.sep, os.sep), up_working_dir)
-        self.assertEqual(result['runtime_version'].lower(), 'node|12-lts')
+        self.assertIn("node|", result['runtime_version'].lower())
         self.assertEqual(result['os'].lower(), 'linux')
 
         # test the full E2E operation works
@@ -798,17 +799,17 @@ class WebAppUpE2ETests(ScenarioTest):
 
         # test dryrun operation
         result = self.cmd(
-            'webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|12-lts" --sku "S1" --dryrun'.format(webapp_name, resource_group, plan)).get_output_in_json()
+            'webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|16-lts" --sku "S1" --dryrun'.format(webapp_name, resource_group, plan)).get_output_in_json()
         self.assertEqual(result['sku'].lower(), 'standard')
         self.assertTrue(result['name'].startswith(webapp_name))
         self.assertTrue(result['src_path'].replace(
             os.sep + os.sep, os.sep), up_working_dir)
-        self.assertEqual(result['runtime_version'].lower(), 'node|12-lts')
+        self.assertEqual(result['runtime_version'].lower(), 'node|16-lts')
         self.assertEqual(result['os'].lower(), 'linux')
 
         # test the full E2E operation works
         full_result = self.cmd(
-            'webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|12-lts" --sku "S1"'.format(webapp_name, resource_group, plan)).get_output_in_json()
+            'webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|16-lts" --sku "S1"'.format(webapp_name, resource_group, plan)).get_output_in_json()
         self.assertEqual(result['name'], full_result['name'])
 
         # Verify app is created
@@ -908,17 +909,17 @@ class WebAppUpE2ETests(ScenarioTest):
 
         # test dryrun operation
         result = self.cmd(
-            'webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|12-lts" --sku "S1" --dryrun'.format(webapp_name, resource_group, plan)).get_output_in_json()
+            'webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|16-lts" --sku "S1" --dryrun'.format(webapp_name, resource_group, plan)).get_output_in_json()
         self.assertEqual(result['sku'].lower(), 'standard')
         self.assertTrue(result['name'].startswith(webapp_name))
         self.assertTrue(result['src_path'].replace(
             os.sep + os.sep, os.sep), up_working_dir)
-        self.assertEqual(result['runtime_version'].lower(), 'node|12-lts')
+        self.assertEqual(result['runtime_version'].lower(), 'node|16-lts')
         self.assertEqual(result['os'].lower(), 'linux')
 
         # test the full E2E operation works
         full_result = self.cmd(
-            'webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|12-lts" --sku "S1"'.format(webapp_name, resource_group, plan)).get_output_in_json()
+            'webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|16-lts" --sku "S1"'.format(webapp_name, resource_group, plan)).get_output_in_json()
         self.assertEqual(result['name'], full_result['name'])
 
         # Verify app is created
@@ -933,7 +934,7 @@ class WebAppUpE2ETests(ScenarioTest):
         from azure.cli.core.util import CLIError
         # changing existing linux app to windows should fail gracefully
         with self.assertRaises(CLIError):
-            self.cmd('webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|12LTS" --sku "S1"'.format(webapp_name, resource_group, plan))
+            self.cmd('webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|16LTS" --sku "S1"'.format(webapp_name, resource_group, plan))
 
         # cleanup
         # switch back the working dir
@@ -965,17 +966,17 @@ class WebAppUpE2ETests(ScenarioTest):
 
         # test dryrun operation
         result = self.cmd(
-            'webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|12LTS" --sku "S1" --dryrun'.format(webapp_name, resource_group, plan)).get_output_in_json()
+            'webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|16LTS" --sku "S1" --dryrun'.format(webapp_name, resource_group, plan)).get_output_in_json()
         self.assertEqual(result['sku'].lower(), 'standard')
         self.assertTrue(result['name'].startswith(webapp_name))
         self.assertTrue(result['src_path'].replace(
             os.sep + os.sep, os.sep), up_working_dir)
-        self.assertEqual(result['runtime_version'].lower(), 'node|12lts')
+        self.assertEqual(result['runtime_version'].lower(), 'node|16lts')
         self.assertEqual(result['os'].lower(), 'windows')
 
         # test the full E2E operation works
         full_result = self.cmd(
-            'webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|12LTS" --sku "S1"'.format(webapp_name, resource_group, plan)).get_output_in_json()
+            'webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|16LTS" --sku "S1"'.format(webapp_name, resource_group, plan)).get_output_in_json()
         self.assertEqual(result['name'], full_result['name'])
 
         # Verify app is created
@@ -990,7 +991,7 @@ class WebAppUpE2ETests(ScenarioTest):
         from azure.cli.core.util import CLIError
         # changing existing linux app to windows should fail gracefully
         with self.assertRaises(CLIError):
-            self.cmd('webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|12-LTS" --sku "S1"'.format(webapp_name, resource_group, plan))
+            self.cmd('webapp up -n {} -g {} --plan {} --os "linux" --runtime "node|16-LTS" --sku "S1"'.format(webapp_name, resource_group, plan))
 
         # cleanup
         # switch back the working dir
@@ -1019,7 +1020,7 @@ class WebAppUpE2ETests(ScenarioTest):
         os.chdir(temp_dir)
 
         # test the full E2E operation works
-        self.cmd('webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|12-LTS"'.format(webapp_name, resource_group, plan))
+        self.cmd('webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|14-LTS"'.format(webapp_name, resource_group, plan))
 
         # Verify app is created
         # since we set local context, -n and -g are no longer required
@@ -1033,7 +1034,7 @@ class WebAppUpE2ETests(ScenarioTest):
         app_settings = self.cmd('webapp config appsettings list').get_output_in_json()
         app_settings = {s["name"] : s["value"] for s in app_settings}
         self.assertIn("WEBSITE_NODE_DEFAULT_VERSION", app_settings)
-        self.assertIn("12", app_settings["WEBSITE_NODE_DEFAULT_VERSION"].lower())
+        self.assertIn("14", app_settings["WEBSITE_NODE_DEFAULT_VERSION"].lower())
 
         # test changing runtime to newer version
         self.cmd('webapp up -n {} -g {} --plan {} --os "windows" --runtime "node|16-lts"'.format(webapp_name, resource_group, plan))
@@ -1075,7 +1076,7 @@ class WebAppUpE2ETests(ScenarioTest):
         self.assertEqual(result['sku'].lower(), 'premiumv2')
         self.assertTrue(result['src_path'].replace(
             os.sep + os.sep, os.sep), up_working_dir)
-        self.assertEqual(result['runtime_version'].lower(), 'node|12-lts')
+        self.assertEqual(result['runtime_version'].lower(), 'node|14-lts')
         self.assertEqual(result['os'].lower(), 'linux')
 
         # test the full E2E operation works
@@ -1091,7 +1092,7 @@ class WebAppUpE2ETests(ScenarioTest):
         ])
 
         self.cmd('webapp config show', checks=[
-            JMESPathCheck('linuxFxVersion', 'NODE|12-lts'),
+            JMESPathCheck('linuxFxVersion', 'NODE|14-lts'),
             JMESPathCheck('tags.cli', 'None'),
         ])
 
@@ -1143,7 +1144,7 @@ class WebAppUpE2ETests(ScenarioTest):
         self.assertTrue(result['name'].startswith(linux_webapp_name))
         self.assertTrue(result['src_path'].replace(
             os.sep + os.sep, os.sep), up_working_dir)
-        self.assertEqual(result['runtime_version'].lower(), 'node|12-lts')
+        self.assertEqual(result['runtime_version'].lower(), 'node|14-lts')
         self.assertEqual(result['os'].lower(), 'linux')
 
         # test the full linux E2E operation works
@@ -1161,7 +1162,7 @@ class WebAppUpE2ETests(ScenarioTest):
         ])
 
         self.cmd('webapp config show', checks=[
-            JMESPathCheck('linuxFxVersion', 'NODE|12-lts'),
+            JMESPathCheck('linuxFxVersion', 'NODE|14-lts'),
             JMESPathCheck('tags.cli', 'None'),
         ])
 
