@@ -8,7 +8,7 @@ import os
 from datetime import datetime, timedelta
 
 from azure.cli.testsdk import CliTestError, ResourceGroupPreparer
-from azure.cli.testsdk.preparers import AbstractPreparer, SingleValueReplacer
+from azure.cli.testsdk.preparers import AbstractPreparer, SingleValueReplacer, KeyVaultPreparer
 from azure.cli.testsdk.base import execute
 # pylint: disable=line-too-long
 
@@ -304,6 +304,86 @@ class RPPreparer(AbstractPreparer, SingleValueReplacer):
             raise CliTestError(template.format(ItemPreparer.__name__, self.vm_parameter_name))
 
 
+class KeyPreparer(AbstractPreparer, SingleValueReplacer):
+    def __init__(self, name_prefix='clitest-key', parameter_name='key_url', keyvault_parameter_name='key_vault',
+                 dev_setting_name='AZURE_CLI_TEST_DEV_BACKUP_KEY_NAME'):
+        super(KeyPreparer, self).__init__(name_prefix, 24)
+        from azure.cli.core.mock import DummyCli
+        self.cli_ctx = DummyCli()
+        self.parameter_name = parameter_name
+        self.key_vault = keyvault_parameter_name
+        self.dev_setting_value = os.environ.get(dev_setting_name, None)
+    
+    def create_resource(self, name, **kwargs):
+        if not self.dev_setting_value:
+            keyvault = self._get_keyvault(**kwargs)
+
+            command_string = 'az keyvault key create --vault-name {} -n {}'
+            command_string = command_string.format(keyvault, name)
+            key_job = execute(self.cli_ctx, command_string).get_output_in_json()
+            return {self.parameter_name: key_job["key"]["kid"]}
+        return {self.parameter_name: self.dev_setting_value}
+    
+    def remove_resource(self, name, **kwargs):
+        # Keyvault deletion will take care of this.
+        pass
+
+    def _get_keyvault(self, **kwargs):
+        try:
+            return kwargs.get(self.key_vault)
+        except KeyError:
+            template = 'To create a Key, a keyvault is required. Please add ' \
+                        'decorator @{}} in front of this Key Preparer.'
+            raise CliTestError(template.format(KeyVaultPreparer.__name__,
+                                                self.keyvault_parameter_name))
+    
+
+class DESPreparer(AbstractPreparer, SingleValueReplacer):
+    def __init__(self, name_prefix='clitest-des', parameter_name='des_name', key_parameter_name='key_url',
+                 resource_group_parameter_name='resource_group', dev_setting_name='AZURE_CLI_TEST_DEV_BACKUP_DES_NAME'):
+        super(DESPreparer, self).__init__(name_prefix, 24)
+        from azure.cli.core.mock import DummyCli
+        self.cli_ctx = DummyCli()
+        self.resource_group = None
+        self.parameter_name = parameter_name
+        self.key_url = key_parameter_name
+        self.resource_group_parameter_name = resource_group_parameter_name
+        self.dev_setting_value = os.environ.get(dev_setting_name, None)
+
+    def create_resource(self, name, **kwargs):
+        if not self.dev_setting_value:
+            self.resource_group = self._get_resource_group(**kwargs)
+            key_url = self._get_key_url(**kwargs)
+
+            command_string = 'az disk-encryption-set create -g {} -n {} --key-url {}'
+            command_string = command_string.format(self.resource_group, name, key_url)
+            execute(self.cli_ctx, command_string)
+            return {self.parameter_name: name}
+        return {self.parameter_name: self.dev_setting_value}
+
+    def remove_resource(self, name, **kwargs):
+        # Resource group deletion will take care of this.
+        pass
+
+    def _get_resource_group(self, **kwargs):
+        try:
+            return kwargs.get(self.resource_group_parameter_name)
+        except KeyError:
+            template = 'To create a Disk encryption set, a resource group is required. Please add ' \
+                       'decorator @{} in front of this DES preparer.'
+            raise CliTestError(template.format(ResourceGroupPreparer.__name__,
+                                               self.resource_group_parameter_name))
+
+    def _get_key_url(self, **kwargs):
+        try:
+            return kwargs.get(self.key_url)
+        except KeyError:
+            template = 'To create a Disk Encryption Set, a key is required. Please add ' \
+                        'decorator @{}} in front of this DES Preparer.'
+            raise CliTestError(template.format(KeyPreparer.__name__,
+                                               self.key_url))
+
+
 class AFSPolicyPreparer(AbstractPreparer, SingleValueReplacer):
     def __init__(self, name_prefix='clitest-item', parameter_name='policy_name', vault_parameter_name='vault_name',
                  resource_group_parameter_name='resource_group',
