@@ -24,9 +24,9 @@ vault_name = "sarath-vault"
 
 class BackupTests(ScenarioTest, unittest.TestCase):
     #@record_only()
-    @ResourceGroupPreparer(location="southeastasia", random_name_length=20)
+    @ResourceGroupPreparer(location="eastasia", random_name_length=20)
     @VaultPreparer()
-    @StorageAccountPreparer(location="southeastasia")
+    @StorageAccountPreparer(location="eastasia")
     @FileSharePreparer()
     @AFSPolicyPreparer()
     def test_afs_backup_scenario(self, resource_group, vault_name, storage_account, afs_name, policy_name):
@@ -57,13 +57,13 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         time.sleep(100)
 
     #@record_only()
-    @ResourceGroupPreparer(location="southeastasia", random_name_length=20)
+    @ResourceGroupPreparer(location="eastasia", random_name_length=20)
     @VaultPreparer()
-    @StorageAccountPreparer(location="southeastasia")
+    @StorageAccountPreparer(location="eastasia")
     @FileSharePreparer()
     @AFSPolicyPreparer()
     @AFSItemPreparer()
-    @StorageAccountPreparer(location="southeastasia", parameter_name="sa2")
+    @StorageAccountPreparer(location="eastasia", parameter_name="sa2")
     @FileSharePreparer(storage_account_parameter_name="sa2", parameter_name="afs2")
     @AFSItemPreparer(afs_parameter_name="afs2", storage_account_parameter_name="sa2")
     def test_afs_backup_container(self, resource_group, vault_name, storage_account, sa2, afs_name, afs2):
@@ -105,9 +105,9 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         time.sleep(100)
 
     #@record_only()
-    @ResourceGroupPreparer(location="southeastasia", random_name_length=20)
+    @ResourceGroupPreparer(location="eastasia", random_name_length=20)
     @VaultPreparer()
-    @StorageAccountPreparer(location="southeastasia")
+    @StorageAccountPreparer(location="eastasia")
     @FileSharePreparer()
     @FileSharePreparer(parameter_name="afs2")
     @AFSPolicyPreparer()
@@ -173,9 +173,9 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         time.sleep(100)
 
     #@record_only()
-    @ResourceGroupPreparer(location="southeastasia", random_name_length=20)
+    @ResourceGroupPreparer(location="eastasia", random_name_length=20)
     @VaultPreparer()
-    @StorageAccountPreparer(location="southeastasia")
+    @StorageAccountPreparer(location="eastasia")
     @FileSharePreparer()
     @AFSPolicyPreparer()
     @AFSItemPreparer()
@@ -214,9 +214,9 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         time.sleep(100)
 
     #@record_only()
-    @ResourceGroupPreparer(location="southeastasia", random_name_length=20)
+    @ResourceGroupPreparer(location="eastasia", random_name_length=20)
     @VaultPreparer()
-    @StorageAccountPreparer(location="southeastasia")
+    @StorageAccountPreparer(location="eastasia")
     @FilePreparer()
     @FilePreparer()
     @FilePreparer(parameter_name="file2")
@@ -335,9 +335,9 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         time.sleep(100)
 
     #@record_only()
-    @ResourceGroupPreparer(location="southeastasia", random_name_length=20)
+    @ResourceGroupPreparer(location="eastasia", random_name_length=20)
     @VaultPreparer()
-    @StorageAccountPreparer(location="southeastasia")
+    @StorageAccountPreparer(location="eastasia")
     @FileSharePreparer()
     @AFSPolicyPreparer()
     def test_afs_backup_protection(self, resource_group, vault_name, storage_account, afs_name, policy_name):
@@ -388,9 +388,9 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         time.sleep(100)
 
     #@record_only()
-    @ResourceGroupPreparer(location="southeastasia", random_name_length=20)
+    @ResourceGroupPreparer(location="eastasia", random_name_length=20)
     @VaultPreparer()
-    @StorageAccountPreparer(location="southeastasia")
+    @StorageAccountPreparer(location="eastasia")
     @FileSharePreparer()
     @AFSPolicyPreparer()
     @AFSItemPreparer()
@@ -445,9 +445,9 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         time.sleep(100)
 
     #@record_only()
-    @ResourceGroupPreparer(location="southeastasia", random_name_length=20)
+    @ResourceGroupPreparer(location="eastasia", random_name_length=20)
     @VaultPreparer()
-    @StorageAccountPreparer(location="southeastasia")
+    @StorageAccountPreparer(location="eastasia")
     @FileSharePreparer()
     @AFSPolicyPreparer()
     @AFSItemPreparer()
