@@ -12,7 +12,7 @@ from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer, StorageAccoun
 from unittest import mock
 
 from azure.cli.testsdk import JMESPathCheck, JMESPathCheckExists, StringContainCheck
-from azure_devtools.scenario_tests import AllowLargeResponse
+from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 
 NODE_STARTUP_TIME = 10 * 60  # Compute node should start in 10 mins after cluster creation.
 CLUSTER_RESIZE_TIME = 20 * 60  # Cluster should resize in 20 mins after job submitted/completed.
