@@ -17,10 +17,8 @@ import requests
 from azure.cli.command_modules.botservice.custom import prepare_webapp_deploy
 from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer, LiveScenarioTest, live_only
 from azure.cli.testsdk.decorators import serial_test
-from azure.mgmt.botservice.models import ErrorException
 from knack.util import CLIError
 
-
 class DirectLineClient(object):
     """Shared methods for the parsed result objects."""
 
@@ -107,8 +105,8 @@ class BotTests(ScenarioTest):
         })
 
         self.cmd(
-            'az bot create -k registration -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} -p '
-            '{password} --tags key1=value1',
+            'az bot create -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} --app-type MultiTenant'
+            ' --tags key1=value1',
             checks=[
                 self.check('name', '{botname}'),
                 self.check('properties.description', '{description}'),
@@ -142,8 +140,8 @@ class BotTests(ScenarioTest):
             })
 
             self.cmd(
-                'az bot create -k registration -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} -p '
-                '{password} --tags key1=value1 -l {location}',
+                'az bot create -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} --app-type MultiTenant'
+                ' --tags key1=value1 -l {location}',
                 checks=[
                     self.check('name', '{botname}'),
                     self.check('properties.description', '{description}'),
@@ -163,6 +161,123 @@ class BotTests(ScenarioTest):
 
             self.cmd('az bot delete -g {rg} -n {botname}')
 
+    @ResourceGroupPreparer(random_name_length=20)
+    def test_botservice_registration_bot_create_singletenant_type(self, resource_group):
+        locations = ['global', 'westus', 'westeurope']
+        for location in locations:
+            self.kwargs.update({
+                'botname': self.create_random_name(prefix='cli', length=10),
+                'description': 'description1',
+                'endpoint': 'https://www.google.com/api/messages',
+                'location': location,
+                'app_id': str(uuid.uuid4()),
+                'app_type': 'SingleTenant',
+                'tenant_id': '54826b22-38d6-4fb2-bad9-b7b93a3e9c5a'
+            })
+
+            self.cmd(
+                'az bot create -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} --app-type {app_type}'
+                ' --tenant-id {tenant_id} --tags key1=value1 -l {location}',
+                checks=[
+                    self.check('name', '{botname}'),
+                    self.check('properties.description', '{description}'),
+                    self.check('resourceGroup', '{rg}'),
+                    self.check('location', '{location}'),
+                    self.check('properties.msaAppTenantId', '{tenant_id}'),
+                    self.check('properties.msaAppType', '{app_type}'),
+                    self.check('tags.key1', 'value1')
+                ])
+
+            self.cmd('az bot show -g {rg} -n {botname}', checks=[
+                self.check('name', '{botname}')
+            ])
+
+            self.cmd('az bot update --description description2 -g {rg} -n {botname}', checks=[
+                self.check('name', '{botname}'),
+                self.check('properties.description', 'description2')
+            ])
+
+            self.cmd('az bot delete -g {rg} -n {botname}')
+
+    @ResourceGroupPreparer(random_name_length=20)
+    def test_botservice_registration_bot_create_multitenant_type(self, resource_group):
+        locations = ['global', 'westus', 'westeurope']
+        for location in locations:
+            self.kwargs.update({
+                'botname': self.create_random_name(prefix='cli', length=10),
+                'description': 'description1',
+                'endpoint': 'https://www.google.com/api/messages',
+                'location': location,
+                'app_id': str(uuid.uuid4()),
+                'app_type': 'MultiTenant'
+            })
+
+            self.cmd(
+                'az bot create -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} --app-type {app_type}'
+                ' --tags key1=value1 -l {location}',
+                checks=[
+                    self.check('name', '{botname}'),
+                    self.check('properties.description', '{description}'),
+                    self.check('resourceGroup', '{rg}'),
+                    self.check('location', '{location}'),
+                    self.check('properties.msaAppType', '{app_type}'),
+                    self.check('tags.key1', 'value1')
+                ])
+
+            self.cmd('az bot show -g {rg} -n {botname}', checks=[
+                self.check('name', '{botname}')
+            ])
+
+            self.cmd('az bot update --description description2 -g {rg} -n {botname}', checks=[
+                self.check('name', '{botname}'),
+                self.check('properties.description', 'description2')
+            ])
+
+            self.cmd('az bot delete -g {rg} -n {botname}')
+
+    @ResourceGroupPreparer(random_name_length=20)
+    def test_botservice_registration_bot_create_userassignedmsi_type(self, resource_group):
+        locations = ['global', 'westus', 'westeurope']
+        for location in locations:
+            self.kwargs.update({
+                'botname': self.create_random_name(prefix='cli', length=10),
+                'description': 'description1',
+                'endpoint': 'https://www.google.com/api/messages',
+                'location': location,
+                'app_id': str(uuid.uuid4()),
+                'app_type': 'UserAssignedMSI',
+                'tenant_id': '54826b22-38d6-4fb2-bad9-b7b93a3e9c5a',
+                'msi': 'botCreateCliTestMsi'
+            })
+            msi_result = self.cmd('identity create -g {rg} -n {msi} --tags tag1=d1', checks=[
+                self.check('name', '{msi}')]).get_output_in_json()
+            self.kwargs['fullQualifiedMsi'] = msi_result['id']
+
+            self.cmd(
+                'az bot create -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} --app-type {app_type}'
+                ' --tenant-id {tenant_id} --msi-resource-id {fullQualifiedMsi} --tags key1=value1 -l {location}',
+                checks=[
+                    self.check('name', '{botname}'),
+                    self.check('properties.description', '{description}'),
+                    self.check('resourceGroup', '{rg}'),
+                    self.check('location', '{location}'),
+                    self.check('properties.msaAppTenantId', '{tenant_id}'),
+                    self.check('properties.msaAppType', '{app_type}'),
+                    self.check('properties.msaAppMsiResourceId', '{fullQualifiedMsi}'),
+                    self.check('tags.key1', 'value1')
+                ])
+
+            self.cmd('az bot show -g {rg} -n {botname}', checks=[
+                self.check('name', '{botname}')
+            ])
+
+            self.cmd('az bot update --description description2 -g {rg} -n {botname}', checks=[
+                self.check('name', '{botname}'),
+                self.check('properties.description', 'description2')
+            ])
+
+            self.cmd('az bot delete -g {rg} -n {botname}')
+
     @ResourceGroupPreparer(random_name_length=20)
     def test_botservice_create_should_be_idempotent_and_return_existing_bot_info(self, resource_group):
         self.kwargs.update({
@@ -174,8 +289,8 @@ class BotTests(ScenarioTest):
         })
 
         self.cmd(
-            'az bot create -k registration -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} -p '
-            '{password} --tags key1=value1',
+            'az bot create -g {rg} -n {botname} -d {description} -e {endpoint} --app-type MultiTenant --appid {app_id} '
+            '--tags key1=value1',
             checks=[
                 self.check('name', '{botname}'),
                 self.check('properties.description', '{description}'),
@@ -185,8 +300,8 @@ class BotTests(ScenarioTest):
             ])
 
         self.cmd(
-            'az bot create -k registration -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} -p '
-            '{password} --tags key1=value1',
+            'az bot create -g {rg} -n {botname} -d {description} -e {endpoint} --app-type MultiTenant --appid {app_id} '
+            '--tags key1=value1',
             checks=[
                 self.check('name', '{botname}'),
                 self.check('properties.description', '{description}'),
@@ -215,29 +330,16 @@ class BotTests(ScenarioTest):
             shutil.rmtree(dir_path)
 
         self.cmd(
-            'az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Csharp --echo',
+            'az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant',
             checks=[
                 self.check('resourceGroup', '{rg}'),
-                self.check('id', '{botname}'),
-                self.check('type', 'abs')
+                self.check('name', '{botname}'),
+                self.check('type', 'Microsoft.BotService/botServices')
             ])
 
         # Talk to bot
         self.__talk_to_bot('hi', 'You sent \'hi\'')
 
-        # Download the bot source
-        self.cmd('az bot download -g {rg} -n {botname}', checks=[
-            self.exists('downloadPath')
-        ])
-        self.check(os.path.isdir(os.path.join('dir_path', 'postDeployScripts')), True)
-
-        # Publish it back
-        self.cmd('az bot publish -g {rg} -n {botname} --code-dir {botname}', checks=[
-            self.check('active', True)
-        ])
-        # Clean up the folder
-        shutil.rmtree(dir_path)
-
         # Delete bot
         self.cmd('az bot delete -g {rg} -n {botname}')
 
@@ -259,26 +361,13 @@ class BotTests(ScenarioTest):
             # clean up the folder
             shutil.rmtree(dir_path)
 
-        self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Javascript --echo',
+        self.cmd('az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant',
                  checks={
                      self.check('resourceGroup', '{rg}'),
-                     self.check('id', '{botname}'),
-                     self.check('type', 'abs')
+                     self.check('name', '{botname}'),
+                     self.check('type', 'Microsoft.BotService/botServices')
                  })
 
-        # Download the bot source
-        self.cmd('az bot download -g {rg} -n {botname}', checks=[
-            self.exists('downloadPath')
-        ])
-        self.check(os.path.isdir(os.path.join('dir_path', 'postDeployScripts')), True)
-
-        # Publish it back
-        self.cmd('az bot publish -g {rg} -n {botname} --code-dir {botname}', checks=[
-            self.check('active', True)
-        ])
-        # Clean up the folder
-        shutil.rmtree(dir_path)
-
         # Delete bot
         self.cmd('az bot delete -g {rg} -n {botname}')
 
@@ -290,88 +379,7 @@ class BotTests(ScenarioTest):
             'password': str(uuid.uuid4())
         })
         self.cmd(
-            'az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Javascript')
-
-    @ResourceGroupPreparer(random_name_length=20)
-    @live_only()  # if the path to download already exist the tests fail as by design which makes this not idempotent
-    def test_botservice_download_should_create_appsettings_for_v4_csharp_webapp_echo_bots_no_bot_file(self,
-                                                                                                      resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=15),
-            'app_id': str(uuid.uuid4()),
-            'password': str(uuid.uuid4())
-        })
-
-        # Delete the bot if already exists
-        self.cmd('az bot delete -g {rg} -n {botname}')
-
-        dir_path = os.path.join('.', self.kwargs.get('botname'))
-        if os.path.exists(dir_path):
-            # clean up the folder
-            shutil.rmtree(dir_path)
-
-        results = self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Csharp '
-                           '--echo',
-                           checks={
-                               self.check('resourceGroup', '{rg}'),
-                               self.check('id', '{botname}'),
-                               self.check('type', 'abs')
-                           })
-
-        bot_name = results.get_output_in_json()['name']
-
-        results = self.cmd('az bot download -g {rg} -n {botname}', checks={self.exists('downloadPath')})
-        results = results.get_output_in_json()
-
-        assert os.path.exists(os.path.join(results['downloadPath'], 'appsettings.json'))
-        assert not os.path.exists(os.path.join(results['downloadPath'], '{0}.bot'.format(bot_name)))
-        with open(os.path.join(results['downloadPath'], 'appsettings.json')) as settings:
-            appsettings = json.load(settings)
-            assert appsettings['MicrosoftAppId']
-            assert appsettings['MicrosoftAppPassword']
-
-        if os.path.exists(dir_path):
-            # clean up the folder
-            shutil.rmtree(dir_path)
-
-    @ResourceGroupPreparer(random_name_length=20)
-    @live_only()
-    def test_botservice_download_should_create_env_file_for_v4_node_webapp_echo_bots_no_bot_file(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=15),
-            'app_id': str(uuid.uuid4()),
-            'password': str(uuid.uuid4())
-        })
-
-        # Delete the bot if already exists
-        self.cmd('az bot delete -g {rg} -n {botname}')
-
-        dir_path = os.path.join('.', self.kwargs.get('botname'))
-        if os.path.exists(dir_path):
-            # clean up the folder
-            shutil.rmtree(dir_path)
-
-        self.cmd(
-            'az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Javascript --echo',
-            checks={
-                self.check('resourceGroup', '{rg}'),
-                self.check('id', '{botname}'),
-                self.check('type', 'abs')
-            })
-
-        results = self.cmd('az bot download -g {rg} -n {botname}', checks={self.exists('downloadPath')})
-        results = results.get_output_in_json()
-
-        assert os.path.exists(os.path.join(results['downloadPath'], '.env'))
-        with open(os.path.join(results['downloadPath'], '.env')) as settings:
-            env = [env_var.split('=') for env_var in settings.read().split('\n')]
-            env = {env[0][0]: env[0][1], env[1][0]: env[1][0]}
-            assert env['MicrosoftAppId']
-            assert env['MicrosoftAppPassword']
-
-        if os.path.exists(dir_path):
-            # clean up the folder
-            shutil.rmtree(dir_path)
+            'az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant')
 
     @ResourceGroupPreparer(random_name_length=20)
     @serial_test()
@@ -391,28 +399,16 @@ class BotTests(ScenarioTest):
             # clean up the folder
             shutil.rmtree(dir_path)
 
-        self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Javascript --echo',
+        self.cmd('az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant',
                  checks={
                      self.check('resourceGroup', '{rg}'),
-                     self.check('id', '{botname}'),
-                     self.check('type', 'abs')
+                     self.check('name', '{botname}'),
+                     self.check('type', 'Microsoft.BotService/botServices')
                  })
 
         # Talk to bot
         self.__talk_to_bot('hi', 'You sent \'hi\'')
 
-        # Download the bot source
-        self.cmd('az bot download -g {rg} -n {botname}', checks=[
-            self.exists('downloadPath')
-        ])
-
-        # Publish it back
-        self.cmd('az bot publish -g {rg} -n {botname} --code-dir {botname} --keep-node-modules', checks=[
-            self.check('active', True)
-        ])
-        # Clean up the folder
-        shutil.rmtree(dir_path)
-
     @ResourceGroupPreparer(random_name_length=20)
     def test_botservice_create_should_create_registration_bot_without_endpoint(self, resource_group):
         self.kwargs.update({
@@ -423,216 +419,7 @@ class BotTests(ScenarioTest):
         # Delete the bot if already exists
         self.cmd('az bot delete -g {rg} -n {botname}')
 
-        self.cmd('az bot create -k registration -g {rg} -n {botname} --appid {app_id}')
-
-    @ResourceGroupPreparer(random_name_length=20)
-    def test_create_v4_webapp_bot_should_succeed_with_ending_hyphen(self, resource_group):
-        bot_name = self.create_random_name(prefix='cli', length=15) + '-'
-        valid_app_name = bot_name[:-1]
-        self.kwargs.update({
-            'valid_app_name': valid_app_name,
-            'botname': bot_name,
-            'app_id': str(uuid.uuid4()),
-            'password': str(uuid.uuid4())
-        })
-
-        # Delete the bot if already exists
-        self.cmd('az bot delete -g {rg} -n {botname}')
-
-        dir_path = os.path.join('.', self.kwargs.get('botname'))
-
-        if os.path.exists(dir_path):
-            # Clean up the folder
-            shutil.rmtree(dir_path)
-
-        self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Csharp',
-                 checks=[
-                     self.check('resourceGroup', '{rg}'),
-                     self.check('id', '{botname}'),
-                     self.check('type', 'abs'),
-                     self.check('endpoint', 'https://{valid_app_name}.azurewebsites.net/api/messages')
-                 ])
-
-    @ResourceGroupPreparer(random_name_length=20)
-    def test_botservice_show_on_v4_js_webapp_bot(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=15),
-            'app_id': str(uuid.uuid4()),
-            'password': str(uuid.uuid4())
-        })
-
-        # Delete the bot if already exists
-        self.cmd('az bot delete -g {rg} -n {botname}')
-
-        dir_path = os.path.join('.', self.kwargs.get('botname'))
-        if os.path.exists(dir_path):
-            # clean up the folder
-            shutil.rmtree(dir_path)
-
-        self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Javascript',
-                 checks={
-                     self.check('resourceGroup', '{rg}'),
-                     self.check('id', '{botname}'),
-                     self.check('type', 'abs')
-                 })
-
-        self.cmd('az bot show -g {rg} -n {botname} --msbot', checks=[
-            self.exists('appPassword'),
-            self.check('id', '{botname}'),
-            self.check('resourceGroup', '{rg}'),
-            self.check('type', 'abs')
-        ])
-
-    @ResourceGroupPreparer(random_name_length=20)
-    def test_botservice_show_on_v4_csharp_webapp_bot(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=15),
-            'app_id': str(uuid.uuid4()),
-            'password': str(uuid.uuid4())
-        })
-
-        # Delete the bot if already exists
-        self.cmd('az bot delete -g {rg} -n {botname}')
-
-        dir_path = os.path.join('.', self.kwargs.get('botname'))
-        if os.path.exists(dir_path):
-            # clean up the folder
-            shutil.rmtree(dir_path)
-
-        self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Csharp',
-                 checks={
-                     self.check('resourceGroup', '{rg}'),
-                     self.check('id', '{botname}'),
-                     self.check('type', 'abs')
-                 })
-
-        self.cmd('az bot show -g {rg} -n {botname} --msbot', checks=[
-            self.exists('appPassword'),
-            self.check('id', '{botname}'),
-            self.check('resourceGroup', '{rg}'),
-            self.check('type', 'abs')
-        ])
-
-    @ResourceGroupPreparer(random_name_length=20)
-    @serial_test()
-    def test_botservice_publish_remove_node_iis_files_if_not_already_local(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=15),
-            'app_id': str(uuid.uuid4()),
-            'password': str(uuid.uuid4())
-        })
-
-        dir_path = os.path.join('.', self.kwargs.get('botname'))
-        if os.path.exists(dir_path):
-            # clean up the folder
-            shutil.rmtree(dir_path)
-
-        self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Javascript --echo',
-                 checks={
-                     self.check('resourceGroup', '{rg}'),
-                     self.check('id', '{botname}'),
-                     self.check('type', 'abs')
-                 })
-
-        # Download the bot source
-        self.cmd('az bot download -g {rg} -n {botname}', checks=[
-            self.exists('downloadPath')
-        ])
-        self.check(os.path.isdir(os.path.join('dir_path', 'postDeployScripts')), True)
-        # Remove the IIS for Node.js files and PostDeployScripts folder
-        shutil.rmtree(os.path.join(dir_path, 'PostDeployScripts'))
-        os.remove(os.path.join(dir_path, 'web.config'))
-        os.remove(os.path.join(dir_path, 'iisnode.yml'))
-        # Publish it back
-        self.cmd('az bot publish -g {rg} -n {botname} --code-dir {botname}', checks=[
-            self.check('active', True)
-        ])
-
-        # Publish should not have left web.config and iisnode.yml files since they did not previously exist in code_dir
-        self.check(os.path.exists(os.path.join(dir_path, 'web.config')), False)
-        self.check(os.path.exists(os.path.join(dir_path, 'iisnode.yml')), False)
-
-        # Clean up the folder
-        shutil.rmtree(dir_path)
-
-    @ResourceGroupPreparer(random_name_length=20)
-    def test_prepare_publish_with_registration_bot_should_raise_error(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=10),
-            'description': 'description1',
-            'endpoint': 'https://www.google.com/api/messages',
-            'app_id': str(uuid.uuid4()),
-            'password': str(uuid.uuid4())
-        })
-
-        self.cmd(
-            'az bot create -k registration -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} -p {password} --tags '
-            'key1=value1',
-            checks=[
-                self.check('name', '{botname}'),
-                self.check('properties.description', '{description}'),
-                self.check('resourceGroup', '{rg}'),
-                self.check('location', 'global'),
-                self.check('tags.key1', 'value1')
-            ])
-
-        self.cmd('az bot show -g {rg} -n {botname}', checks=[
-            self.check('name', '{botname}')
-        ])
-
-        try:
-            self.cmd('az bot prepare-publish -g {rg} -n {botname} --sln-name invalid.sln --proj-name invalid.csproj '
-                     '--code-dir .')
-            raise AssertionError('should have thrown an error.')
-        except CLIError:
-            pass
-        except AssertionError:
-            raise AssertionError('should have thrown an error for registration-type bot.')
-
-    @ResourceGroupPreparer(random_name_length=20)
-    def test_prepare_publish_with_unregistered_bot_name_should_fail(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=10),
-        })
-
-        try:
-            self.cmd('az bot prepare-publish -g {rg} -n {botname} --sln-name invalid.sln --proj-name invalid.csproj '
-                     '--code-dir .')
-            raise AssertionError('should have thrown an error.')
-        except ErrorException:
-            # We are expecting an ErrorException which is thrown from azure.mgmt.botservice SDK.
-            pass
-        except AssertionError:
-            raise AssertionError('should have thrown an error for an unregistered bot.')
-        except Exception as error:
-            raise error
-
-    @ResourceGroupPreparer(random_name_length=20)
-    def test_prepare_publish_should_raise_cli_error_when_version_is_v4(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=15),
-            'sln_name': 'invalid.sln',
-            'proj_name': 'invalid.csproj',
-            'version': 'v4'
-        })
-
-        # Delete the bot if already exists
-        self.cmd('az bot delete -g {rg} -n {botname}')
-
-        dir_path = os.path.join('.', self.kwargs.get('botname'))
-        if os.path.exists(dir_path):
-            # Clean up the folder
-            shutil.rmtree(dir_path)
-
-        try:
-            self.cmd('az bot prepare-publish -g {rg} -n {botname} --sln-name {sln_name} --proj-name {proj_name} -v v4')
-            raise Exception("'az bot prepare-publish' should have failed with a --version argument of 'v4'")
-        except CLIError as cli_error:
-            assert cli_error.__str__() == "'az bot prepare-publish' is only for v3 bots. Please use 'az bot publish' " \
-                                          "to prepare and publish a v4 bot."
-
-        except Exception as error:
-            raise error
+        self.cmd('az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant')
 
     @ResourceGroupPreparer(random_name_length=20)
     def test_botservice_update_should_update_bot_properties(self, resource_group):
@@ -651,7 +438,7 @@ class BotTests(ScenarioTest):
 
         self.cmd('az bot delete -g {rg} -n {botname}')
 
-        self.cmd('az bot create -k registration -g {rg} -n {botname} --appid {app_id}',
+        self.cmd('az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant',
                  checks={
                      self.check('resourceGroup', '{rg}'),
                      self.check('id', '{botname}'),
@@ -691,8 +478,7 @@ class BotTests(ScenarioTest):
                          "for more information on App Registrations. See 'az bot create --help' for more CLI " \
                          "information."
         try:
-            self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {numbers_id} -p {password} --lang '
-                     'Javascript --echo')
+            self.cmd('az bot create -g {rg} -n {botname} --appid {numbers_id} --app-type MultiTenant')
             raise AssertionError()
         except CLIError as cli_error:
             assert cli_error.__str__() == expected_error
@@ -700,8 +486,7 @@ class BotTests(ScenarioTest):
             raise AssertionError('should have thrown an error for appid that is not valid GUID.')
 
         try:
-            self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {short_app_id} -p {password} --lang '
-                     'Javascript --echo')
+            self.cmd('az bot create -g {rg} -n {botname} --appid {short_app_id} --app-type MultiTenant')
             raise AssertionError()
         except CLIError as cli_error:
             assert cli_error.__str__() == expected_error
@@ -709,46 +494,13 @@ class BotTests(ScenarioTest):
             raise AssertionError('should have thrown an error for appid that is not valid GUID.')
 
         try:
-            self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid "" -p {password} --lang '
-                     'Javascript --echo')
+            self.cmd('az bot create -g {rg} -n {botname} --appid "" --app-type MultiTenant')
             raise AssertionError()
         except CLIError as cli_error:
             assert cli_error.__str__() == expected_error
         except AssertionError:
             raise AssertionError('should have thrown an error for appid that is not valid GUID.')
 
-    @ResourceGroupPreparer(random_name_length=20)
-    def test_botservice_create_should_raise_error_for_empty_password_strings_for_webapp_bots(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=15),
-            'app_id': str(uuid.uuid4())
-        })
-
-        try:
-            self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p "" --lang Javascript --echo')
-            raise AssertionError()
-        except CLIError as cli_error:
-            assert cli_error.__str__() == "--password cannot have a length of 0 for Web App Bots. This value is used to " \
-                                          "authorize calls to your bot. See 'az bot create --help'."
-        except AssertionError:
-            raise AssertionError('should have thrown an error for empty string passwords.')
-
-    @ResourceGroupPreparer(random_name_length=20)
-    def test_botservice_create_should_raise_error_with_no_password_for_webapp_bots(self, resource_group):
-        self.kwargs.update({
-            'botname': self.create_random_name(prefix='cli', length=15),
-            'app_id': str(uuid.uuid4())
-        })
-
-        try:
-            self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} --lang Javascript --echo')
-            raise AssertionError()
-        except CLIError as cli_error:
-            assert cli_error.__str__() == "--password cannot have a length of 0 for Web App Bots. This value is used to " \
-                                          "authorize calls to your bot. See 'az bot create --help'."
-        except AssertionError:
-            raise AssertionError('should have thrown an error for empty string passwords.')
-
     @ResourceGroupPreparer(random_name_length=20)
     @ResourceGroupPreparer(key='rg2', random_name_length=20)
     def test_botservice_should_throw_if_name_is_unavailable(self, resource_group):
@@ -762,7 +514,7 @@ class BotTests(ScenarioTest):
         })
 
         self.cmd(
-            'az bot create -k registration -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id}',
+            'az bot create -g {rg} -n {botname} -d {description} -e {endpoint} --appid {app_id} --app-type MultiTenant',
             checks=[
                 self.check('name', '{botname}'),
                 self.check('properties.description', '{description}'),
@@ -772,7 +524,7 @@ class BotTests(ScenarioTest):
 
         try:
             self.cmd(
-                'az bot create -k registration -g {rg2} -n {botname} -d {description} -e {endpoint} --appid {app_id}')
+                'az bot create -g {rg2} -n {botname} -d {description} -e {endpoint} --appid {app_id} --app-type MultiTenant')
             raise AssertionError()
         except CLIError as cli_error:
             assert cli_error.__str__().startswith('Unable to create bot.\nReason: ')
@@ -822,7 +574,7 @@ class BotTests(ScenarioTest):
         })
 
         self.cmd(
-            'az bot create -k registration -g {rg} -n {botname} --appid {app_id}',
+            'az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant',
             checks=[
                 self.check('name', '{botname}'),
             ])
@@ -846,8 +598,8 @@ class BotLiveOnlyTests(LiveScenarioTest):
             'password': str(uuid.uuid4())
         })
 
-        self.cmd('az bot create -k registration -g {rg} -n {botname} --appid {app_id} -p {password} '
-                 '-e https://testurl.com/api/messages',
+        self.cmd('az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant'
+                 ' -e https://testurl.com/api/messages',
                  checks={
                      self.check('resourceGroup', '{rg}'),
                      self.check('type', 'Microsoft.BotService/botServices')
@@ -864,11 +616,11 @@ class BotLiveOnlyTests(LiveScenarioTest):
             'password': str(uuid.uuid4())
         })
 
-        self.cmd('az bot create -k webapp -g {rg} -n {botname} --appid {app_id} -p {password} --lang Javascript',
+        self.cmd('az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant',
                  checks={
                      self.check('resourceGroup', '{rg}'),
                      self.check('id', '{valid_bot_name}'),
-                     self.check('type', 'abs')
+                     self.check('type', 'Microsoft.BotService/botServices')
                  })
 
     @ResourceGroupPreparer(random_name_length=20)
@@ -898,7 +650,7 @@ class BotLiveOnlyTests(LiveScenarioTest):
         cmk_url = resultAzKey['key']['kid']
 
         resultsCreate = self.cmd(
-            'az bot create -k registration -g {rg} -n {botname} --appid {app_id} --cmk-key-vault-key-url ' + cmk_url,
+            'az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant --cmk-key-vault-key-url ' + cmk_url,
             checks={
                 self.check('resourceGroup', '{rg}'),
                 self.check('id', '{botname}'),
@@ -930,7 +682,7 @@ class BotLiveOnlyTests(LiveScenarioTest):
 
         self.cmd('az bot delete -g {rg} -n {botname}')
 
-        resultsCreate = self.cmd('az bot create -k registration -g {rg} -n {botname} --appid {app_id}',
+        resultsCreate = self.cmd('az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant',
                                  checks={
                                      self.check('resourceGroup', '{rg}'),
                                      self.check('id', '{botname}'),
@@ -989,7 +741,7 @@ class BotLiveOnlyTests(LiveScenarioTest):
         cmk_url = resultAzKey['key']['kid']
 
         self.cmd(
-            'az bot create -k webapp -g {rg} -n {botname} --appid {app_id} --echo --lang Csharp --password {pass} --cmk-key-vault-key-url ' + cmk_url,
+            'az bot create -g {rg} -n {botname} --appid {app_id} --app-type MultiTenant  --cmk-key-vault-key-url ' + cmk_url,
             checks={
                 self.check('resourceGroup', '{rg}'),
                 self.check('id', '{botname}'),
@@ -1040,7 +792,7 @@ class BotLocalErrorsTests(unittest.TestCase):
 
         try:
             prepare_webapp_deploy(language, code_dir, proj_file_path)
-            raise Exception("'az bot prepare-publish --lang Javascript' should have failed with --proj-file-path")
+            raise Exception("'az bot prepare-publish ' should have failed with --proj-file-path")
         except CLIError as cli_error:
             assert cli_error.__str__() == '--proj-file-path should not be passed in if language is not Csharp'
         except Exception as error:
@@ -1126,7 +878,7 @@ class BotLocalErrorsTests(unittest.TestCase):
 
         try:
             prepare_webapp_deploy(language, code_dir, proj_file_path)
-            raise Exception("'az bot prepare-publish --lang Csharp' should have failed with no --proj-file-path")
+            raise Exception("'az bot prepare-publish ' should have failed with no --proj-file-path")
         except CLIError as cli_error:
             assert cli_error.__str__() == '--proj-file-path must be provided if language is Csharp'
 
