@@ -6,6 +6,8 @@ from azure.cli.testsdk import ResourceGroupPreparer, JMESPathCheck
 from azure.cli.testsdk import ScenarioTest, record_only
 from .afdx_scenario_mixin import CdnAfdScenarioMixin
 
+from azure.core.exceptions import (HttpResponseError)
+
 
 class CdnAfdSecurityPolicyScenarioTest(CdnAfdScenarioMixin, ScenarioTest):
     @ResourceGroupPreparer()
@@ -21,31 +23,36 @@ class CdnAfdSecurityPolicyScenarioTest(CdnAfdScenarioMixin, ScenarioTest):
         # Create an endpoint
         endpoint1_name = self.create_random_name(prefix='endpoint1', length=24)
         endpoint2_name = self.create_random_name(prefix='endpoint2', length=24)
-        origin_response_timeout_seconds = 100
         enabled_state = "Enabled"
-        endpoint_checks = [JMESPathCheck('originResponseTimeoutSeconds', 100),
-                           JMESPathCheck('enabledState', 'Enabled')]
+        endpoint_checks = [JMESPathCheck('enabledState', 'Enabled')]
         self.afd_endpoint_create_cmd(resource_group,
                                      profile_name,
                                      endpoint1_name,
-                                     origin_response_timeout_seconds,
                                      enabled_state,
                                      checks=endpoint_checks)
 
         self.afd_endpoint_create_cmd(resource_group,
                                      profile_name,
                                      endpoint2_name,
-                                     origin_response_timeout_seconds,
                                      enabled_state,
                                      checks=endpoint_checks)
-
-        # Create a security policy
+        
         security_policy_name = self.create_random_name(prefix='security', length=24)
         domain_ids = []
         domain_ids.append(f'/subscriptions/{self.get_subscription_id()}/resourcegroups/{resource_group}/providers/Microsoft.Cdn/profiles/{profile_name}/afdEndpoints/{endpoint1_name}')
         domain_ids.append(f'/subscriptions/{self.get_subscription_id()}/resourcegroups/{resource_group}/providers/Microsoft.Cdn/profiles/{profile_name}/afdEndpoints/{endpoint2_name}')
+        
+        # Create a security policy with non-exisit waf should fail
+        waf_policy_id = f'/subscriptions/{self.get_subscription_id()}/resourcegroups/CliDevReservedGroup/providers/Microsoft.Network/frontdoorwebapplicationfirewallpolicies/nonexist'
+        with self.assertRaisesRegexp(HttpResponseError, "Web Application Firewall Policy being attached to AFDX profile does not exist"):
+            self.afd_security_policy_create_cmd(resource_group,
+                                                profile_name,
+                                                security_policy_name,
+                                                domain_ids,
+                                                waf_policy_id)
+        
+        # Create a security policy
         waf_policy_id = f'/subscriptions/{self.get_subscription_id()}/resourcegroups/CliDevReservedGroup/providers/Microsoft.Network/frontdoorwebapplicationfirewallpolicies/SampleStandard'
-
         checks = [JMESPathCheck('provisioningState', 'Succeeded')]
         self.afd_security_policy_create_cmd(resource_group,
                                             profile_name,
