@@ -20,6 +20,11 @@ class CdnEndpointScenarioTest(CdnScenarioMixin, ScenarioTest):
         self.endpoint_list_cmd(resource_group, profile_name, checks=list_checks)
 
         endpoint_name = self.create_random_name(prefix='endpoint', length=24)
+        
+        name_exist_checks = [JMESPathCheck('reason', None),
+                             JMESPathCheck('nameAvailable', True)]
+        self.cmd(f"cdn name-exists --name {endpoint_name}", checks=name_exist_checks)
+
         origin = 'www.example.com'
         checks = [JMESPathCheck('name', endpoint_name),
                   JMESPathCheck('origins[0].hostName', origin),
@@ -32,6 +37,10 @@ class CdnEndpointScenarioTest(CdnScenarioMixin, ScenarioTest):
                                  profile_name,
                                  origin,
                                  checks=checks)
+ 
+        name_exist_checks = [JMESPathCheck('reason', "Name is already in use"),
+                             JMESPathCheck('nameAvailable', False)]
+        self.cmd(f"cdn name-exists --name {endpoint_name}", checks=name_exist_checks)
 
         list_checks = [JMESPathCheck('length(@)', 1),
                        JMESPathCheck('@[0].name', endpoint_name),
