@@ -17,7 +17,7 @@ class CognitiveServicesApiPropertiesTests(ScenarioTest):
             'sname': sname,
             'kind': 'FormRecognizer',
             'sku': 'F0',
-            'location': 'centraluseuap'
+            'location': 'SOUTHCENTRALUS'
         })
 
         # test to create cognitive services account
@@ -43,7 +43,7 @@ class CognitiveServicesApiPropertiesTests(ScenarioTest):
             'sname': sname,
             'kind': 'Face',
             'sku': 'S0',
-            'location': 'centraluseuap'
+            'location': 'SOUTHCENTRALUS'
         })
 
         # test to create cognitive services account
@@ -55,12 +55,6 @@ class CognitiveServicesApiPropertiesTests(ScenarioTest):
         print(account)
         self.assertEqual(account['properties']['publicNetworkAccess'], 'Enabled')
 
-        import time
-        for i in range(10):
-            time.sleep(15)
-            account = self.cmd('az cognitiveservices account show -n {sname} -g {rg}').get_output_in_json()
-            if 'Creating' != account['properties']['provisioningState']:
-                break
 
         # delete the cognitive services account
         ret = self.cmd('az cognitiveservices account delete -n {sname} -g {rg}')
