@@ -36,3 +36,11 @@ def private_endpoint_connections_mgmt_client_factory(cli_ctx, _):
 
 def private_link_mgmt_client_factory(cli_ctx, _):
     return cf_eventhub(cli_ctx).private_link_resources
+
+
+def schema_registry_mgmt_client_factory(cli_ctx, _):
+    return cf_eventhub(cli_ctx).schema_registry
+
+
+def application_group_mgmt_client_factory(cli_ctx, _):
+    return cf_eventhub(cli_ctx).application_group
