@@ -14,9 +14,8 @@ from azure.cli.core.profiles import ResourceType
 # , resource_type = ResourceType.MGMT_EVENTHUB
 # Namespace Region
 def cli_namespace_create(cmd, client, resource_group_name, namespace_name, location=None, tags=None, sku='Standard', capacity=None,
-                         is_auto_inflate_enabled=None, maximum_throughput_units=None, is_kafka_enabled=None,
-                         default_action=None, identity=None, zone_redundant=None, cluster_arm_id=None, trusted_service_access_enabled=None,
-                         disable_local_auth=None, mi_system_assigned=None, mi_user_assigned=None, encryption_config=None, minimum_tls_version=None):
+                         is_auto_inflate_enabled=None, maximum_throughput_units=None, is_kafka_enabled=None, zone_redundant=None, cluster_arm_id=None,
+                         disable_local_auth=None, mi_system_assigned=None, mi_user_assigned=None, encryption_config=None, minimum_tls_version=None, require_infrastructure_encryption=None):
     EHNamespace = cmd.get_models('EHNamespace', resource_type=ResourceType.MGMT_EVENTHUB)
     Sku = cmd.get_models('Sku', resource_type=ResourceType.MGMT_EVENTHUB)
     Identity = cmd.get_models('Identity', resource_type=ResourceType.MGMT_EVENTHUB)
@@ -37,7 +36,7 @@ def cli_namespace_create(cmd, client, resource_group_name, namespace_name, locat
         ehparam.cluster_arm_id = cluster_arm_id
         ehparam.minimum_tls_version = minimum_tls_version
 
-        if identity or mi_system_assigned:
+        if mi_system_assigned:
             ehparam.identity = Identity(type=IdentityType.SYSTEM_ASSIGNED)
 
         if mi_user_assigned:
@@ -56,28 +55,23 @@ def cli_namespace_create(cmd, client, resource_group_name, namespace_name, locat
             ehparam.encryption = Encryption()
             ehparam.encryption.key_vault_properties = encryption_config
 
+        if require_infrastructure_encryption is not None:
+            if ehparam.encryption is None:
+                ehparam.encryption = Encryption()
+            ehparam.encryption.require_infrastructure_encryption = require_infrastructure_encryption
+
         client.begin_create_or_update(
             resource_group_name=resource_group_name,
             namespace_name=namespace_name,
             parameters=ehparam).result()
 
-    if default_action or trusted_service_access_enabled:
-        netwrokruleset = client.get_network_rule_set(resource_group_name, namespace_name)
-        netwrokruleset.default_action = default_action
-        netwrokruleset.trusted_service_access_enabled = trusted_service_access_enabled
-        client.create_or_update_network_rule_set(resource_group_name, namespace_name, netwrokruleset)
-
     return client.get(resource_group_name, namespace_name)
 
 
-def cli_namespace_update(cmd, client, instance, tags=None, sku=None, capacity=None, is_auto_inflate_enabled=None,
-                         maximum_throughput_units=None, is_kafka_enabled=None, default_action=None,
-                         identity=None, key_source=None, key_name=None, key_vault_uri=None, key_version=None, trusted_service_access_enabled=None,
+def cli_namespace_update(cmd, instance, tags=None, sku=None, capacity=None, is_auto_inflate_enabled=None,
+                         maximum_throughput_units=None, is_kafka_enabled=None,
                          disable_local_auth=None, require_infrastructure_encryption=None, minimum_tls_version=None):
     Encryption = cmd.get_models('Encryption', resource_type=ResourceType.MGMT_EVENTHUB)
-    KeyVaultProperties = cmd.get_models('KeyVaultProperties', resource_type=ResourceType.MGMT_EVENTHUB)
-    Identity = cmd.get_models('Identity', resource_type=ResourceType.MGMT_EVENTHUB)
-    IdentityType = cmd.get_models('ManagedServiceIdentityType', resource_type=ResourceType.MGMT_EVENTHUB)
 
     if cmd.supported_api_version(resource_type=ResourceType.MGMT_EVENTHUB, min_api='2021-06-01-preview'):
         if tags:
@@ -102,25 +96,10 @@ def cli_namespace_update(cmd, client, instance, tags=None, sku=None, capacity=No
         if minimum_tls_version:
             instance.minimum_tls_version = minimum_tls_version
 
-        if identity is True and instance.identity is None:
-            instance.identity = Identity(type=IdentityType.SYSTEM_ASSIGNED)
-        elif instance.identity and (key_name or key_vault_uri or key_version or key_source):
-            instance.encryption = Encryption()
-            if key_source:
-                instance.encryption.key_source = key_source
-            if key_name and key_vault_uri:
-                keyprop = []
-                keyprop.append(KeyVaultProperties(key_name=key_name, key_vault_uri=key_vault_uri, key_version=key_version))
-                instance.encryption.key_vault_properties = keyprop
-            if require_infrastructure_encryption:
-                instance.encryption.require_infrastructure_encryption = require_infrastructure_encryption
-
-        if default_action:
-            resourcegroup = instance.id.split('/')[4]
-            netwrokruleset = client.get_network_rule_set(resourcegroup, instance.name)
-            netwrokruleset.default_action = default_action
-            netwrokruleset.trusted_service_access_enabled = trusted_service_access_enabled
-            client.create_or_update_network_rule_set(resourcegroup, instance.name, netwrokruleset)
+        if require_infrastructure_encryption is not None:
+            if instance.encryption is None:
+                instance.encryption = Encryption()
+            instance.encryption.require_infrastructure_encryption = require_infrastructure_encryption
 
         if disable_local_auth is not None:
             instance.disable_local_auth = disable_local_auth
@@ -549,7 +528,7 @@ def cli_remove_identity(cmd, client, resource_group_name, namespace_name, system
     return get_namespace
 
 
-def cli_add_encryption(cmd, client, resource_group_name, namespace_name, encryption_config):
+def cli_add_encryption(cmd, client, resource_group_name, namespace_name, encryption_config, require_infrastructure_encryption=None):
     namespace = client.get(resource_group_name, namespace_name)
     Encryption = cmd.get_models('Encryption', resource_type=ResourceType.MGMT_EVENTHUB)
 
@@ -563,6 +542,9 @@ def cli_add_encryption(cmd, client, resource_group_name, namespace_name, encrypt
         namespace.encryption = Encryption()
         namespace.encryption.key_vault_properties = encryption_config
 
+    if require_infrastructure_encryption is not None:
+        namespace.encryption.require_infrastructure_encryption = require_infrastructure_encryption
+
     client.begin_create_or_update(
         resource_group_name=resource_group_name,
         namespace_name=namespace_name,
