@@ -2,11 +2,11 @@
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
-
 from knack.log import get_logger
 from knack.prompting import prompt_pass, NoTTYException
 from knack.util import CLIError
 from azure.cli.core.util import sdk_no_wait, user_confirmation
+from azure.cli.core.azclierror import RequiredArgumentMissingError
 
 logger = get_logger(__name__)
 
@@ -15,7 +15,7 @@ logger = get_logger(__name__)
 def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
                    location=None, tags=None, no_wait=False, cluster_version='default', cluster_tier=None,
                    cluster_configurations=None, component_version=None,
-                   headnode_size='large', workernode_size='large', zookeepernode_size=None, edgenode_size=None,
+                   headnode_size=None, workernode_size=None, zookeepernode_size=None, edgenode_size=None,
                    kafka_management_node_size=None, kafka_management_node_count=2,
                    kafka_client_group_id=None, kafka_client_group_name=None,
                    workernode_count=3, workernode_data_disks_per_node=None,
@@ -36,17 +36,18 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
                    autoscale_type=None, autoscale_min_workernode_count=None, autoscale_max_workernode_count=None,
                    timezone=None, days=None, time=None, autoscale_workernode_count=None,
                    encryption_at_host=None, esp=False, idbroker=False,
-                   resource_provider_connection=None, enable_private_link=None,
+                   resource_provider_connection=None, enable_private_link=None, enable_compute_isolation=None,
+                   host_sku=None, zones=None, private_link_configurations=None,
                    no_validation_timeout=False):
     from .util import build_identities_info, build_virtual_network_profile, parse_domain_name, \
-        get_storage_account_endpoint, validate_esp_cluster_create_params
+        get_storage_account_endpoint, validate_esp_cluster_create_params, set_vm_size
     from azure.mgmt.hdinsight.models import ClusterCreateParametersExtended, ClusterCreateProperties, OSType, \
         ClusterDefinition, ComputeProfile, HardwareProfile, Role, OsProfile, LinuxOperatingSystemProfile, \
         StorageProfile, StorageAccount, DataDisksGroups, SecurityProfile, \
-        DirectoryType, DiskEncryptionProperties, Tier, SshProfile, SshPublicKey, \
+        DiskEncryptionProperties, Tier, SshProfile, SshPublicKey, \
         KafkaRestProperties, ClientGroupInfo, EncryptionInTransitProperties, \
         Autoscale, AutoscaleCapacity, AutoscaleRecurrence, AutoscaleSchedule, AutoscaleTimeAndCapacity, \
-        NetworkProperties, PrivateLink
+        NetworkProperties, PrivateLink, ComputeIsolationProperties
 
     validate_esp_cluster_create_params(esp, cluster_name, resource_group_name, cluster_type,
                                        subnet, domain, cluster_admin_account, assign_identity,
@@ -68,7 +69,8 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
 
     if component_version:
         # See validator
-        component_version = {c: v for c, v in [version.split('=') for version in component_version]}
+        # pylint: disable=consider-using-dict-comprehension
+        component_version = dict([version.split('=') for version in component_version])
 
     # Validate whether HTTP credentials were provided
     if 'gateway' in cluster_configurations:
@@ -197,6 +199,16 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
         )
     ]
 
+    # call get default vm size api to set vm size if customer does not provide the value
+    if not (workernode_size and headnode_size):
+        headnode_size, workernode_size = set_vm_size(cmd.cli_ctx, location, cluster_type, headnode_size,
+                                                     workernode_size)
+
+    if not headnode_size:
+        raise RequiredArgumentMissingError('Please specify --headnode-size explicitly.')
+    if not workernode_size:
+        raise RequiredArgumentMissingError('Please specify --workernode-size explicitly.')
+
     os_profile = OsProfile(
         linux_operating_system_profile=LinuxOperatingSystemProfile(
             username=ssh_username,
@@ -309,7 +321,7 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
         ldaps_urls = ['ldaps://{}:636'.format(domain_name)]
 
     security_profile = domain and SecurityProfile(
-        directory_type=DirectoryType.active_directory,
+        directory_type=SecurityProfile.directory_type,
         domain=domain_name,
         ldaps_urls=ldaps_urls,
         domain_username=cluster_admin_account,
@@ -333,26 +345,33 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
         else:
             disk_encryption_properties = DiskEncryptionProperties(encryption_at_host=encryption_at_host)
 
-    kafka_rest_properties = (kafka_client_group_id and kafka_client_group_name) and KafkaRestProperties(
+    kafka_rest_properties = KafkaRestProperties(
         client_group_info=ClientGroupInfo(
             group_id=kafka_client_group_id,
             group_name=kafka_client_group_name
         )
-    )
+    ) if (kafka_client_group_id and kafka_client_group_name) else None
 
-    encryption_in_transit_properties = encryption_in_transit and EncryptionInTransitProperties(
+    encryption_in_transit_properties = EncryptionInTransitProperties(
         is_encryption_in_transit_enabled=encryption_in_transit
-    )
+    ) if encryption_in_transit is True else None
 
     # relay outbound and private link
-    network_properties = (resource_provider_connection or enable_private_link) and NetworkProperties(
+    network_properties = NetworkProperties(
         resource_provider_connection=resource_provider_connection,
         private_link=PrivateLink.enabled if enable_private_link is True else PrivateLink.disabled
-    )
+    ) if (resource_provider_connection is not None or enable_private_link is not None) else None
+
+    # compute isolation
+    compute_isolation_properties = ComputeIsolationProperties(
+        enable_compute_isolation=enable_compute_isolation,
+        host_sku=host_sku
+    ) if enable_compute_isolation is True else None
 
     create_params = ClusterCreateParametersExtended(
         location=location,
         tags=tags,
+        zones=zones,
         properties=ClusterCreateProperties(
             cluster_version=cluster_version,
             os_type=OSType.linux,
@@ -373,15 +392,14 @@ def create_cluster(cmd, client, cluster_name, resource_group_name, cluster_type,
             kafka_rest_properties=kafka_rest_properties,
             min_supported_tls_version=minimal_tls_version,
             encryption_in_transit_properties=encryption_in_transit_properties,
-            network_properties=network_properties
+            network_properties=network_properties,
+            compute_isolation_properties=compute_isolation_properties,
+            private_link_configurations=private_link_configurations
         ),
         identity=cluster_identity
     )
 
-    if no_wait:
-        return sdk_no_wait(no_wait, client.create, resource_group_name, cluster_name, create_params)
-
-    return client.create(resource_group_name, cluster_name, create_params)
+    return sdk_no_wait(no_wait, client.begin_create, resource_group_name, cluster_name, create_params)
 
 
 def list_clusters(cmd, client, resource_group_name=None):  # pylint: disable=unused-argument
@@ -391,6 +409,15 @@ def list_clusters(cmd, client, resource_group_name=None):  # pylint: disable=unu
     return list(clusters_list)
 
 
+def update_cluster(cmd, client, cluster_name, resource_group_name, tags=None, no_wait=False):
+    from azure.mgmt.hdinsight.models import ClusterPatchParameters
+    cluster_patch_parameters = ClusterPatchParameters(
+        tags=tags
+    )
+
+    return sdk_no_wait(no_wait, client.update, resource_group_name, cluster_name, cluster_patch_parameters)
+
+
 # pylint: disable=unused-argument
 def rotate_hdi_cluster_key(cmd, client, resource_group_name, cluster_name,
                            encryption_vault_uri, encryption_key_name, encryption_key_version, no_wait=False):
@@ -401,10 +428,18 @@ def rotate_hdi_cluster_key(cmd, client, resource_group_name, cluster_name,
         key_version=encryption_key_version
     )
 
-    if no_wait:
-        return sdk_no_wait(no_wait, client.rotate_disk_encryption_key, resource_group_name, cluster_name, rotate_params)
+    return sdk_no_wait(no_wait, client.begin_rotate_disk_encryption_key, resource_group_name, cluster_name,
+                       rotate_params)
 
-    return client.rotate_disk_encryption_key(resource_group_name, cluster_name, rotate_params)
+
+def resize_cluster(cmd, client, cluster_name, resource_group_name, target_instance_count, no_wait=False):
+    from azure.mgmt.hdinsight.models import ClusterResizeParameters, RoleName
+    resize_cluster_parameters = ClusterResizeParameters(
+        target_instance_count=target_instance_count
+    )
+
+    return sdk_no_wait(no_wait, client.begin_resize, resource_group_name, cluster_name, RoleName.WORKERNODE,
+                       resize_cluster_parameters)
 
 
 def _all_or_none(*params):
@@ -491,12 +526,13 @@ def create_hdi_application(cmd, client, resource_group_name, cluster_name, appli
         properties=application_properties
     )
 
-    return client.create(resource_group_name, cluster_name, application_name, create_params)
+    return client.begin_create(resource_group_name, cluster_name, application_name, create_params)
 
 
 # pylint: disable=unused-argument
 def enable_hdi_monitoring(cmd, client, resource_group_name, cluster_name, workspace,
                           primary_key=None, workspace_type='resource_id', no_validation_timeout=False):
+    from azure.mgmt.hdinsight.models import ClusterMonitoringRequest
     from msrestazure.tools import parse_resource_id
     from ._client_factory import cf_log_analytics
 
@@ -525,18 +561,63 @@ def enable_hdi_monitoring(cmd, client, resource_group_name, cluster_name, worksp
 
         workspace_id = log_analytics_workspace.customer_id
 
-    return client.enable_monitoring(
+    monitor_request_parameter = ClusterMonitoringRequest(
+        workspace_id=workspace_id,
+        primary_key=primary_key
+    )
+    return client.begin_enable_monitoring(
         resource_group_name,
         cluster_name,
-        workspace_id,
-        primary_key)
+        monitor_request_parameter)
+
+
+# pylint: disable=unused-argument
+def enable_hdi_azure_monitor(cmd, client, resource_group_name, cluster_name, workspace, primary_key=None,
+                             workspace_type='resource_id', no_validation_timeout=False):
+    from azure.mgmt.hdinsight.models import AzureMonitorRequest
+    from msrestazure.tools import parse_resource_id
+    from ._client_factory import cf_log_analytics
+
+    if workspace_type != 'resource_id' and not primary_key:
+        raise RequiredArgumentMissingError('primary key is required when workspace ID is provided.')
+
+    workspace_id = workspace
+    if workspace_type == 'resource_id':
+        parsed_workspace = parse_resource_id(workspace)
+        workspace_resource_group_name = parsed_workspace['resource_group']
+        workspace_name = parsed_workspace['resource_name']
+
+        log_analytics_client = cf_log_analytics(cmd.cli_ctx)
+        log_analytics_workspace = log_analytics_client.workspaces.get(workspace_resource_group_name, workspace_name)
+        if not log_analytics_workspace:
+            raise CLIError('Fails to retrieve workspace by {}'.format(workspace))
+
+        # Only retrieve primary key when not provided
+        if not primary_key:
+            shared_keys = log_analytics_client.shared_keys.get_shared_keys(workspace_resource_group_name,
+                                                                           workspace_name)
+            if not shared_keys:
+                raise CLIError('Fails to retrieve shared key for workspace {}'.format(log_analytics_workspace))
+
+            primary_key = shared_keys.primary_shared_key
+
+        workspace_id = log_analytics_workspace.customer_id
+
+    azure_monitor_request_parameter = AzureMonitorRequest(
+        workspace_id=workspace_id,
+        primary_key=primary_key
+    )
+    return client.begin_enable_azure_monitor(
+        resource_group_name,
+        cluster_name,
+        azure_monitor_request_parameter)
 
 
 # pylint: disable=unused-argument
 def execute_hdi_script_action(cmd, client, resource_group_name, cluster_name,
                               script_uri, script_action_name, roles, script_parameters=None,
                               persist_on_success=False):
-    from azure.mgmt.hdinsight.models import RuntimeScriptAction
+    from azure.mgmt.hdinsight.models import RuntimeScriptAction, ExecuteScriptActionParameters
 
     script_actions_params = [
         RuntimeScriptAction(
@@ -546,8 +627,11 @@ def execute_hdi_script_action(cmd, client, resource_group_name, cluster_name,
             roles=roles
         )
     ]
-
-    return client.execute_script_actions(resource_group_name, cluster_name, persist_on_success, script_actions_params)
+    execute_script_action_parameters = ExecuteScriptActionParameters(
+        persist_on_success=persist_on_success,
+        script_actions=script_actions_params
+    )
+    return client.begin_execute_script_actions(resource_group_name, cluster_name, execute_script_action_parameters)
 
 
 # pylint: disable=redefined-builtin
@@ -555,7 +639,7 @@ def create_autoscale(cmd, client, resource_group_name, cluster_name, type, min_w
                      max_workernode_count=None, timezone=None, days=None, time=None, workernode_count=None,
                      no_wait=False, yes=False):
     from azure.mgmt.hdinsight.models import Autoscale, AutoscaleCapacity, AutoscaleRecurrence, AutoscaleSchedule, \
-        AutoscaleTimeAndCapacity
+        AutoscaleTimeAndCapacity, AutoscaleConfigurationUpdateParameter, RoleName
     load_based_type = "Load"
     schedule_based_type = "Schedule"
     autoscale_configuration = None
@@ -595,13 +679,17 @@ def create_autoscale(cmd, client, resource_group_name, cluster_name, type, min_w
         "This operation will override previous autoscale configuration. "
         "Are you sure you want to perform this operation", yes)
 
-    return sdk_no_wait(no_wait, client.update_auto_scale_configuration, resource_group_name, cluster_name,
-                       autoscale_configuration)
+    autoscale_configuration_update_parameter = AutoscaleConfigurationUpdateParameter(
+        autoscale=autoscale_configuration
+    )
+    return sdk_no_wait(no_wait, client.begin_update_auto_scale_configuration, resource_group_name, cluster_name,
+                       RoleName.WORKERNODE, autoscale_configuration_update_parameter)
 
 
 def update_autoscale(cmd, client, resource_group_name, cluster_name, min_workernode_count=None,
                      max_workernode_count=None, timezone=None, no_wait=False):
-    from azure.mgmt.hdinsight.models import AutoscaleCapacity, AutoscaleRecurrence
+    from azure.mgmt.hdinsight.models import AutoscaleCapacity, AutoscaleRecurrence, \
+        AutoscaleConfigurationUpdateParameter, RoleName
     cluster = client.get(resource_group_name, cluster_name)
     autoscale_configuration = _extract_and_validate_autoscale_configuration(cluster)
 
@@ -627,8 +715,11 @@ def update_autoscale(cmd, client, resource_group_name, cluster_name, min_workern
         elif not autoscale_configuration.recurrence:
             autoscale_configuration.recurrence = AutoscaleRecurrence(time_zone=timezone)
 
-    return sdk_no_wait(no_wait, client.update_auto_scale_configuration, resource_group_name, cluster_name,
-                       autoscale_configuration)
+    autoscale_configuration_update_parameter = AutoscaleConfigurationUpdateParameter(
+        autoscale=autoscale_configuration
+    )
+    return sdk_no_wait(no_wait, client.begin_update_auto_scale_configuration, resource_group_name, cluster_name,
+                       RoleName.WORKERNODE, autoscale_configuration_update_parameter)
 
 
 def show_autoscale(cmd, client, resource_group_name, cluster_name):
@@ -638,12 +729,17 @@ def show_autoscale(cmd, client, resource_group_name, cluster_name):
 
 
 def delete_autoscale(cmd, client, resource_group_name, cluster_name, no_wait=False):
+    from azure.mgmt.hdinsight.models import AutoscaleConfigurationUpdateParameter, RoleName
+
     cluster = client.get(resource_group_name, cluster_name)
     _extract_and_validate_autoscale_configuration(cluster)
     autoscale_configuration = None
 
-    return sdk_no_wait(no_wait, client.update_auto_scale_configuration, resource_group_name, cluster_name,
-                       autoscale_configuration)
+    autoscale_configuration_update_parameter = AutoscaleConfigurationUpdateParameter(
+        autoscale=autoscale_configuration
+    )
+    return sdk_no_wait(no_wait, client.begin_update_auto_scale_configuration, resource_group_name, cluster_name,
+                       RoleName.WORKERNODE, autoscale_configuration_update_parameter)
 
 
 def list_timezones(cmd, client):
@@ -653,7 +749,8 @@ def list_timezones(cmd, client):
 
 def create_autoscale_condition(cmd, client, resource_group_name, cluster_name, days, time, workernode_count,
                                no_wait=False):
-    from azure.mgmt.hdinsight.models import AutoscaleRecurrence, AutoscaleSchedule, AutoscaleTimeAndCapacity
+    from azure.mgmt.hdinsight.models import AutoscaleRecurrence, AutoscaleSchedule, AutoscaleTimeAndCapacity, \
+        AutoscaleConfigurationUpdateParameter, RoleName
     cluster = client.get(resource_group_name, cluster_name)
     autoscale_configuration = _extract_and_validate_autoscale_configuration(cluster)
 
@@ -671,13 +768,17 @@ def create_autoscale_condition(cmd, client, resource_group_name, cluster_name, d
         autoscale_configuration.recurrence = AutoscaleRecurrence(
             schedule=[condition]
         )
-
-    return sdk_no_wait(no_wait, client.update_auto_scale_configuration, resource_group_name, cluster_name,
-                       autoscale_configuration)
+    autoscale_configuration_update_parameter = AutoscaleConfigurationUpdateParameter(
+        autoscale=autoscale_configuration
+    )
+    return sdk_no_wait(no_wait, client.begin_update_auto_scale_configuration, resource_group_name, cluster_name,
+                       RoleName.WORKERNODE, autoscale_configuration_update_parameter)
 
 
 def update_autoscale_condition(cmd, client, resource_group_name, cluster_name, index, days=None, time=None,
                                workernode_count=None, no_wait=False):
+    from azure.mgmt.hdinsight.models import AutoscaleConfigurationUpdateParameter, RoleName
+
     cluster = client.get(resource_group_name, cluster_name)
     autoscale_configuration = _extract_and_validate_autoscale_configuration(cluster)
     _validate_schedule_configuration(autoscale_configuration)
@@ -696,11 +797,16 @@ def update_autoscale_condition(cmd, client, resource_group_name, cluster_name, i
         autoscale_configuration.recurrence.schedule[index].time_and_capacity.min_instance_count = workernode_count
         autoscale_configuration.recurrence.schedule[index].time_and_capacity.max_instance_count = workernode_count
 
-    return sdk_no_wait(no_wait, client.update_auto_scale_configuration, resource_group_name, cluster_name,
-                       autoscale_configuration)
+    autoscale_configuration_update_parameter = AutoscaleConfigurationUpdateParameter(
+        autoscale=autoscale_configuration
+    )
+    return sdk_no_wait(no_wait, client.begin_update_auto_scale_configuration, resource_group_name, cluster_name,
+                       RoleName.WORKERNODE, autoscale_configuration_update_parameter)
 
 
 def delete_autoscale_condition(cmd, client, resource_group_name, cluster_name, index, no_wait=False):
+    from azure.mgmt.hdinsight.models import AutoscaleConfigurationUpdateParameter, RoleName
+
     cluster = client.get(resource_group_name, cluster_name)
     autoscale_configuration = _extract_and_validate_autoscale_configuration(cluster)
     _validate_schedule_configuration(autoscale_configuration)
@@ -711,8 +817,11 @@ def delete_autoscale_condition(cmd, client, resource_group_name, cluster_name, i
                        'If you want to disable autoscale please use `az hdinsight autoscale delete`.')
     autoscale_configuration.recurrence.schedule = [autoscale_configuration.recurrence.schedule[i] for i in
                                                    range(conditions_count) if i not in index]
-    return sdk_no_wait(no_wait, client.update_auto_scale_configuration, resource_group_name, cluster_name,
-                       autoscale_configuration)
+    autoscale_configuration_update_parameter = AutoscaleConfigurationUpdateParameter(
+        autoscale=autoscale_configuration
+    )
+    return sdk_no_wait(no_wait, client.begin_update_auto_scale_configuration, resource_group_name, cluster_name,
+                       RoleName.WORKERNODE, autoscale_configuration_update_parameter)
 
 
 def list_autoscale_condition(cmd, client, resource_group_name, cluster_name):
