@@ -6,27 +6,45 @@
 
 from azure.cli.testsdk import ResourceGroupPreparer, ScenarioTest, StorageAccountPreparer
 from azure.cli.testsdk.scenario_tests import AllowLargeResponse
+from .recording_processors import KeyReplacer
+import unittest
 
 
 class IoTHubTest(ScenarioTest):
 
+    def __init__(self, method_name):
+        super(IoTHubTest, self).__init__(
+            method_name, recording_processors=[KeyReplacer()]
+        )
+
     @AllowLargeResponse()
     @ResourceGroupPreparer(location='westus2')
     @StorageAccountPreparer()
+    @unittest.skip('Need to try with passing SAS key in environment.')  # TODO
     def test_iot_hub(self, resource_group, resource_group_location, storage_account):
-        hub = 'iot-hub-for-test-20190301'
+        hub = self.create_random_name(prefix='iot-hub-for-test-11', length=32)
         rg = resource_group
         location = resource_group_location
-        containerName = 'iothubcontainer20190301'
+        containerName = 'iothubcontainer1'
         storageConnectionString = self._get_azurestorage_connectionstring(rg, containerName, storage_account)
         ehConnectionString = self._get_eventhub_connectionstring(rg)
         subscription_id = self._get_current_subscription()
 
+        # Test hub life cycle in free tier
+        self.cmd('iot hub create -n {0} -g {1} --sku F1'.format(hub, rg), expect_failure=True)
+        self.cmd('iot hub create -n {0} -g {1} --sku F1 --partition-count 4'.format(hub, rg), expect_failure=True)
+        self.cmd('iot hub create -n {0} -g {1} --sku F1 --partition-count 2'.format(hub, rg),
+                 checks=[self.check('resourcegroup', rg),
+                         self.check('name', hub),
+                         self.check('sku.name', 'F1'),
+                         self.check('properties.eventHubEndpoints.events.partitionCount', '2')])
+        self.cmd('iot hub delete -n {0}'.format(hub), checks=self.is_empty())
+
         # Test 'az iot hub create'
         self.cmd('iot hub create -n {0} -g {1} --sku S1 --fn true'.format(hub, rg), expect_failure=True)
         self.cmd('iot hub create -n {0} -g {1} --sku S1 --fn true --fc containerName'
                  .format(hub, rg), expect_failure=True)
-        self.cmd('iot hub create -n {0} -g {1} --sku S1 --partition-count 4 --retention-day 3'
+        self.cmd('iot hub create -n {0} -g {1} --retention-day 3'
                  ' --c2d-ttl 23 --c2d-max-delivery-count 89 --feedback-ttl 29 --feedback-lock-duration 35'
                  ' --feedback-max-delivery-count 40 --fileupload-notification-max-delivery-count 79'
                  ' --fileupload-notification-ttl 20'.format(hub, rg),
@@ -136,7 +154,7 @@ class IoTHubTest(ScenarioTest):
         policy = self.cmd('iot hub policy renew-key --hub-name {0} -n {1} --renew-key Primary'.format(hub, policy_name),
                           checks=[self.check('keyName', policy_name)]).get_output_in_json()
 
-        policy_name_conn_str_pattern = r'^HostName={0}.azure-devices.net;SharedAccessKeyName={1};SharedAccessKey={2}'.format(
+        policy_name_conn_str_pattern = r'HostName={0}.azure-devices.net;SharedAccessKeyName={1};SharedAccessKey={2}'.format(
             hub, policy_name, policy['primaryKey'])
 
         # Test policy_name connection-string 'az iot hub show-connection-string'
@@ -334,44 +352,38 @@ class IoTHubTest(ScenarioTest):
                          self.check('length(serviceBusTopics[*])', 0),
                          self.check('length(storageContainers[*])', 1)])
 
-        # In the '2019-03-01-hybrid' profile, the api-version used by IotHub is stable version
-        # and does not support devicestream for the time being, so hide the command test temporarily
         # Test 'az iot hub devicestream show'
-        # self.cmd('iot hub devicestream show -n {0} -g {1}'.format(hub, rg), checks=self.is_empty())
-
-        # properties.routing.enrichments are not supported in the API version 2019-03-22,
-        # It can be supported in newer api-version, so hide the command test temporarily
+        self.cmd('iot hub devicestream show -n {0} -g {1}'.format(hub, rg), checks=self.is_empty())
 
         # Test 'az iot hub message-enrichment create'
-        # real_endpoints = 'events'
-        # fake_endpoints = 'events fake_endpoint'
-        # key = 'key'
-        # fake_key = 'fake_key'
-        # value = 'value'
-        #
-        # self.cmd('iot hub message-enrichment create -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
-        #          .format(hub, rg, key, value, fake_endpoints), expect_failure=True)
+        real_endpoints = 'events'
+        fake_endpoints = 'events fake_endpoint'
+        key = 'key'
+        fake_key = 'fake_key'
+        value = 'value'
 
-        # self.cmd('iot hub message-enrichment create -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
-        # .format(hub, rg, key, value, real_endpoints), checks=[self.check('length(properties.routing.enrichments)', 1)])
+        self.cmd('iot hub message-enrichment create -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
+                 .format(hub, rg, key, value, fake_endpoints), expect_failure=True)
+        self.cmd('iot hub message-enrichment create -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
+                 .format(hub, rg, key, value, real_endpoints), checks=[self.check('length(properties.routing.enrichments)', 1)])
 
         # Test 'az iot hub message-enrichment update'
-        # self.cmd('iot hub message-enrichment update -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
-        #          .format(hub, rg, fake_key, value, real_endpoints), expect_failure=True)
-        # self.cmd('iot hub message-enrichment update -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
-        #          .format(hub, rg, key, value, fake_endpoints), expect_failure=True)
-        # self.cmd('iot hub message-enrichment update -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
-        # .format(hub, rg, key, value, real_endpoints), checks=[self.check('length(properties.routing.enrichments)', 1)])
+        self.cmd('iot hub message-enrichment update -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
+                 .format(hub, rg, fake_key, value, real_endpoints), expect_failure=True)
+        self.cmd('iot hub message-enrichment update -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
+                 .format(hub, rg, key, value, fake_endpoints), expect_failure=True)
+        self.cmd('iot hub message-enrichment update -n {0} -g {1} --key {2} --value {3} --endpoints {4}'
+                 .format(hub, rg, key, value, real_endpoints), checks=[self.check('length(properties.routing.enrichments)', 1)])
 
         # Test 'az iot hub message-enrichment list'
-        # self.cmd('iot hub message-enrichment list -n {0} -g {1}'.format(hub, rg),
-        #          checks=[self.check('length([*])', 1)])
+        self.cmd('iot hub message-enrichment list -n {0} -g {1}'.format(hub, rg),
+                 checks=[self.check('length([*])', 1)])
 
         # Test 'az iot hub message-enrichment delete'
-        # self.cmd('iot hub message-enrichment delete -n {0} -g {1} --key {2}'.format(hub, rg, fake_key),
-        #          expect_failure=True)
-        # self.cmd('iot hub message-enrichment delete -n {0} -g {1} --key {2}'.format(hub, rg, key),
-        #          checks=[self.check('length(properties.routing.enrichments)', 0)])
+        self.cmd('iot hub message-enrichment delete -n {0} -g {1} --key {2}'.format(hub, rg, fake_key),
+                 expect_failure=True)
+        self.cmd('iot hub message-enrichment delete -n {0} -g {1} --key {2}'.format(hub, rg, key),
+                 checks=[self.check('length(properties.routing.enrichments)', 0)])
 
         # Test 'az iot hub manual-failover'
         self.cmd('iot hub manual-failover -n {0} -g {1}'.format(hub, rg),
@@ -379,9 +391,135 @@ class IoTHubTest(ScenarioTest):
         # Test 'az iot hub delete'
         self.cmd('iot hub delete -n {0}'.format(hub), checks=self.is_empty())
 
+    @AllowLargeResponse()
+    @ResourceGroupPreparer(location='westus2')
+    @StorageAccountPreparer()
+    @unittest.skip('Need to try with passing SAS key in environment.')  # TODO
+    def test_identity_hub(self, resource_group, resource_group_location, storage_account):
+        # Test IoT Hub create with identity
+        subscription_id = self._get_current_subscription()
+        rg = resource_group
+        location = resource_group_location
+
+        private_endpoint_type = 'Microsoft.Devices/IoTHubs'
+        identity_hub = self.create_random_name(prefix='identitytesthub', length=32)
+        identity_based_auth = 'identityBased'
+        event_hub_identity_endpoint_name = 'EventHubIdentityEndpoint'
+
+        containerName = 'iothubcontainer'
+        storageConnectionString = self._get_azurestorage_connectionstring(rg, containerName, storage_account)
+        endpoint_name = 'Event1'
+        endpoint_type = 'EventHub'
+        eventhub_endpoint_uri = 'eh://test'
+        storage_cs_pattern = 'DefaultEndpointsProtocol=https;EndpointSuffix=core.windows.net;AccountName='
+        entity_path = 'entity'
+
+        # identity hub creation
+        import os
+        templateFile = os.path.join(os.path.dirname(os.path.abspath(__file__)), os.path.pardir, 'templates', 'identity.json')
+        self.cmd('deployment group create --name {0} -g {1} --template-file "{2}" --parameters name={3} --parameters location={4}'
+                 .format("identity-hub-deployment", resource_group, templateFile, identity_hub, location))
+        self.cmd('iot hub show --name {0}'.format(identity_hub), checks=[
+                 self.check('properties.minTlsVersion', '1.2'),
+                 self.check('identity.type', 'SystemAssigned')])
+
+        # Test 'az iot hub update' with Identity-based fileUpload
+        updated_hub = self.cmd('iot hub update -n {0} --fsa {1} --fcs {2} --fc {3} --fn true --fnt 32 --fnd 80 --rd 4 '
+                               '--ct 34 --cdd 46 --ft 43 --fld 10 --fd 76'
+                               .format(identity_hub, identity_based_auth, storageConnectionString, containerName)).get_output_in_json()
+        assert updated_hub['properties']['storageEndpoints']['$default']['authenticationType'] == identity_based_auth
+        assert storage_cs_pattern in updated_hub['properties']['storageEndpoints']['$default']['connectionString']
+        # TODO - implement file upload container URI instead of connectionString once implemented in service
+
+        # Test 'az iot hub routing-endpoint create' with Identity-based event hub endpoint
+        self.cmd('iot hub routing-endpoint create --hub-name {0} -g {1} -n {2} -t {3} -r {4} -s {5} --auth-type {6} --endpoint-uri {7} --entity-path {8}'
+                 .format(identity_hub, rg, event_hub_identity_endpoint_name, endpoint_type, rg, subscription_id, identity_based_auth, eventhub_endpoint_uri, entity_path),
+                 checks=[self.check('length(eventHubs[*])', 1),
+                         self.check('eventHubs[0].resourceGroup', rg),
+                         self.check('eventHubs[0].name', event_hub_identity_endpoint_name),
+                         self.check('eventHubs[0].authenticationType', identity_based_auth),
+                         self.check('eventHubs[0].connectionString', None),
+                         self.check('eventHubs[0].endpointUri', eventhub_endpoint_uri),
+                         self.check('eventHubs[0].entityPath', entity_path),
+                         self.check('length(serviceBusQueues[*])', 0),
+                         self.check('length(serviceBusTopics[*])', 0),
+                         self.check('length(storageContainers[*])', 0)])
+
+        vnet = 'test-iot-vnet'
+        subnet = 'subnet1'
+        endpoint_name = 'iot-private-endpoint'
+        connection_name = 'iot-private-endpoint-connection'
+
+        # Test private endpoints
+        # Prepare network
+        self.cmd('network vnet create -n {0} -g {1} -l {2} --subnet-name {3}'
+                 .format(vnet, rg, location, subnet),
+                 checks=self.check('length(newVNet.subnets)', 1))
+        self.cmd('network vnet subnet update -n {0} --vnet-name {1} -g {2} '
+                 '--disable-private-endpoint-network-policies true'
+                 .format(subnet, vnet, rg),
+                 checks=self.check('privateEndpointNetworkPolicies', 'Disabled'))
+
+        # Create a private endpoint connection
+        pr = self.cmd('network private-link-resource list --type {0} -n {1} -g {2}'
+                      .format(private_endpoint_type, identity_hub, rg)).get_output_in_json()
+        group_id = pr[0]['properties']['groupId']
+
+        hub = self.cmd('iot hub show -n {0} -g {1}'.format(identity_hub, rg)).get_output_in_json()
+        hub_id = hub['id']
+
+        private_endpoint = self.cmd(
+            'network private-endpoint create -g {0} -n {1} --vnet-name {2} --subnet {3} -l {4} '
+            '--connection-name {5} --private-connection-resource-id {6} --group-ids {7}'
+            .format(rg, endpoint_name, vnet, subnet, location, connection_name, hub_id, group_id)
+        ).get_output_in_json()
+
+        self.assertEqual(private_endpoint['name'], endpoint_name)
+        self.assertEqual(private_endpoint['privateLinkServiceConnections'][0]['name'], connection_name)
+        self.assertEqual(private_endpoint['privateLinkServiceConnections'][0]['privateLinkServiceConnectionState']['status'], 'Approved')
+        self.assertEqual(private_endpoint['privateLinkServiceConnections'][0]['provisioningState'], 'Succeeded')
+        self.assertEqual(private_endpoint['privateLinkServiceConnections'][0]['groupIds'][0], group_id)
+
+        hub = self.cmd('iot hub show -n {0} -g {1}'.format(identity_hub, rg)).get_output_in_json()
+        endpoint_id = hub['properties']['privateEndpointConnections'][0]['id']
+        private_endpoint_name = hub['properties']['privateEndpointConnections'][0]['name']
+
+        # endpoint list
+        self.cmd('network private-endpoint-connection list --type {0} -n {1} -g {2}'
+                 .format(private_endpoint_type, identity_hub, rg),
+                 checks=[self.check('length(@)', 1),
+                         self.check('[0].id', endpoint_id),
+                         self.check('[0].name', private_endpoint_name)])
+
+        # endpoint connection approve by name
+        approve_desc = 'Approving endpoint connection'
+        self.cmd('network private-endpoint-connection approve --type {0} -n {1} --resource-name {2} -g {3} --description "{4}"'
+                 .format(private_endpoint_type, private_endpoint_name, identity_hub, rg, approve_desc),
+                 checks=[self.check('properties.privateLinkServiceConnectionState.status', 'Approved')])
+
+        # endpoint approve by id
+        self.cmd('network private-endpoint-connection approve --id {0} --description "{1}"'
+                 .format(endpoint_id, approve_desc),
+                 checks=[self.check('properties.privateLinkServiceConnectionState.status', 'Approved')])
+
+        # endpoint connection reject by name
+        reject_desc = 'Rejecting endpoint connection'
+        self.cmd('network private-endpoint-connection reject --type {0} -n {1} --resource-name {2} -g {3} --description "{4}"'
+                 .format(private_endpoint_type, private_endpoint_name, identity_hub, rg, reject_desc),
+                 checks=[self.check('properties.privateLinkServiceConnectionState.status', 'Rejected')])
+
+        # endpoint show
+        self.cmd('network private-endpoint-connection show --type {0} -n {1} --resource-name {2} -g {3}'
+                 .format(private_endpoint_type, private_endpoint_name, identity_hub, rg),
+                 checks=self.check('id', endpoint_id))
+
+        # endpoint delete
+        self.cmd('network private-endpoint-connection delete --type {0} -n {1} --resource-name {2} -g {3} -y'
+                 .format(private_endpoint_type, private_endpoint_name, identity_hub, rg))
+
     def _get_eventhub_connectionstring(self, rg):
-        ehNamespace = 'ehNamespaceiothubfortest20190301'
-        eventHub = 'eventHubiothubfortest'
+        ehNamespace = self.create_random_name(prefix='ehNamespaceiothubfortest', length=32)
+        eventHub = self.create_random_name(prefix='eventHubiothubfortest', length=32)
         eventHubPolicy = 'eventHubPolicyiothubfortest'
         eventHubPolicyRight = 'Send'
 
