@@ -211,14 +211,6 @@ examples:
     text: |
         az monitor action-group test-notifications create --action-group MyActionGroup \\
         --resource-group MyResourceGroup -a email alice alice@example.com usecommonalertsChema --alert-type budget
-  - name: Create an action group test-notifications with resource-group
-    text: |
-        az monitor action-group test-notifications create --resource-group MyResourceGroup \\
-        -a email alice alice@example.com usecommonalertsChema --alert-type budget
-  - name: Create an action group test-notifications
-    text: |
-        az monitor action-group test-notifications create -a email alice alice@example.com usecommonalertsChema \\
-        --alert-type budget
 """
 
 helps['monitor activity-log'] = """
@@ -709,140 +701,6 @@ examples:
     crafted: true
 """
 
-helps['monitor diagnostic-settings'] = """
-type: group
-short-summary: Manage service diagnostic settings.
-"""
-
-helps['monitor diagnostic-settings categories'] = """
-type: group
-short-summary: Retrieve service diagnostic settings categories.
-"""
-
-helps['monitor diagnostic-settings categories list'] = """
-type: command
-short-summary:  List the diagnostic settings categories for the specified resource.
-examples:
-  - name: List diagnostic settings categories by using resource ID
-    text: az monitor diagnostic-settings categories list --resource /subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/myRG/providers/microsoft.logic/workflows/myWorkflow
-  - name: List diagnostic settings categories by using resource name
-    text: az monitor diagnostic-settings categories list -g myRG --resource-type microsoft.logic/workflows --resource myWorkflow
-
-"""
-
-helps['monitor diagnostic-settings create'] = """
-type: command
-short-summary: Create diagnostic settings for the specified resource.
-long-summary: >
-    For more information, visit: https://docs.microsoft.com/rest/api/monitor/diagnosticsettings/createorupdate#metricsettings
-parameters:
-  - name: --name -n
-    short-summary: The name of the diagnostic settings.
-  - name: --resource-group -g
-    type: string
-    short-summary: Name of the resource group for the Log Analytics and Storage Account when the name of the service instead of a full resource ID is given.
-  - name: --storage-account
-    type: string
-    short-summary: Name or ID of the storage account to send diagnostic logs to.
-  - name: --workspace
-    type: string
-    short-summary: Name or ID of the Log Analytics workspace to send diagnostic logs to.
-  - name: --event-hub
-    type: string
-    short-summary: >
-        Name or ID an event hub. If none is specified, the default event hub will be selected.
-  - name: --event-hub-rule
-    short-summary: Name or ID of the event hub authorization rule.
-examples:
-  - name: Create diagnostic settings, retention here only applies when the target is a storage account.
-    text: |
-        az monitor diagnostic-settings create --resource {ID} -n {name}
-           --storage-account {storageAccount}
-           --logs '[
-             {
-               "category": "WorkflowRuntime",
-               "enabled": true,
-               "retentionPolicy": {
-                 "enabled": false,
-                 "days": 0
-               }
-             }
-           ]'
-           --metrics '[
-             {
-               "category": "WorkflowRuntime",
-               "enabled": true,
-               "retentionPolicy": {
-                 "enabled": false,
-                 "days": 0
-               }
-             }
-           ]'
-"""
-
-helps['monitor diagnostic-settings update'] = """
-type: command
-short-summary: Update diagnostic settings.
-examples:
-  - name: Update diagnostic settings. (autogenerated)
-    text: |
-        az monitor diagnostic-settings update --name MyDiagnosticSetting --resource myScaleSet --set retentionPolicy.days=365
-    crafted: true
-"""
-
-helps['monitor diagnostic-settings subscription'] = """
-type: group
-short-summary: Manage diagnostic settings for subscription.
-"""
-
-helps['monitor diagnostic-settings subscription create'] = """
-type: command
-short-summary: Create diagnostic settings for a subscription
-examples:
-  - name: Create diagnostic settings for a subscription with EventHub.
-    text: |
-        az monitor diagnostic-settings subscription create -n {name} --location westus --event-hub-auth-rule {eventHubRuleID} --storage-account {storageAccount} \\
-        --logs '[
-           {
-             "category": "Security",
-             "enabled": true
-           },
-           {
-             "category": "Administrative",
-             "enabled": true
-           },
-           {
-             "category": "ServiceHealth",
-             "enabled": true
-           },
-           {
-             "category": "Alert",
-             "enabled": true
-           },
-           {
-             "category": "Recommendation",
-             "enabled": true
-           },
-           {
-             "category": "Policy",
-             "enabled": true
-           },
-           {
-             "category": "Autoscale",
-             "enabled": true
-           },
-           {
-             "category": "ResourceHealth",
-             "enabled": true
-           }
-           ]'
-"""
-
-helps['monitor diagnostic-settings subscription update'] = """
-type: command
-short-summary: Update diagnostic settings for a subscription.
-"""
-
 helps['monitor log-analytics workspace recover'] = """
 type: command
 short-summary: Recover a workspace in a soft-delete state within 14 days.
@@ -939,46 +797,6 @@ examples:
     text: az monitor log-analytics workspace linked-storage remove --type AzureWatson -g MyResourceGroup --workspace-name MyWorkspace --storage-accounts /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/clitest.rg000001/providers/Microsoft.Storage/storageAccounts/cli000001
 """
 
-helps['monitor log-profiles'] = """
-type: group
-short-summary: Manage log profiles.
-"""
-
-helps['monitor log-profiles create'] = """
-type: command
-short-summary: Create a log profile.
-parameters:
-  - name: --name -n
-    short-summary: The name of the log profile.
-  - name: --locations
-    short-summary: Space-separated list of regions for which Activity Log events should be stored.
-  - name: --categories
-    short-summary: Space-separated categories of the logs. These categories are created as is convenient to the user. Some values are Write, Delete, and/or Action.
-  - name: --storage-account-id
-    short-summary: The resource id of the storage account to which you would like to send the Activity Log.
-  - name: --service-bus-rule-id
-    short-summary: The service bus rule ID of the service bus namespace in which you would like to have Event Hubs created for streaming the Activity Log. The rule ID is of the format '{service bus resource ID}/authorizationrules/{key name}'.
-  - name: --days
-    short-summary: The number of days for the retention in days. A value of 0 will retain the events indefinitely
-  - name: --enabled
-    short-summary: Whether the retention policy is enabled.
-examples:
-  - name: Create a log profile. (autogenerated)
-    text: |
-        az monitor log-profiles create --categories "Delete" --days 0 --enabled true --location westus2 --locations westus --name MyLogProfile --service-bus-rule-id "/subscriptions/{YOUR SUBSCRIPTION ID}/resourceGroups/{RESOURCE GROUP NAME}/providers/Microsoft.EventHub/namespaces/{EVENT HUB NAME SPACE}/authorizationrules/RootManageSharedAccessKey"
-    crafted: true
-"""
-
-helps['monitor log-profiles update'] = """
-type: command
-short-summary: Update a log profile.
-examples:
-  - name: Update a log profile. (autogenerated)
-    text: |
-        az monitor log-profiles update --name MyLogProfile --set retentionPolicy.days=365
-    crafted: true
-"""
-
 helps['monitor metrics'] = """
 type: group
 short-summary: View Azure resource metrics.
