@@ -7,9 +7,11 @@ from ..aaz.latest.monitor.diagnostic_settings import Create as _DiagnosticSettin
 from ..aaz.latest.monitor.diagnostic_settings import List as _DiagnosticSettingsList
 from ..aaz.latest.monitor.diagnostic_settings import Show as _DiagnosticSettingsShow
 from ..aaz.latest.monitor.diagnostic_settings import Delete as _DiagnosticSettingsDelete
+from ..aaz.latest.monitor.diagnostic_settings import Update as _DiagnosticSettingsUpdate
 from ..aaz.latest.monitor.diagnostic_settings.categories import List as _DiagnosticSettingsCategoryList
 from ..aaz.latest.monitor.diagnostic_settings.categories import Show as _DiagnosticSettingsCategoryShow
 from knack.util import CLIError
+from azure.cli.core.azclierror import ArgumentUsageError
 
 
 def create_resource_parameters(arg_schema, arg_group=None):
@@ -95,7 +97,7 @@ class DiagnosticSettingsCreate(_DiagnosticSettingsCreate):
         rg = args.resource_group_name.to_serialized_data()
 
         if not has_value(rg):
-            rg = parse_resource_id(ctx.resource)['resource_group']
+            rg = parse_resource_id(args.resource.to_serialized_data())['resource_group']
             args.resource_group_name = rg
 
         storage_account = args.storage_account.to_serialized_data()
@@ -149,6 +151,8 @@ class DiagnosticSettingsCreate(_DiagnosticSettingsCreate):
         export_to_resource_specific = args.export_to_resource_specific.to_serialized_data()
         if has_value(export_to_resource_specific) and export_to_resource_specific:
             args.log_analytics_destination_type = 'Dedicated'
+            if not has_value(workspace):
+                raise ArgumentUsageError('usage error: --workspace and --export-to-specific-resource')
         else:
             args.log_analytics_destination_type = None
 
@@ -192,6 +196,19 @@ class DiagnosticSettingsDelete(_DiagnosticSettingsDelete):
         update_resource_parameters(ctx)
 
 
+class DiagnosticSettingsUpdate(_DiagnosticSettingsUpdate):
+
+    @classmethod
+    def _build_arguments_schema(cls, *args, **kwargs):
+        arg_schema = super()._build_arguments_schema(*args, **kwargs)
+        create_resource_parameters(arg_schema, arg_group="Target Resource")
+        return arg_schema
+
+    def pre_operations(self):
+        ctx = self.ctx
+        update_resource_parameters(ctx)
+
+
 class DiagnosticSettingsCategoryList(_DiagnosticSettingsCategoryList):
     @classmethod
     def _build_arguments_schema(cls, *args, **kwargs):
