@@ -4,7 +4,9 @@
 # --------------------------------------------------------------------------------------------
 
 from azure.cli.testsdk import ScenarioTest, ResourceGroupPreparer, StorageAccountPreparer, live_only
-import mock
+from azure.cli.testsdk.constants import AUX_SUBSCRIPTION
+from unittest import mock
+import unittest
 from msrestazure.tools import resource_id
 
 
@@ -32,7 +34,7 @@ class MonitorCloneVMScenarios(ScenarioTest):
             'vm3_id': vm3_json['id']
         })
         self.cmd('monitor action-group create -g {rg} -n {ag1}')
-        self.cmd('monitor metrics alert create -g {rg} -n {alert} --scopes {vm1_id} {vm2_id} --action {ag1} --condition "avg Percentage CPU > 90" --description "High CPU"', checks=[
+        self.cmd('monitor metrics alert create -g {rg} -n {alert} --scopes {vm1_id} {vm2_id} --action {ag1} --region eastus --condition "avg Percentage CPU > 90" --description "High CPU"', checks=[
             self.check('description', 'High CPU'),
             self.check('severity', 2),
             self.check('autoMitigate', None),
@@ -76,7 +78,7 @@ class MonitorCloneStorageAccountScenarios(ScenarioTest):
         })
 
         self.cmd('monitor action-group create -g {rg} -n {ag1}')
-        self.cmd('monitor metrics alert create -g {rg} -n {alert} --scopes {sa_id} --action {ag1} --description "Test" --condition "total transactions > 5 where ResponseType includes Success and ApiName includes GetBlob" --condition "avg SuccessE2ELatency > 250 where ApiName includes GetBlob"', checks=[
+        self.cmd('monitor metrics alert create -g {rg} -n {alert} --scopes {sa_id} --region westus --action {ag1} --description "Test" --condition "total transactions > 5 where ResponseType includes Success and ApiName includes GetBlob" --condition "avg SuccessE2ELatency > 250 where ApiName includes GetBlob"', checks=[
             self.check('description', 'Test'),
             self.check('severity', 2),
             self.check('autoMitigate', None),
@@ -125,7 +127,7 @@ class MonitorCloneStorageAccountAlwaysScenarios(ScenarioTest):
         })
 
         self.cmd('monitor action-group create -g {rg} -n {ag1}')
-        self.cmd('monitor metrics alert create -g {rg} -n {alert} --scopes {sa_id} --action {ag1} --description "Test" --condition "total transactions > 5 where ResponseType includes Success and ApiName includes GetBlob" --condition "avg SuccessE2ELatency > 250 where ApiName includes GetBlob"', checks=[
+        self.cmd('monitor metrics alert create -g {rg} -n {alert} --scopes {sa_id} --region westus --action {ag1} --description "Test" --condition "total transactions > 5 where ResponseType includes Success and ApiName includes GetBlob" --condition "avg SuccessE2ELatency > 250 where ApiName includes GetBlob"', checks=[
             self.check('description', 'Test'),
             self.check('severity', 2),
             self.check('autoMitigate', None),
@@ -170,7 +172,7 @@ class MonitorClonePublicIpScenarios(ScenarioTest):
         })
 
         self.cmd('monitor action-group create -g {rg} -n {ag1}')
-        self.cmd('monitor metrics alert create -g {rg} -n {alert} --scopes {ip1_id} --action {ag1} --description "Test" --condition "total TCPBytesForwardedDDoS > 5"', checks=[
+        self.cmd('monitor metrics alert create -g {rg} -n {alert} --scopes {ip1_id} --region westus --action {ag1} --description "Test" --condition "total TCPBytesForwardedDDoS > 5"', checks=[
             self.check('description', 'Test'),
             self.check('severity', 2),
             self.check('windowSize', '0:05:00'),
@@ -178,7 +180,7 @@ class MonitorClonePublicIpScenarios(ScenarioTest):
             self.check('length(scopes)', 1)
         ])
 
-        self.cmd('monitor metrics alert create -g {rg} -n {alert2} --scopes {ip1_id} --action {ag1} --description "Test2" --condition "max TCPBytesForwardedDDoS > 5"', checks=[
+        self.cmd('monitor metrics alert create -g {rg} -n {alert2} --scopes {ip1_id} --region westus --action {ag1} --description "Test2" --condition "max TCPBytesForwardedDDoS > 5"', checks=[
             self.check('description', 'Test2'),
             self.check('severity', 2),
             self.check('windowSize', '0:05:00'),
@@ -193,20 +195,22 @@ class MonitorClonePublicIpScenarios(ScenarioTest):
 
 
 class MonitorCloneStorageAccountAcrossSubsScenarios(ScenarioTest):
-    @live_only()
+    @unittest.skip('Accross subs are not supported now.')
+    # @live_only()
     @ResourceGroupPreparer(name_prefix='cli_test_metric_alert_clone')
-    def test_monitor_clone_storage_metric_alerts_across_subs_scenario(self, resource_group):
+    @ResourceGroupPreparer(name_prefix='cli_test_metric_alert_clone',
+                           parameter_name='another_resource_group', subscription=AUX_SUBSCRIPTION)
+    def test_monitor_clone_storage_metric_alerts_across_subs_scenario(self, resource_group, another_resource_group):
         self.kwargs.update({
             'alert': 'alert1',
             'sa': self.create_random_name('sa', 24),
             'sa2': self.create_random_name('sa', 24),
             'ag1': 'ag1',
             'rg': resource_group,
-            'ext_sub': '1c638cf4-608f-4ee6-b680-c329e824c3a8',
-            'ext_rg': self.create_random_name('test_rg', 24),
+            'ext_sub': AUX_SUBSCRIPTION,
+            'ext_rg': another_resource_group,
         })
 
-        self.cmd('group create -l eastus -n {ext_rg} --subscription {ext_sub}')
         sa1_json = self.cmd('storage account create -n {sa} -g {ext_rg} -l eastus --sku Standard_LRS --kind Storage --subscription {ext_sub}').get_output_in_json()
         sa2_json = self.cmd('storage account create -n {sa2} -g {rg} -l eastus --sku Standard_LRS --kind Storage').get_output_in_json()
         self.kwargs.update({
