@@ -19,7 +19,8 @@ from azure.cli.command_modules.netappfiles._client_factory import (
     vaults_mgmt_client_factory,
     subvolumes_mgmt_client_factory,
     volume_groups_mgmt_client_factory,
-    netapp_resource_mgmt_client_factory)
+    netapp_resource_mgmt_client_factory,
+    volume_quota_rules_mgmt_client_factory)
 
 from azure.cli.command_modules.netappfiles._exception_handler import netappfiles_exception_handler
 
@@ -109,6 +110,13 @@ def load_command_table(self, _):
     )
     load_net_app_resource_command_groups(self, netappfiles_resource_sdk)
 
+    netappfiles_volume_quota_rules_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.netapp.operations._volume_quota_rules_operations#VolumeQuotaRulesOperations.{}',
+        client_factory=volume_quota_rules_mgmt_client_factory,
+        exception_handler=netappfiles_exception_handler
+    )
+    load_volume_quota_rules_command_group(self, netappfiles_volume_quota_rules_sdk)
+
     with self.command_group('netappfiles', is_preview=False):
         pass
 
@@ -386,4 +394,24 @@ def load_volume_groups_command_groups(self, netappfiles_volume_groups_sdk):
 
 def load_net_app_resource_command_groups(self, netappfiles_resource_sdk):
     with self.command_group('netappfiles resource', netappfiles_resource_sdk) as g:
-        g.command('query-region-info', 'query_region_info', supports_no_wait=True)
+        g.command('query-region-info', 'query_region_info')
+
+
+def load_volume_quota_rules_command_group(self, netappfiles_volume_quota_rules_sdk):
+    with self.command_group('netappfiles volume quota-rule', netappfiles_volume_quota_rules_sdk) as g:
+        g.show_command('show', 'get')
+        g.command('list', 'list_by_volume')
+        g.custom_command('create', 'create_volume_quota_rule',
+                         client_factory=volume_quota_rules_mgmt_client_factory,
+                         supports_no_wait=True,
+                         doc_string_source='azure.mgmt.netapp.models#VolumeQuotaRule',
+                         exception_handler=netappfiles_exception_handler)
+        g.generic_update_command('update',
+                                 setter_name='begin_update',
+                                 custom_func_name='update_volume_quota_rule',
+                                 supports_no_wait=True,
+                                 setter_arg_name='body',
+                                 doc_string_source='azure.mgmt.netapp.models#VolumeQuotaRulePatch',
+                                 exception_handler=netappfiles_exception_handler)
+        g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
+        g.wait_command('wait')
