@@ -20,10 +20,6 @@ def cf_application_gateways(cli_ctx, _):
     return network_client_factory(cli_ctx).application_gateways
 
 
-def cf_app_gateway_waf_policy(cli_ctx, _):
-    return network_client_factory(cli_ctx).web_application_firewall_policies
-
-
 def cf_connection_monitor(cli_ctx, _):
     return network_client_factory(cli_ctx).connection_monitors
 
@@ -32,18 +28,6 @@ def cf_flow_logs(cli_ctx, _):
     return network_client_factory(cli_ctx).flow_logs
 
 
-def cf_private_endpoints(cli_ctx, _):
-    return network_client_factory(cli_ctx).private_endpoints
-
-
-def cf_private_dns_zone_groups(cli_ctx, _):
-    return network_client_factory(cli_ctx).private_dns_zone_groups
-
-
-def cf_private_endpoint_types(cli_ctx, _):
-    return network_client_factory(cli_ctx).available_private_endpoint_types
-
-
 def cf_private_link_services(cli_ctx, _):
     return network_client_factory(cli_ctx).private_link_services
 
@@ -76,10 +60,6 @@ def cf_private_access(cli_ctx, _):
     return network_client_factory(cli_ctx).available_private_access_services
 
 
-def cf_public_ip_addresses(cli_ctx, _):
-    return network_client_factory(cli_ctx).public_ip_addresses
-
-
 def cf_virtual_network_gateway_connections(cli_ctx, _):
     return network_client_factory(cli_ctx).virtual_network_gateway_connections
 
@@ -116,7 +96,3 @@ def cf_virtual_hub(cli_ctx, _):
 
 def cf_virtual_router_peering(cli_ctx, _):
     return network_client_factory(cli_ctx).virtual_router_peerings
-
-
-def cf_bastion_hosts(cli_ctx, _):
-    return network_client_factory(cli_ctx).bastion_hosts
