@@ -7,8 +7,7 @@ from msrestazure.tools import is_valid_resource_id, resource_id
 
 from azure.cli.core.commands.client_factory import get_subscription_id
 from azure.cli.core.util import sdk_no_wait
-
-from knack.util import CLIError
+from azure.cli.core.azclierror import ResourceNotFoundError, ArgumentUsageError
 
 
 def list_policy_events(
@@ -69,8 +68,10 @@ def list_policy_events(
     elif resource:
         if not is_valid_resource_id(resource):
             if resource_type_parent:
-                resource_type_parent = _remove_leading_and_trailing_slash(resource_type_parent)
-                resource_type = "{}/{}".format(resource_type_parent, resource_type)
+                resource_type_parent = _remove_leading_and_trailing_slash(
+                    resource_type_parent)
+                resource_type = "{}/{}".format(resource_type_parent,
+                                               resource_type)
             resource = resource_id(
                 subscription=subscription_id,
                 resource_group=resource_group_name,
@@ -166,8 +167,10 @@ def list_policy_states(
     elif resource:
         if not is_valid_resource_id(resource):
             if resource_type_parent:
-                resource_type_parent = _remove_leading_and_trailing_slash(resource_type_parent)
-                resource_type = "{}/{}".format(resource_type_parent, resource_type)
+                resource_type_parent = _remove_leading_and_trailing_slash(
+                    resource_type_parent)
+                resource_type = "{}/{}".format(resource_type_parent,
+                                               resource_type)
             resource = resource_id(
                 subscription=subscription_id,
                 resource_group=resource_group_name,
@@ -424,7 +427,7 @@ def create_policy_remediation(
         resource_discovery_mode=None):
 
     subscription_id = get_subscription_id(cmd.cli_ctx)
-    scope = _build_remediation_scope(
+    scope = _build_policy_object_scope(
         management_group_name,
         subscription_id,
         resource_group_name,
@@ -434,22 +437,12 @@ def create_policy_remediation(
         namespace)
 
     from azure.mgmt.policyinsights.models import Remediation
-    remediation = Remediation(policy_definition_reference_id=definition_reference_id)
+    remediation = Remediation(
+        policy_definition_reference_id=definition_reference_id)
 
     # Get the full resource ID of the referenced policy assignment
-    if (not is_valid_resource_id(policy_assignment) and
-            not policy_assignment.lower().startswith("/providers/microsoft.management/managementgroups/")):
-        from ._client_factory import cf_policy
-        policy_assignment_client = cf_policy(cmd.cli_ctx).policy_assignments
-        policy_assignments = policy_assignment_client.list()
-        policy_assignment_ids = [p.id for p in policy_assignments if p.name.lower() == policy_assignment.lower()]
-        if not policy_assignment_ids:
-            raise CLIError("No policy assignment with the name '{}' found.".format(policy_assignment))
-        if len(policy_assignment_ids) > 1:
-            raise CLIError("Multiple policy assignment with the name '{}' found. "
-                           "Specify the policy assignment ID.".format(policy_assignment))
-        policy_assignment = policy_assignment_ids[0]
-    remediation.policy_assignment_id = policy_assignment
+    remediation.policy_assignment_id = _get_policy_assignment_id(
+        cmd, policy_assignment=policy_assignment)
 
     # Ensure locations in the location filters are using their short name
     if location_filters:
@@ -483,11 +476,182 @@ def list_policy_metadata(cmd, client, top_value=None):   # pylint: disable=unuse
                 results += list(next(page_iter))
             except StopIteration:
                 break
-
         return results[:top_value]
-
     return list(client.list())
 
+# pylint: disable=no-else-return
+
+
+def create_policy_attestation(
+        cmd,
+        attestation_name,
+        policy_assignment_id,
+        assessment_date=None,
+        comments=None,
+        compliance_state=None,
+        evidence=None,
+        expires_on=None,
+        metadata=None,
+        owner=None,
+        definition_reference_id=None,
+        namespace=None,
+        resource=None,
+        resource_group_name=None,
+        resource_type_parent=None,
+        resource_type=None):
+
+    policy_assignment_id = _get_policy_assignment_id(
+        cmd, policy_assignment=policy_assignment_id)
+    attestation_args = {
+        "attestation_name": attestation_name,
+        "policy_assignment_id": policy_assignment_id,
+        "assessment_date": assessment_date,
+        "comments": comments,
+        "compliance_state": compliance_state,
+        "evidence": evidence,
+        "expires_on": expires_on,
+        "metadata": metadata,
+        "owner": owner,
+        "policy_definition_reference_id": definition_reference_id
+    }
+    from .aaz.latest.policy_insights.attestation import Create, CreateByRg, CreateBySubscription
+
+    if resource:
+        subscription_id = get_subscription_id(cmd.cli_ctx)
+        scope = _build_policy_object_scope(
+            subscription=subscription_id,
+            resource_group_name=resource_group_name,
+            resource=resource,
+            resource_type_parent=resource_type_parent,
+            resource_type=resource_type,
+            namespace=namespace)
+        attestation_args["resource_id"] = scope
+        return Create(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+    elif resource_group_name:
+        attestation_args["resource_group"] = resource_group_name
+        return CreateByRg(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+    else:
+        return CreateBySubscription(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+
+# pylint: disable=no-else-return
+
+
+def update_policy_attestation(
+        cmd,
+        attestation_name,
+        policy_assignment_id=None,
+        assessment_date=None,
+        comments=None,
+        compliance_state=None,
+        evidence=None,
+        expires_on=None,
+        metadata=None,
+        owner=None,
+        definition_reference_id=None,
+        namespace=None,
+        resource=None,
+        resource_group_name=None,
+        resource_type_parent=None,
+        resource_type=None):
+
+    attestation_args = {
+        "attestation_name": attestation_name,
+        "policy_assignment_id": policy_assignment_id,
+        "assessment_date": assessment_date,
+        "comments": comments,
+        "compliance_state": compliance_state,
+        "evidence": evidence,
+        "expires_on": expires_on,
+        "metadata": metadata,
+        "owner": owner,
+        "policy_definition_reference_id": definition_reference_id
+    }
+    from .aaz.latest.policy_insights.attestation import Update, UpdateByRg, UpdateBySubscription
+
+    if resource:
+        subscription_id = get_subscription_id(cmd.cli_ctx)
+        scope = _build_policy_object_scope(
+            subscription=subscription_id,
+            resource_group_name=resource_group_name,
+            resource=resource,
+            resource_type_parent=resource_type_parent,
+            resource_type=resource_type,
+            namespace=namespace)
+        attestation_args["resource_id"] = scope
+        return Update(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+    elif resource_group_name:
+        attestation_args["resource_group"] = resource_group_name
+        return UpdateByRg(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+    else:
+        return UpdateBySubscription(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+
+# pylint: disable=no-else-return
+
+
+def delete_policy_attestation(
+    cmd,
+    attestation_name,
+    namespace=None,
+    resource=None,
+    resource_group_name=None,
+    resource_type_parent=None,
+    resource_type=None
+):
+
+    attestation_args = {
+        "attestation_name": attestation_name,
+    }
+
+    subscription_id = get_subscription_id(cmd.cli_ctx)
+
+    from .aaz.latest.policy_insights.attestation import Delete, DeleteByRg, DeleteBySubscription
+    if resource:
+        scope = _build_policy_object_scope(
+            subscription=subscription_id,
+            resource_group_name=resource_group_name,
+            resource=resource,
+            resource_type_parent=resource_type_parent,
+            resource_type=resource_type,
+            namespace=namespace)
+        attestation_args["resource_id"] = scope
+        return Delete(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+    elif resource_group_name:
+        attestation_args["resource_group"] = resource_group_name
+        return DeleteByRg(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+    else:
+        return DeleteBySubscription(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+
+
+def show_policy_attestation(
+    cmd,
+    attestation_name,
+    namespace=None,
+    resource=None,
+    resource_group_name=None,
+    resource_type_parent=None,
+    resource_type=None
+):
+    attestation_args = {
+        "attestation_name": attestation_name,
+    }
+    from .aaz.latest.policy_insights.attestation import Show, ShowByRg, ShowBySubscription
+    if resource:
+        subscription_id = get_subscription_id(cmd.cli_ctx)
+        scope = _build_policy_object_scope(
+            subscription=subscription_id,
+            resource_group_name=resource_group_name,
+            resource=resource,
+            resource_type_parent=resource_type_parent,
+            resource_type=resource_type,
+            namespace=namespace)
+        attestation_args["resource_id"] = scope
+        return Show(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+    elif resource_group_name:
+        attestation_args["resource_group"] = resource_group_name
+        return ShowByRg(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+    else:
+        return ShowBySubscription(cli_ctx=cmd.cli_ctx)(command_args=attestation_args)
+
 
 def _execute_remediation_operation(
         cmd,
@@ -502,7 +666,7 @@ def _execute_remediation_operation(
         remediation_name=None):
 
     subscription_id = get_subscription_id(cmd.cli_ctx)
-    scope = _build_remediation_scope(
+    scope = _build_policy_object_scope(
         management_group_name,
         subscription_id,
         resource_group_name,
@@ -527,7 +691,8 @@ def _build_resource_id(
 
     if not is_valid_resource_id(resource):
         if resource_type_parent:
-            resource_type_parent = _remove_leading_and_trailing_slash(resource_type_parent)
+            resource_type_parent = _remove_leading_and_trailing_slash(
+                resource_type_parent)
             resource_type = "{}/{}".format(resource_type_parent, resource_type)
 
         resource = resource_id(
@@ -540,7 +705,7 @@ def _build_resource_id(
     return resource
 
 
-def _build_remediation_scope(
+def _build_policy_object_scope(
         management_group=None,
         subscription=None,
         resource_group_name=None,
@@ -565,3 +730,21 @@ def _remove_leading_and_trailing_slash(s):
             s = s[:-1]
 
     return s
+
+
+def _get_policy_assignment_id(cmd, policy_assignment):
+    # Get the full resource ID of the referenced policy assignment
+    if (not is_valid_resource_id(policy_assignment) and
+            not policy_assignment.lower().startswith("/providers/microsoft.management/managementgroups/")):
+        from ._client_factory import cf_policy
+        policy_assignment_client = cf_policy(cmd.cli_ctx).policy_assignments
+        policy_assignments = policy_assignment_client.list()
+        policy_assignment_ids = [
+            p.id for p in policy_assignments if p.name.lower() == policy_assignment.lower()]
+        if not policy_assignment_ids:
+            raise ResourceNotFoundError(
+                "No policy assignment with the name '{}' found.".format(policy_assignment))
+        if len(policy_assignment_ids) > 1:
+            raise ArgumentUsageError("Multiple policy assignment with the name '{}' found. "
+                                     "Specify the policy assignment ID.".format(policy_assignment))
+        return policy_assignment_ids[0]
