@@ -73,11 +73,6 @@ class ProfileCommandsLoader(AzCommandsLoader):
             c.argument('refresh', help="retrieve up-to-date subscriptions from server", action='store_true')
             c.ignore('_subscription')  # hide the global subscription parameter
 
-        with self.argument_context('account show') as c:
-            c.argument('show_auth_for_sdk', options_list=['--sdk-auth'], action='store_true',
-                       deprecate_info=c.deprecate(target='--sdk-auth'),
-                       help='Output result to a file compatible with Azure SDK auth. Only applicable when authenticating with a Service Principal.')
-
         with self.argument_context('account get-access-token') as c:
             c.argument('resource_type', get_enum_type(cloud_resource_types), options_list=['--resource-type'], arg_group='', help='Type of well-known resource.')
             c.argument('resource', options_list=['--resource'], help='Azure resource endpoints in AAD v1.0.')
