@@ -119,7 +119,7 @@ class ServerMgmtScenarioTest(ScenarioTest):
         geoloc = 'eastus'
 
         if self.cli_ctx.local_context.is_on:
-            self.cmd('local-context off')
+            self.cmd('config param-persist off')
 
         list_checks = [JMESPathCheck('name', servers[0]),
                        JMESPathCheck('resourceGroup', resource_group_1),
