@@ -14,14 +14,16 @@ allowed_p_family_sizes = ['p1', 'p2', 'p3', 'p4', 'p5']
 wrong_vmsize_error = CLIError('Invalid VM size. Example for Valid values: '
                               'For Standard Sku : (C0, C1, C2, C3, C4, C5, C6), '
                               'for Premium Sku : (P1, P2, P3, P4, P5)')
-
+allowed_auth_methods = ['SAS', 'ManagedIdentity']
 # region Custom Commands
 
 
 # pylint: disable=unused-argument
-def cli_redis_export(cmd, client, resource_group_name, name, prefix, container, file_format=None):
+def cli_redis_export(cmd, client, resource_group_name, name, prefix, container,
+                     preferred_data_archive_auth_method=None, file_format=None):
     from azure.mgmt.redis.models import ExportRDBParameters
-    parameters = ExportRDBParameters(prefix=prefix, container=container, format=file_format)
+    parameters = ExportRDBParameters(prefix=prefix, container=container, format=file_format,
+                                     preferred_data_archive_auth_method=preferred_data_archive_auth_method)
     return client.begin_export_data(resource_group_name, name, parameters)
 
 
@@ -72,6 +74,11 @@ def cli_redis_update(cmd, instance, sku=None, vm_size=None):
     return update_params
 
 
+def custom_update_setter(client, resource_group_name, name, parameters):
+    # Custom update setter is used to match behavior from when update was not a LRO
+    return client.begin_update(resource_group_name, name, parameters).result(0)
+
+
 # pylint: disable=unused-argument
 # pylint: disable=too-many-locals
 def cli_redis_create(cmd, client,
@@ -178,9 +185,11 @@ def cli_redis_regenerate_key(client, resource_group_name, name, key_type):
     return client.regenerate_key(resource_group_name, name, RedisRegenerateKeyParameters(key_type=key_type))
 
 
-def cli_redis_import(client, resource_group_name, name, files, file_format=None):
+def cli_redis_import(client, resource_group_name, name, files,
+                     preferred_data_archive_auth_method=None, file_format=None):
     from azure.mgmt.redis.models import ImportRDBParameters
-    return client.begin_import_data(resource_group_name, name, ImportRDBParameters(files=files, format=file_format))
+    return client.begin_import_data(resource_group_name, name, ImportRDBParameters(files=files, format=file_format,
+                                    preferred_data_archive_auth_method=preferred_data_archive_auth_method))
 
 
 def cli_redis_force_reboot(client, resource_group_name, name, reboot_type, shard_id=None):
@@ -214,7 +223,7 @@ def cli_redis_identity_assign(client, resource_group_name, cache_name, mi_system
                 mi_user_assigned.append(user_id)
     update_params = RedisUpdateParameters(
         identity=build_identity(mi_system_assigned, mi_user_assigned))
-    redis_resourse = client.update(resource_group_name, cache_name, update_params)
+    redis_resourse = client.begin_update(resource_group_name, cache_name, update_params).result()
     return redis_resourse.identity
 
 
@@ -246,7 +255,7 @@ def cli_redis_identity_remove(client, resource_group_name, cache_name, mi_system
     update_params = RedisUpdateParameters(
         identity=build_identity(system_assigned, user_assigned)
     )
-    updated_resourse = client.update(resource_group_name, cache_name, update_params)
+    updated_resourse = client.begin_update(resource_group_name, cache_name, update_params).result()
     if updated_resourse.identity is None:
         updated_resourse.identity = none_identity
     return updated_resourse.identity
