@@ -4,87 +4,101 @@
 # --------------------------------------------------------------------------------------------
 
 from azure.cli.testsdk import ScenarioTest, record_only
+import pytest
 
-
-@record_only()
 class AzureManagementGroupsScenarioTest(ScenarioTest):
+    
+    def test_list_managementgroups(self):
+        managementgroups_list = self.cmd(
+            'account management-group list').get_output_in_json()
+        self.assertIsNotNone(managementgroups_list)
+        self.assertTrue(len(managementgroups_list) > 0)
+        self.assertIsNotNone(managementgroups_list[0]["displayName"])
+        self.assertTrue(managementgroups_list[0]["id"].startswith(
+            "/providers/Microsoft.Management/managementGroups/"))
+        self.assertIsNotNone(managementgroups_list[0]["name"])
+        self.assertIsNotNone(managementgroups_list[0]["tenantId"])
+        self.assertEqual(
+            managementgroups_list[0]["type"],
+            "Microsoft.Management/managementGroups")
+
     def test_show_managementgroup(self):
-        self.cmd('account management-group create --name testcligetgroup1')
-        self.cmd('account management-group create --name testcligetgroup2 --parent /providers/Microsoft.Management/managementGroups/testcligetgroup1')
+        self.cmd('account management-group create --name testcligetgroup')
+        self.cmd('account management-group create --name testcligetgroup1 --parent /providers/Microsoft.Management/managementGroups/testcligetgroup')
         managementgroup_get = self.cmd(
-            'account management-group show --name testcligetgroup2').get_output_in_json()
-        self.cmd('account management-group delete --name testcligetgroup2')
+            'account management-group show --name testcligetgroup1').get_output_in_json()
         self.cmd('account management-group delete --name testcligetgroup1')
+        self.cmd('account management-group delete --name testcligetgroup')
 
         self.assertIsNotNone(managementgroup_get)
         self.assertIsNone(managementgroup_get["children"])
         self.assertIsNotNone(managementgroup_get["details"])
         self.assertEqual(
             managementgroup_get["id"],
-            "/providers/Microsoft.Management/managementGroups/testcligetgroup2")
-        self.assertEqual(managementgroup_get["name"], "testcligetgroup2")
+            "/providers/Microsoft.Management/managementGroups/testcligetgroup1")
+        self.assertEqual(managementgroup_get["name"], "testcligetgroup1")
         self.assertEqual(
             managementgroup_get["displayName"],
-            "testcligetgroup2")
+            "testcligetgroup1")
         self.assertEqual(
             managementgroup_get["details"]["parent"]["displayName"],
-            "testcligetgroup1")
+            "testcligetgroup")
         self.assertEqual(
             managementgroup_get["details"]["parent"]["id"],
-            "/providers/Microsoft.Management/managementGroups/testcligetgroup1")
+            "/providers/Microsoft.Management/managementGroups/testcligetgroup")
         self.assertEqual(
             managementgroup_get["details"]["parent"]["name"],
-            "testcligetgroup1")
+            "testcligetgroup")
         self.assertIsNotNone(managementgroup_get["tenantId"])
         self.assertEqual(
             managementgroup_get["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
 
     def test_show_managementgroup_with_expand(self):
-        self.cmd('account management-group create --name testcligetgroup1')
-        self.cmd('account management-group create --name testcligetgroup2 --parent testcligetgroup1')
-        self.cmd('account management-group create --name testcligetgroup3 --parent /providers/Microsoft.Management/managementGroups/testcligetgroup2')
+        self.cmd('account management-group create --name testcligetgroup')
+        self.cmd('account management-group create --name testcligetgroup1 --parent testcligetgroup')
+        self.cmd('account management-group create --name testcligetgroup2 --parent /providers/Microsoft.Management/managementGroups/testcligetgroup1')
         managementgroup_get = self.cmd(
-            'account management-group show --name testcligetgroup2 --expand').get_output_in_json()
-        self.cmd('account management-group delete --name testcligetgroup3')
+            'account management-group show --name testcligetgroup1 --expand').get_output_in_json()
         self.cmd('account management-group delete --name testcligetgroup2')
         self.cmd('account management-group delete --name testcligetgroup1')
+        self.cmd('account management-group delete --name testcligetgroup')
 
         self.assertIsNotNone(managementgroup_get)
         self.assertIsNotNone(managementgroup_get["children"])
         self.assertIsNotNone(managementgroup_get["details"])
         self.assertEqual(
             managementgroup_get["id"],
-            "/providers/Microsoft.Management/managementGroups/testcligetgroup2")
-        self.assertEqual(managementgroup_get["name"], "testcligetgroup2")
+            "/providers/Microsoft.Management/managementGroups/testcligetgroup1")
+        self.assertEqual(managementgroup_get["name"], "testcligetgroup1")
         self.assertEqual(
             managementgroup_get["displayName"],
-            "testcligetgroup2")
+            "testcligetgroup1")
         self.assertEqual(
             managementgroup_get["details"]["parent"]["displayName"],
-            "testcligetgroup1")
+            "testcligetgroup")
         self.assertEqual(
             managementgroup_get["details"]["parent"]["id"],
-            "/providers/Microsoft.Management/managementGroups/testcligetgroup1")
+            "/providers/Microsoft.Management/managementGroups/testcligetgroup")
         self.assertEqual(
             managementgroup_get["details"]["parent"]["name"],
-            "testcligetgroup1")
+            "testcligetgroup")
         self.assertIsNotNone(managementgroup_get["tenantId"])
         self.assertEqual(
             managementgroup_get["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
         self.assertEqual(
             managementgroup_get["children"][0]["id"],
-            "/providers/Microsoft.Management/managementGroups/testcligetgroup3")
+            "/providers/Microsoft.Management/managementGroups/testcligetgroup2")
         self.assertEqual(
             managementgroup_get["children"][0]["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
         self.assertEqual(
             managementgroup_get["children"][0]["displayName"],
-            "testcligetgroup3")
+            "testcligetgroup2")
         self.assertEqual(
             managementgroup_get["children"][0]["name"],
-            "testcligetgroup3")
+            "testcligetgroup2")
 
     def test_show_managementgroup_with_expand_and_recurse(self):
         self.cmd('account management-group create --name testcligetgroup1')
@@ -120,13 +134,13 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
         self.assertIsNotNone(managementgroup_get["tenantId"])
         self.assertEqual(
             managementgroup_get["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
         self.assertEqual(
             managementgroup_get["children"][0]["id"],
             "/providers/Microsoft.Management/managementGroups/testcligetgroup3")
         self.assertEqual(
             managementgroup_get["children"][0]["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
         self.assertEqual(
             managementgroup_get["children"][0]["displayName"],
             "testcligetgroup3")
@@ -138,14 +152,14 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
             "/providers/Microsoft.Management/managementGroups/testcligetgroup4")
         self.assertEqual(
             managementgroup_get["children"][0]["children"][0]["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
         self.assertEqual(
             managementgroup_get["children"][0]["children"][0]["displayName"],
             "testcligetgroup4")
         self.assertEqual(
             managementgroup_get["children"][0]["children"][0]["name"],
             "testcligetgroup4")
-
+    
     def test_create_managementgroup(self):
         name = "testcligroup"
         displayName = "testcligroup"
@@ -155,25 +169,28 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
         self.cmd('account management-group delete --name ' + name)
 
         self.assertIsNotNone(managementgroup_create)
-        self.assertIsNotNone(managementgroup_create["properties"]["details"])
+        self.assertIsNotNone(managementgroup_create["details"])
         self.assertEqual(
             managementgroup_create["id"],
             "/providers/Microsoft.Management/managementGroups/" + name)
         self.assertEqual(managementgroup_create["name"], name)
         self.assertEqual(
-            managementgroup_create["properties"]["displayName"],
+            managementgroup_create["displayName"],
             displayName)
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["id"],
-            "/providers/Microsoft.Management/managementGroups/" +
-            managementgroup_create["properties"]["tenantId"])
+            managementgroup_create["details"]["parent"]["displayName"],
+            "Root Management Group")
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["name"],
-            managementgroup_create["properties"]["tenantId"])
-        self.assertIsNotNone(managementgroup_create["properties"]["tenantId"])
+            managementgroup_create["details"]["parent"]["id"],
+            "/providers/Microsoft.Management/managementGroups/" +
+            managementgroup_create["tenantId"])
+        self.assertEqual(
+            managementgroup_create["details"]["parent"]["name"],
+            managementgroup_create["tenantId"])
+        self.assertIsNotNone(managementgroup_create["tenantId"])
         self.assertEqual(
             managementgroup_create["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
 
     def test_create_managementgroup_with_displayname(self):
         name = "testcligroup"
@@ -186,25 +203,28 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
         self.cmd('account management-group delete --name ' + name)
 
         self.assertIsNotNone(managementgroup_create)
-        self.assertIsNotNone(managementgroup_create["properties"]["details"])
+        self.assertIsNotNone(managementgroup_create["details"])
         self.assertEqual(
             managementgroup_create["id"],
             "/providers/Microsoft.Management/managementGroups/" + name)
         self.assertEqual(managementgroup_create["name"], name)
         self.assertEqual(
-            managementgroup_create["properties"]["displayName"],
+            managementgroup_create["displayName"],
             displayName)
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["id"],
-            "/providers/Microsoft.Management/managementGroups/" +
-            managementgroup_create["properties"]["tenantId"])
+            managementgroup_create["details"]["parent"]["displayName"],
+            "Root Management Group")
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["name"],
-            managementgroup_create["properties"]["tenantId"])
-        self.assertIsNotNone(managementgroup_create["properties"]["tenantId"])
+            managementgroup_create["details"]["parent"]["id"],
+            "/providers/Microsoft.Management/managementGroups/" +
+            managementgroup_create["tenantId"])
+        self.assertEqual(
+            managementgroup_create["details"]["parent"]["name"],
+            managementgroup_create["tenantId"])
+        self.assertIsNotNone(managementgroup_create["tenantId"])
         self.assertEqual(
             managementgroup_create["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
 
     def test_create_managementgroup_with_parentid(self):
         name = "testcligroupchild"
@@ -221,27 +241,27 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
         self.cmd('account management-group delete --name ' + parentName)
 
         self.assertIsNotNone(managementgroup_create)
-        self.assertIsNotNone(managementgroup_create["properties"]["details"])
+        self.assertIsNotNone(managementgroup_create["details"])
         self.assertEqual(
             managementgroup_create["id"],
             "/providers/Microsoft.Management/managementGroups/" + name)
         self.assertEqual(managementgroup_create["name"], name)
         self.assertEqual(
-            managementgroup_create["properties"]["displayName"],
+            managementgroup_create["displayName"],
             displayName)
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["displayName"],
+            managementgroup_create["details"]["parent"]["displayName"],
             parentName)
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["id"],
+            managementgroup_create["details"]["parent"]["id"],
             parentId)
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["name"],
+            managementgroup_create["details"]["parent"]["name"],
             parentName)
-        self.assertIsNotNone(managementgroup_create["properties"]["tenantId"])
+        self.assertIsNotNone(managementgroup_create["tenantId"])
         self.assertEqual(
             managementgroup_create["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
 
     def test_create_managementgroup_with_displayname_and_parentid(self):
         name = "testcligroupchild"
@@ -260,27 +280,27 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
         self.cmd('account management-group delete --name ' + parentName)
 
         self.assertIsNotNone(managementgroup_create)
-        self.assertIsNotNone(managementgroup_create["properties"]["details"])
+        self.assertIsNotNone(managementgroup_create["details"])
         self.assertEqual(
             managementgroup_create["id"],
             "/providers/Microsoft.Management/managementGroups/" + name)
         self.assertEqual(managementgroup_create["name"], name)
         self.assertEqual(
-            managementgroup_create["properties"]["displayName"],
+            managementgroup_create["displayName"],
             displayName)
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["displayName"],
+            managementgroup_create["details"]["parent"]["displayName"],
             parentName)
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["id"],
+            managementgroup_create["details"]["parent"]["id"],
             parentId)
         self.assertEqual(
-            managementgroup_create["properties"]["details"]["parent"]["name"],
+            managementgroup_create["details"]["parent"]["name"],
             parentName)
-        self.assertIsNotNone(managementgroup_create["properties"]["tenantId"])
+        self.assertIsNotNone(managementgroup_create["tenantId"])
         self.assertEqual(
             managementgroup_create["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
 
     def test_update_managementgroup_with_displayname(self):
         name = "testcligroup"
@@ -300,6 +320,9 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
             "/providers/Microsoft.Management/managementGroups/" + name)
         self.assertEqual(managementgroup_update["name"], name)
         self.assertEqual(managementgroup_update["displayName"], displayName)
+        self.assertEqual(
+            managementgroup_update["details"]["parent"]["displayName"],
+            "Root Management Group")
         self.assertEqual(
             managementgroup_update["details"]["parent"]["id"],
             "/providers/Microsoft.Management/managementGroups/" +
@@ -310,7 +333,7 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
         self.assertIsNotNone(managementgroup_update["tenantId"])
         self.assertEqual(
             managementgroup_update["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
 
     def test_update_managementgroup_with_parentid(self):
         name = "testcligroupchild"
@@ -324,6 +347,7 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
             name +
             ' --parent ' +
             parentId).get_output_in_json()
+        print(managementgroup_update)
         self.cmd('account management-group delete --name ' + name)
         self.cmd('account management-group delete --name ' + parentName)
 
@@ -346,7 +370,7 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
         self.assertIsNotNone(managementgroup_update["tenantId"])
         self.assertEqual(
             managementgroup_update["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
 
     def test_update_managementgroup_with_displayname_and_parentid(self):
         name = "testcligroupchild"
@@ -384,7 +408,7 @@ class AzureManagementGroupsScenarioTest(ScenarioTest):
         self.assertIsNotNone(managementgroup_update["tenantId"])
         self.assertEqual(
             managementgroup_update["type"],
-            "/providers/Microsoft.Management/managementGroups")
+            "Microsoft.Management/managementGroups")
 
     def test_create_delete_group_managementgroup(self):
         self.cmd('account management-group create --name testcligroup')
