@@ -690,7 +690,7 @@ examples:
     text: az role assignment create --assignee sp_name --role a_role
   - name: Create role assignment for an assignee with description and condition.
     text: >-
-        az role assignment create --role "Owner" --assignee "Jhon.Doe@Contoso.com"
+        az role assignment create --role "Owner" --assignee "John.Doe@Contoso.com"
         --description "Role assignment foo to check on bar"
         --condition "@Resource[Microsoft.Storage/storageAccounts/blobServices/containers:Name] stringEquals 'foo'"
         --condition-version "2.0"
@@ -699,6 +699,8 @@ examples:
     text: |
         az role assignment create --assignee 00000000-0000-0000-0000-000000000000 --role "Storage Account Key Operator Service Role" --scope $id
     crafted: true
+  - name: Create role assignment with your own assignment name.
+    text: az role assignment create --assignee-object-id 00000000-0000-0000-0000-000000000000 --assignee-principal-type ServicePrincipal --role Reader --scope /subscriptions/00000000-0000-0000-0000-000000000000 --name 00000000-0000-0000-0000-000000000000
 """
 
 
