@@ -9,7 +9,8 @@ from .action import (
     AddSecretAuthInfoAuto,
     AddUserAssignedIdentityAuthInfo,
     AddSystemAssignedIdentityAuthInfo,
-    AddServicePrincipalAuthInfo
+    AddServicePrincipalAuthInfo,
+    AddUserAccountAuthInfo
 )
 # pylint: disable=line-too-long
 
@@ -17,6 +18,7 @@ from .action import (
 # The dict defines the resource types, including both source resources and target resources.
 # The enum value will be used in command name
 class RESOURCE(Enum):
+    Local = 'connection'
     WebApp = 'webapp'
     # `az spring-cloud` migrated to `az spring`
     SpringCloud = 'spring'
@@ -47,14 +49,24 @@ class RESOURCE(Enum):
     WebPubSub = 'webpubsub'
     ConfluentKafka = 'confluent-cloud'
 
+    @classmethod
+    def value_of(cls, value):
+        for _, v in cls.__members__.items():
+            if v.value == value:
+                return v
+
+        raise ValueError(f"'{cls.__name__}' enum not found for '{value}'")
 
 # The dict defines the auth types
+
+
 class AUTH_TYPE(Enum):
     Secret = 'secret'
     SecretAuto = 'secret(auto)'  # secret which don't need user provide name & password
     SystemIdentity = 'system-managed-identity'
     UserIdentity = 'user-managed-identity'
     ServicePrincipalSecret = 'service-principal'
+    UserAccount = 'user-account'
 
 
 # The dict defines the client types
@@ -94,6 +106,7 @@ SOURCE_RESOURCES = {
     RESOURCE.ContainerApp: '/subscriptions/{subscription}/resourceGroups/{source_resource_group}/providers/Microsoft.App/containerApps/{app}'
 }
 
+LOCAL_CONNECTION_RESOURCE = '/subscriptions/{subscriptionId}/resourceGroups/{resource_group}/providers/Microsoft.ServiceLinker/locations/{location}/connectors/{connection_name}'
 
 # The dict defines the resource id pattern of target resources.
 TARGET_RESOURCES = {
@@ -126,6 +139,19 @@ TARGET_RESOURCES = {
 }
 
 
+LOCAL_CONNECTION_PARAMS = {
+    'connection_name': {
+        'options': ['--connection'],
+        'type': str,
+        'help': 'Name of the connection.',
+    },
+    'resource_group_name': {
+        'options': ['--resource-group', '-g'],
+        'help': 'The resource group which contains the connection.'
+    },
+    'location': {
+    }
+}
 # The dict defines the parameters used to position the source resources.
 # The parmaters should include all variables defined in source resource id expect
 # for 'subscription', which will be dealt by CLI core as a default parameter.
@@ -643,6 +669,13 @@ AUTH_TYPE_PARAMS = {
             'help': 'The service principal auth info',
             'action': AddServicePrincipalAuthInfo
         }
+    },
+    AUTH_TYPE.UserAccount: {
+        'user_account_auth_info': {
+            'options': ['--user-account'],
+            'help': 'The local user account auth info',
+            'action': AddUserAccountAuthInfo
+        }
     }
 }
 
@@ -650,6 +683,34 @@ AUTH_TYPE_PARAMS = {
 # The dict defines the supported auth type of each source-target resource pair
 # The first one will be used as the default auth type
 SUPPORTED_AUTH_TYPE = {
+    RESOURCE.Local: {
+        RESOURCE.Postgres: [AUTH_TYPE.Secret, AUTH_TYPE.UserAccount],
+        RESOURCE.PostgresFlexible: [AUTH_TYPE.Secret, AUTH_TYPE.UserAccount],
+        RESOURCE.Mysql: [AUTH_TYPE.Secret],
+        RESOURCE.MysqlFlexible: [AUTH_TYPE.Secret, AUTH_TYPE.UserAccount],
+        RESOURCE.Sql: [AUTH_TYPE.Secret, AUTH_TYPE.UserAccount],
+        RESOURCE.Redis: [AUTH_TYPE.SecretAuto],
+        RESOURCE.RedisEnterprise: [AUTH_TYPE.SecretAuto],
+
+        RESOURCE.CosmosCassandra: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.CosmosGremlin: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.CosmosMongo: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.CosmosTable: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.CosmosSql: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+
+        RESOURCE.StorageBlob: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.StorageQueue: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.StorageFile: [AUTH_TYPE.SecretAuto],
+        RESOURCE.StorageTable: [AUTH_TYPE.SecretAuto],
+
+        RESOURCE.KeyVault: [AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.AppConfig: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.EventHub: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.ServiceBus: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.SignalR: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.WebPubSub: [AUTH_TYPE.SecretAuto, AUTH_TYPE.UserAccount, AUTH_TYPE.ServicePrincipalSecret],
+        RESOURCE.ConfluentKafka: [AUTH_TYPE.Secret],
+    },
     RESOURCE.WebApp: {
         RESOURCE.Postgres: [AUTH_TYPE.Secret, AUTH_TYPE.SystemIdentity],
         RESOURCE.PostgresFlexible: [AUTH_TYPE.Secret, AUTH_TYPE.SystemIdentity],
@@ -981,3 +1042,4 @@ SUPPORTED_CLIENT_TYPE[RESOURCE.SpringCloud] = SUPPORTED_CLIENT_TYPE[RESOURCE.Web
 SUPPORTED_CLIENT_TYPE[RESOURCE.SpringCloudDeprecated] = SUPPORTED_CLIENT_TYPE[RESOURCE.WebApp]
 SUPPORTED_CLIENT_TYPE[RESOURCE.KubernetesCluster] = SUPPORTED_CLIENT_TYPE[RESOURCE.WebApp]
 SUPPORTED_CLIENT_TYPE[RESOURCE.ContainerApp] = SUPPORTED_CLIENT_TYPE[RESOURCE.WebApp]
+SUPPORTED_CLIENT_TYPE[RESOURCE.Local] = SUPPORTED_CLIENT_TYPE[RESOURCE.WebApp]
