@@ -87,8 +87,9 @@ def run_cli_cmd(cmd, retry=0, interval=0, should_retry_func=None):
         if retry:
             time.sleep(interval)
             return run_cli_cmd(cmd, retry - 1, interval)
+        err = output.stderr.decode(encoding='UTF-8', errors='ignore')
         raise CLIInternalError('Command execution failed, command is: '
-                               '{}, error message is: {}'.format(cmd, output.stderr))
+                               '{}, error message is: \n {}'.format(cmd, err))
     try:
         return json.loads(output.stdout.decode(encoding='UTF-8', errors='ignore')) if output.stdout else None
     except ValueError as e:
@@ -325,3 +326,24 @@ def is_packaged_installed(package_name):
     pkg_installed = any((package_name) in d.key.lower()
                         for d in installed_packages)
     return pkg_installed
+
+
+def get_object_id_of_current_user():
+    signed_in_user = run_cli_cmd('az account show').get('user')
+    user_type = signed_in_user.get('type')
+    try:
+        if user_type == 'user':
+            user_info = run_cli_cmd('az ad signed-in-user show')
+            user_object_id = user_info.get('objectId') if user_info.get(
+                'objectId') else user_info.get('id')
+            return user_object_id
+        if user_type == 'servicePrincipal':
+            user_info = run_cli_cmd(
+                f'az ad sp show --id {signed_in_user.get("name")}')
+            user_object_id = user_info.get('id')
+            return user_object_id
+    except CLIInternalError as e:
+        if 'AADSTS530003' in e.error_msg:
+            logger.warning(
+                'Please ask your IT department for help to join this device to Azure Active Directory.')
+        raise e
