@@ -20,10 +20,13 @@ from azure.cli.core.commands.client_factory import get_subscription_id
 from azure.cli.core.azclierror import (
     ValidationError,
     InvalidArgumentValueError,
-    RequiredArgumentMissingError
+    RequiredArgumentMissingError,
 )
 
-from ._utils import run_cli_cmd
+from ._utils import (
+    run_cli_cmd,
+    get_object_id_of_current_user
+)
 from ._resource_config import (
     CLIENT_TYPE,
     RESOURCE,
@@ -834,8 +837,6 @@ def validate_service_state(linker_parameters):
 def get_default_object_id_of_current_user(cmd, namespace):  # pylint: disable=unused-argument
     user_account_auth_info = getattr(namespace, 'user_account_auth_info', None)
     if user_account_auth_info and not user_account_auth_info.get('principal_id', None):
-        user_info = run_cli_cmd('az ad signed-in-user show')
-        user_object_id = user_info.get('objectId') if user_info.get(
-            'objectId') else user_info.get('id')
+        user_object_id = get_object_id_of_current_user()
         user_account_auth_info['principal_id'] = user_object_id
         setattr(namespace, 'user_account_auth_info', user_account_auth_info)
