@@ -32,7 +32,6 @@ from ._utils import (
     set_user_token_header,
     auto_register
 )
-from ._credential_free import enable_mi_for_db_linker
 # pylint: disable=unused-argument,unsubscriptable-object,unsupported-membership-test,too-many-statements,too-many-locals
 
 
@@ -294,6 +293,51 @@ def connection_create(cmd, client,  # pylint: disable=too-many-locals,too-many-s
                       namespace=None,                                        # Resource.EventHub
                       webpubsub=None,                                        # Resource.WebPubSub
                       signalr=None):                                         # Resource.SignalR
+    from ._credential_free import enable_mi_for_db_linker
+
+    return connection_create_func(cmd, client, connection_name, client_type,
+                                  source_resource_group, source_id,
+                                  target_resource_group, target_id,
+                                  secret_auth_info, secret_auth_info_auto,
+                                  user_identity_auth_info, system_identity_auth_info,
+                                  service_principal_auth_info_secret,
+                                  key_vault_id,
+                                  service_endpoint,
+                                  private_endpoint,
+                                  store_in_connection_string,
+                                  new_addon, no_wait,
+                                  # Resource.KubernetesCluster
+                                  cluster, scope, enable_csi,
+                                  enable_mi_for_db_linker=enable_mi_for_db_linker
+                                  )
+
+
+def connection_create_func(cmd, client,  # pylint: disable=too-many-locals,too-many-statements
+                           connection_name=None, client_type=None,
+                           source_resource_group=None, source_id=None,
+                           target_resource_group=None, target_id=None,
+                           secret_auth_info=None, secret_auth_info_auto=None,
+                           user_identity_auth_info=None, system_identity_auth_info=None,
+                           service_principal_auth_info_secret=None,
+                           key_vault_id=None,
+                           service_endpoint=None,
+                           private_endpoint=None,
+                           store_in_connection_string=False,
+                           new_addon=False, no_wait=False,
+                           # Resource.KubernetesCluster
+                           cluster=None, scope=None, enable_csi=False,
+                           site=None,                                             # Resource.WebApp
+                           spring=None, app=None, deployment='default',           # Resource.SpringCloud
+                           # Resource.*Postgres, Resource.*Sql*
+                           server=None, database=None,
+                           vault=None,                                            # Resource.KeyVault
+                           account=None,                                          # Resource.Storage*
+                           key_space=None, graph=None, table=None,                # Resource.Cosmos*,
+                           config_store=None,                                     # Resource.AppConfig
+                           namespace=None,                                        # Resource.EventHub
+                           webpubsub=None,                                        # Resource.WebPubSub
+                           signalr=None,
+                           enable_mi_for_db_linker=None):                                         # Resource.SignalR
 
     if not source_id:
         raise RequiredArgumentMissingError(err_msg.format('--source-id'))
@@ -386,8 +430,10 @@ def connection_create(cmd, client,  # pylint: disable=too-many-locals,too-many-s
                                      'manually and then create the connection.'.format(str(e)))
 
     validate_service_state(parameters)
-    new_auth_info = enable_mi_for_db_linker(cmd, source_id, target_id, auth_info, client_type, connection_name)
-    parameters['auth_info'] = new_auth_info or parameters['auth_info']
+    if enable_mi_for_db_linker:
+        new_auth_info = enable_mi_for_db_linker(
+            cmd, source_id, target_id, auth_info, client_type, connection_name)
+        parameters['auth_info'] = new_auth_info or parameters['auth_info']
     return auto_register(sdk_no_wait, no_wait,
                          client.begin_create_or_update,
                          resource_uri=source_id,
@@ -413,7 +459,42 @@ def local_connection_create(cmd, client,  # pylint: disable=too-many-locals,too-
                             config_store=None,                                     # Resource.AppConfig
                             namespace=None,                                        # Resource.EventHub
                             webpubsub=None,                                        # Resource.WebPubSub
-                            signalr=None):                                         # Resource.SignalR
+                            signalr=None,                                          # Resource.SignalR
+                            ):
+    from ._credential_free import enable_mi_for_db_linker
+
+    return local_connection_create_func(cmd, client, resource_group_name,
+                                        connection_name,
+                                        location,
+                                        client_type,
+                                        target_resource_group, target_id,
+                                        secret_auth_info, secret_auth_info_auto,
+                                        user_account_auth_info,                      # new auth info
+                                        service_principal_auth_info_secret,
+                                        no_wait,
+                                        enable_mi_for_db_linker=enable_mi_for_db_linker)
+
+
+def local_connection_create_func(cmd, client,  # pylint: disable=too-many-locals,too-many-statements
+                                 resource_group_name,
+                                 connection_name=None,
+                                 location=None,
+                                 client_type=None,
+                                 target_resource_group=None, target_id=None,
+                                 secret_auth_info=None, secret_auth_info_auto=None,
+                                 user_account_auth_info=None,                      # new auth info
+                                 service_principal_auth_info_secret=None,
+                                 no_wait=False,
+                                 # Resource.*Postgres, Resource.*Sql*
+                                 server=None, database=None,
+                                 vault=None,                                            # Resource.KeyVault
+                                 account=None,                                          # Resource.Storage*
+                                 key_space=None, graph=None, table=None,                # Resource.Cosmos*,
+                                 config_store=None,                                     # Resource.AppConfig
+                                 namespace=None,                                        # Resource.EventHub
+                                 webpubsub=None,                                        # Resource.WebPubSub
+                                 signalr=None,                                          # Resource.SignalR
+                                 enable_mi_for_db_linker=None):
 
     all_auth_info = []
     if secret_auth_info is not None:
@@ -446,9 +527,10 @@ def local_connection_create(cmd, client,  # pylint: disable=too-many-locals,too-
         client, cmd.cli_ctx, source_type, target_type)
 
     validate_service_state(parameters)
-    new_auth_info = enable_mi_for_db_linker(
-        cmd, None, target_id, auth_info, client_type, connection_name)
-    parameters['auth_info'] = new_auth_info or parameters['auth_info']
+    if enable_mi_for_db_linker:
+        new_auth_info = enable_mi_for_db_linker(
+            cmd, None, target_id, auth_info, client_type, connection_name)
+        parameters['auth_info'] = new_auth_info or parameters['auth_info']
     return auto_register(sdk_no_wait, no_wait,
                          client.begin_create_or_update,
                          subscription_id=get_subscription_id(cmd.cli_ctx),
