@@ -373,6 +373,31 @@ def firewall_rule_table_format(result):
     return _apply_format(result, _firewall_rule_table_format)
 
 
+###############################################
+#           sql server ipv6-firewall-rule     #
+###############################################
+
+
+def ipv6_firewall_rule_table_format(result):
+    '''
+    Formats a single or list of server ipv6 firewall rules as summary results for display with "-o table".
+    '''
+
+    def _ipv6_firewall_rule_table_format(result):
+        '''
+        Formats a server ipv6 firewall rule as summary results for display with "-o table".
+        '''
+        from collections import OrderedDict
+
+        return OrderedDict([
+            ('name', result['name']),
+            ('startIPv6Address', result['startIPv6Address']),
+            ('endIPv6Address', result['endIPv6Address'])
+        ])
+
+    return _apply_format(result, _ipv6_firewall_rule_table_format)
+
+
 ########################################################
 #            sql server outbound-firewall-rule         #
 ########################################################
