@@ -192,6 +192,10 @@ def get_sql_managed_databases_operations(cli_ctx, _):
     return get_sql_management_client(cli_ctx).managed_databases
 
 
+def get_sql_recoverable_managed_databases_operations(cli_ctx, _):
+    return get_sql_management_client(cli_ctx).recoverable_managed_databases
+
+
 def get_sql_managed_database_advanced_threat_protection_settings_operations(cli_ctx, _):
     return get_sql_management_client(cli_ctx).managed_database_advanced_threat_protection_settings
 
@@ -238,3 +242,7 @@ def get_sql_managed_database_restore_details_operations(cli_ctx, _):
 
 def get_sql_database_ledger_digest_uploads_operations(cli_ctx, _):
     return get_sql_management_client(cli_ctx).ledger_digest_uploads
+
+
+def get_sql_database_recoverable_databases_operations(cli_ctx, _):
+    return get_sql_management_client(cli_ctx).recoverable_databases
