@@ -119,11 +119,12 @@ def validate_subnet(cmd, namespace):
 
 def validate_backup_storage_redundancy(namespace):
     # Validate if entered backup storage redundancy value is within allowed values
-    if (not namespace.storage_account_type or
-            (namespace.storage_account_type and namespace.storage_account_type in ['LRS', 'ZRS', 'GRS'])):
+    if (not namespace.requested_backup_storage_redundancy or
+            (namespace.requested_backup_storage_redundancy and
+             namespace.requested_backup_storage_redundancy in ['Local', 'Zone', 'Geo', 'GeoZone'])):
         pass
     else:
-        raise CLIError('incorrect usage: --backup-storage-redundancy must be either Local, Zone or Geo')
+        raise CLIError('incorrect usage: --backup-storage-redundancy must be either Local, Zone, Geo or GeoZone')
 
 
 ###############################################
@@ -137,12 +138,3 @@ def validate_managed_instance_storage_size(namespace):
         pass
     else:
         raise CLIError('incorrect usage: --storage must be specified in increments of 32 GB')
-
-
-def validate_managed_instance_backup_storage_redundancy(namespace):
-    # Validate if entered backup storage redundancy value is within allowed values
-    if (not namespace.storage_account_type or
-            (namespace.storage_account_type and namespace.storage_account_type in ['LRS', 'ZRS', 'GRS'])):
-        pass
-    else:
-        raise CLIError('incorrect usage: --backup-storage-redundancy must be either Local, Zone or Geo')
