@@ -18,7 +18,9 @@ from azure.mgmt.sqlvirtualmachine.models import (
     SqlVmGroupImageSku,
     SqlImageSku,
     SqlManagementMode,
-    AssessmentDayOfWeek
+    AssessmentDayOfWeek,
+    LeastPrivilegeMode,
+    ClusterSubnetType
 )
 
 from azure.cli.core.commands.parameters import (
@@ -37,7 +39,8 @@ from ._validators import (
     validate_sqlmanagement,
     validate_expand,
     validate_assessment,
-    validate_assessment_start_time_local
+    validate_assessment_start_time_local,
+    validate_least_privilege_mode
 )
 
 
@@ -94,6 +97,9 @@ def load_arguments(self, _):
                    help='Optional path for fileshare witness.')
         c.argument('ou_path',
                    help='Organizational Unit path in which the nodes and cluster will be present. Example: OU=WSCluster,DC=testdomain,DC=com')
+        c.argument('cluster_subnet_type',
+                   help='Cluster subnet type.',
+                   arg_type=get_enum_type(ClusterSubnetType))
 
     ###############################################
     #    availability group listener params       #
@@ -171,6 +177,11 @@ def load_arguments(self, _):
                    options_list=['--sql-mgmt-type'],
                    validator=validate_sqlmanagement,
                    arg_type=get_enum_type(SqlManagementMode))
+        c.argument('least_privilege_mode',
+                   help='SQL IaaS Agent Least Privilege Mode. Updates from sysadmin to specific permissions used per feature.',
+                   options_list=['--least-privilege-mode'],
+                   validator=validate_least_privilege_mode,
+                   arg_type=get_enum_type(LeastPrivilegeMode))
 
     with self.argument_context('sql vm', arg_group='SQL Server License') as c:
         c.argument('sql_server_license_type',
@@ -207,7 +218,8 @@ def load_arguments(self, _):
                    arg_type=get_enum_type(['Full']))
         c.argument('prompt',
                    options_list=['--yes', '-y'],
-                   help="Do not prompt for confirmation. Requires --sql-mgmt-type.")
+                   help="Do not prompt for confirmation. Requires --sql-mgmt-type.",
+                   deprecate_info=c.deprecate())
 
     with self.argument_context('sql vm add-to-group', arg_group='WSFC Domain Credentials') as c:
         c.argument('cluster_bootstrap_account_password',
