@@ -21,6 +21,7 @@ from azure.cli.testsdk import (
 from azure.cli.testsdk.preparers import (
     AbstractPreparer,
     SingleValueReplacer)
+from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 
 
 # Constants
@@ -29,7 +30,6 @@ sqlvm_domain_prefix = 'domainvm'
 sqlvm_group_prefix = 'sqlgroup'
 sqlvm_max_length = 15
 
-
 class SqlVirtualMachinePreparer(AbstractPreparer, SingleValueReplacer):
     def __init__(self, name_prefix=sqlvm_name_prefix, location='westus',
                  vm_user='admin123', vm_password='SecretPassword123', parameter_name='sqlvm',
@@ -44,7 +44,7 @@ class SqlVirtualMachinePreparer(AbstractPreparer, SingleValueReplacer):
 
     def create_resource(self, name, **kwargs):
         group = self._get_resource_group(**kwargs)
-        template = ('az vm create -l {} -g {} -n {} --admin-username {} --admin-password {} --image MicrosoftSQLServer:SQL2017-WS2016:Enterprise:latest'
+        template = ('az vm create -l {} -g {} -n {} --admin-username {} --admin-password {} --image microsoftsqlserver:sql2019-ws2022:enterprise:latest'
                     ' --size Standard_DS2_v2 --nsg-rule NONE')
         execute(DummyCli(), template.format(self.location, group, name, self.vm_user, self.vm_password))
         return {self.parameter_name: name}
@@ -63,7 +63,6 @@ class SqlVirtualMachinePreparer(AbstractPreparer, SingleValueReplacer):
             raise CliTestError(template.format(ResourceGroupPreparer.__name__,
                                                self.resource_group_parameter_name))
 
-
 class DomainPreparer(AbstractPreparer, SingleValueReplacer):
     def __init__(self, name_prefix=sqlvm_domain_prefix, location='westus',
                  vm_user='admin123', vm_password='SecretPassword123', parameter_name='domainvm',
@@ -110,6 +109,7 @@ class DomainPreparer(AbstractPreparer, SingleValueReplacer):
 
 
 class SqlVmScenarioTest(ScenarioTest):
+    @AllowLargeResponse()
     @ResourceGroupPreparer()
     @SqlVirtualMachinePreparer()
     @LogAnalyticsWorkspacePreparer(location="westus")
@@ -173,10 +173,12 @@ class SqlVmScenarioTest(ScenarioTest):
                      JMESPathCheck('provisioningState', "Succeeded")
                  ])
 
+
+    @AllowLargeResponse()
     @ResourceGroupPreparer()
     @SqlVirtualMachinePreparer()
     @StorageAccountPreparer()
-    def test_sqlvm_mgmt(self, resource_group, resource_group_location, sqlvm, storage_account):
+    def test_sqlvm_mgmt(self, resource_group, sqlvm, storage_account):
 
         loc = 'westus'
         self.cmd('storage account update -n {} -g {} --set kind=StorageV2'.format(storage_account, resource_group))
@@ -192,6 +194,11 @@ class SqlVmScenarioTest(ScenarioTest):
             self.cmd('sql vm create -n {} -g {} -l {} --license-type {} --sql-mgmt-type {}'
                      .format(sqlvm, resource_group, loc, 'PAYG', 'NoAgent'))
 
+        # Assert customer cannot create a SQL vm with least privilege and LightWeight mode
+        with self.assertRaisesRegex(RequiredArgumentMissingError, "usage error: --least-privilege-mode Enabled --sql-mgmt-type Full"):
+            self.cmd('sql vm create -n {} -g {} -l {} --license-type {} --least-privilege-mode {}'
+                     .format(sqlvm, resource_group, loc, 'PAYG', 'Enabled'))
+
         # test create sqlvm with minimal required parameters
         sqlvm_1 = self.cmd('sql vm create -n {} -g {} -l {} --license-type {}'
                            .format(sqlvm, resource_group, loc, 'PAYG'),
@@ -224,7 +231,7 @@ class SqlVmScenarioTest(ScenarioTest):
                  ])
 
         # test update sqlvm with management mode to make sure it updates to full.
-        self.cmd('sql vm update -n {} -g {} --sql-mgmt-type {} --yes'
+        self.cmd('sql vm update -n {} -g {} --sql-mgmt-type {}'
                  .format(sqlvm, resource_group, 'Full'),
                  checks=[
                      JMESPathCheck('name', sqlvm),
@@ -232,6 +239,24 @@ class SqlVmScenarioTest(ScenarioTest):
                      JMESPathCheck('sqlManagement', 'Full')
                  ]).get_output_in_json()
 
+        # test least privilege mode - Note LPM won't change result
+        self.cmd('sql vm update -n {} -g {} --sql-mgmt-type {} --least-privilege-mode {}'
+                 .format(sqlvm, resource_group, 'Full', 'Enabled'),
+                 checks=[
+                     JMESPathCheck('name', sqlvm),
+                     JMESPathCheck('location', loc),
+                     JMESPathCheck('sqlManagement', 'Full')
+                 ]).get_output_in_json()
+
+        # test show of vm after enabling Least privilege mode
+        self.cmd('sql vm show -n {} -g {}'
+                 .format(sqlvm, resource_group),
+                 checks=[
+                     JMESPathCheck('name', sqlvm),
+                     JMESPathCheck('sqlManagement', 'Full'),
+                     JMESPathCheck('leastPrivilegeMode', "Enabled")
+                 ])
+
         # test expand parameter: * - all settings exist
         expand_all = self.cmd('sql vm show -n {} -g {} --expand {}'
                               .format(sqlvm, resource_group, '*')
@@ -332,6 +357,8 @@ class SqlVmScenarioTest(ScenarioTest):
         # test list sql vm should be empty
         self.cmd('sql vm list -g {}'.format(resource_group), checks=[NoneCheck()])
 
+
+    @AllowLargeResponse()
     @ResourceGroupPreparer(name_prefix='sqlvm_cli_test_create')
     @SqlVirtualMachinePreparer(parameter_name='sqlvm1')
     @SqlVirtualMachinePreparer(parameter_name='sqlvm2')
@@ -349,14 +376,15 @@ class SqlVmScenarioTest(ScenarioTest):
                      JMESPathCheck('sqlServerLicenseType', 'PAYG')
                  ])
 
-        # test create sqlvm2 with AHUB changes inmediately
-        self.cmd('sql vm create -n {} -g {} -l {} --license-type {}'
-                 .format(sqlvm2, resource_group, resource_group_location, 'AHUB'),
+        # test create sqlvm2 with AHUB changes inmediately and least privilege mode
+        self.cmd('sql vm create -n {} -g {} -l {} --license-type {} --least-privilege-mode {} --sql-mgmt-type {}'
+                 .format(sqlvm2, resource_group, resource_group_location, 'AHUB', 'Enabled', 'Full'),
                  checks=[
                      JMESPathCheck('name', sqlvm2),
                      JMESPathCheck('location', resource_group_location),
                      JMESPathCheck('provisioningState', "Succeeded"),
-                     JMESPathCheck('sqlServerLicenseType', 'AHUB')
+                     JMESPathCheck('sqlServerLicenseType', 'AHUB'),
+                     JMESPathCheck('leastPrivilegeMode', 'Enabled'),
                  ])
 
         # test create sqlvm with sql connectivity settings
@@ -428,6 +456,8 @@ class SqlVmScenarioTest(ScenarioTest):
                      JMESPathCheck('sqlManagement', 'Full')
                  ])
 
+
+    @AllowLargeResponse()
     @ResourceGroupPreparer(name_prefix='sqlvm_cli_test_license')
     @SqlVirtualMachinePreparer(parameter_name='sqlvm1')
     def test_sqlvm_update_license_and_sku(self, resource_group, resource_group_location, sqlvm1):
@@ -526,6 +556,7 @@ class SqlVmGroupScenarioTest(ScenarioTest):
     def test_sqlvm_group_mgmt(self, resource_group, resource_group_location, storage_account1, storage_account2):
 
         name = 'sqlvmgroup'
+        name_two = 'sqlvmgrouptwo'
         image_offer = 'SQL2017-WS2016'
         image_sku = 'Enterprise'
         domain = 'domain.com'
@@ -554,8 +585,18 @@ class SqlVmGroupScenarioTest(ScenarioTest):
                                   JMESPathCheck('provisioningState', "Succeeded")
                               ]).get_output_in_json()
 
+        # create sql vm group with multi subnet
+        sqlvmgrouptwo = self.cmd('sql vm group create -n {} -g {} -l {} -i {} -s {} -f {} -p {} -k {} -e {} -u {} --cluster-subnet-type MultiSubnet'
+                              .format(name_two, resource_group, resource_group_location, image_offer, image_sku,
+                                      domain, operator_acc, key_1[0]['value'], sql_service_acc, sa_1['primaryEndpoints']['blob']),
+                              checks=[
+                                  JMESPathCheck('name', name_two),
+                                  JMESPathCheck('location', resource_group_location),
+                                  JMESPathCheck('provisioningState', "Succeeded")
+                              ]).get_output_in_json()
+
         # test list sqlvm should be 1
-        self.cmd('sql vm group list -g {}'.format(resource_group), checks=[JMESPathCheck('length(@)', 1)])
+        self.cmd('sql vm group list -g {}'.format(resource_group), checks=[JMESPathCheck('length(@)', 2)])
 
         # test show of the group
         self.cmd('sql vm group show -n {} -g {}'
@@ -596,19 +637,25 @@ class SqlVmGroupScenarioTest(ScenarioTest):
                      JMESPathCheck('wsfcDomainProfile.clusterOperatorAccount', 'my' + operator_acc)
                  ])
 
-        # test delete vm
+        # test delete group
         self.cmd('sql vm group delete -n {} -g {} --yes'
                  .format(name, resource_group),
                  checks=NoneCheck())
 
+        # test delete group
+        self.cmd('sql vm group delete -n {} -g {} --yes'
+                 .format(name_two, resource_group),
+                 checks=NoneCheck())
+
         # test list sql vm should be empty
         self.cmd('sql vm group list -g {}'.format(resource_group), checks=[NoneCheck()])
 
 
 class SqlVmAndGroupScenarioTest(ScenarioTest):
     """
-    This is a very lengthy test, it may take more than 45 minutes to run.
+    This is a very lengthy test, it may take more than 45 minutes to run. For now this test is failing, leaving it commented to prevent failures
     """
+    @AllowLargeResponse()
     @ResourceGroupPreparer()
     @DomainPreparer()
     @SqlVirtualMachinePreparer(parameter_name='sqlvm1')
@@ -639,7 +686,7 @@ class SqlVmAndGroupScenarioTest(ScenarioTest):
                        .format(storage_account, resource_group)).get_output_in_json()
 
         sqlvmgroup = self.cmd('sql vm group create -n {} -g {} -l {} -i {} -s {} -f {} -p {} -k {} -e {} -u {} --bootstrap-acc {}'
-                              .format('cligroup', resource_group, resource_group_location, 'SQL2017-WS2016', 'Enterprise',
+                              .format('cligroup', resource_group, resource_group_location, 'sql2019-ws2022', 'enterprise',
                                       'domain.com', 'admin123', key[0]['value'], 'admin123', sa['primaryEndpoints']['blob'], 'admin123')).get_output_in_json()
 
         # test create sqlvm1
