@@ -8,16 +8,14 @@ import re
 import unittest
 from datetime import datetime, timedelta
 from azure.cli.testsdk import (ScenarioTest, ResourceGroupPreparer, StorageAccountPreparer,
-                               JMESPathCheck, JMESPathCheckExists, NoneCheck, api_version_constraint)
+                               JMESPathCheck, NoneCheck, api_version_constraint)
 from knack.util import CLIError
 from azure.cli.core.profiles import ResourceType
 
 from azure.cli.command_modules.storage._client_factory import MISSING_CREDENTIALS_ERROR_MESSAGE
 from ..storage_test_util import StorageScenarioMixin
-from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 
 
-@api_version_constraint(ResourceType.MGMT_STORAGE, min_api='2016-12-01')
 class StorageBlobUploadTests(StorageScenarioMixin, ScenarioTest):
     @ResourceGroupPreparer()
     @StorageAccountPreparer(parameter_name='source_account')
@@ -47,14 +45,12 @@ class StorageBlobUploadTests(StorageScenarioMixin, ScenarioTest):
     @ResourceGroupPreparer()
     @StorageAccountPreparer()
     def test_storage_blob_upload_small_file(self, resource_group, storage_account):
-        for blob_type in ['block', 'page']:
-            self.verify_blob_upload_and_download(resource_group, storage_account, 1, blob_type, 0)
+        self.verify_blob_upload_and_download(resource_group, storage_account, 1, 'block', 0)
 
     @ResourceGroupPreparer()
     @StorageAccountPreparer()
     def test_storage_blob_upload_midsize_file(self, resource_group, storage_account):
-        for blob_type in ['block', 'page']:
-            self.verify_blob_upload_and_download(resource_group, storage_account, 4096, 'block', 0)
+        self.verify_blob_upload_and_download(resource_group, storage_account, 4096, 'block', 0)
 
     def verify_blob_upload_and_download(self, group, account, file_size_kb, blob_type,
                                         block_count=0, skip_download=False):
@@ -74,13 +70,8 @@ class StorageBlobUploadTests(StorageScenarioMixin, ScenarioTest):
             .assert_with_checks(JMESPathCheck('exists', True))
         self.storage_cmd('storage blob list -c {} -otable --num-results 1', account_info, container)
 
-        show_result = self.storage_cmd('storage blob show -n {} -c {}', account_info, blob_name,
-                                       container).get_output_in_json()
-        self.assertEqual(show_result.get('name'), blob_name)
-        if blob_type == 'page':
-            self.assertEqual(type(show_result.get('properties').get('pageRanges')), list)
-        else:
-            self.assertEqual(show_result.get('properties').get('pageRanges'), None)
+        self.storage_cmd('storage blob show -n {} -c {}', account_info, blob_name, container) \
+            .assert_with_checks(JMESPathCheck('name', blob_name))
 
         expiry = (datetime.utcnow() + timedelta(hours=1)).strftime('%Y-%m-%dT%H:%MZ')
         sas = self.storage_cmd('storage blob generate-sas -n {} -c {} --expiry {} --permissions '
@@ -96,13 +87,6 @@ class StorageBlobUploadTests(StorageScenarioMixin, ScenarioTest):
             [JMESPathCheck('properties.contentSettings.contentType', 'application/test-content'),
              JMESPathCheck('properties.contentLength', file_size_kb * 1024)])
 
-        # check that blob properties can be set back to null
-        self.storage_cmd('storage blob update -n {} -c {} --content-type ""',
-                         account_info, blob_name, container)
-
-        self.storage_cmd('storage blob show -n {} -c {}', account_info, blob_name, container) \
-            .assert_with_checks(JMESPathCheck('properties.contentSettings.contentType', None))
-
         self.storage_cmd('storage blob service-properties show', account_info) \
             .assert_with_checks(JMESPathCheck('hourMetrics.enabled', True))
 
@@ -348,22 +332,6 @@ class StorageBlobUploadTests(StorageScenarioMixin, ScenarioTest):
             self.storage_cmd('storage blob upload -c {} -f "{}" -n {} --type append --if-none-match *', account_info,
                              container, local_file, blob_name)
 
-    @AllowLargeResponse()
-    @ResourceGroupPreparer()
-    @StorageAccountPreparer()
-    @api_version_constraint(resource_type=ResourceType.DATA_STORAGE, max_api='2018-11-09')
-    def test_storage_blob_suppress_400(self, resource_group, storage_account):
-        # test for azure.cli.command_modules.storage.StorageCommandGroup.get_handler_suppress_some_400
-        # test 404
-        with self.assertRaises(SystemExit) as ex:
-            self.cmd('storage blob show --account-name {} -c foo -n bar.txt --auth-mode key'.format(storage_account))
-        self.assertEqual(ex.exception.code, 3)
-
-        # test 403
-        from azure.common import AzureException
-        with self.assertRaisesRegex(AzureException, "Authentication failure"):
-            self.cmd('storage blob show --account-name {} --account-key="YQ==" -c foo -n bar.txt '.format(storage_account))
-
 
 if __name__ == '__main__':
     unittest.main()
