@@ -169,15 +169,18 @@ class StorageBlobCopyTests(StorageScenarioMixin, LiveScenarioTest):
     @ResourceGroupPreparer()
     @StorageAccountPreparer(parameter_name='account1', kind='StorageV2')
     @StorageAccountPreparer(parameter_name='account2', kind='StorageV2')
-    def test_storage_blob_copy_destination_blob_type(self, resource_group, account1, account2):
+    @StorageAccountPreparer(parameter_name='accountpremium', sku='Premium_LRS', kind='StorageV2')
+    def test_storage_blob_copy_destination_blob_type(self, resource_group, account1, account2, accountpremium):
         source_file = self.create_temp_file(16, full_random=True)
         account1_info = self.get_account_info(resource_group, account1)
         account2_info = self.get_account_info(resource_group, account2)
+        accountpremium_info = self.get_account_info(resource_group, accountpremium)
 
         # Prepare
         source_container = self.create_container(account1_info)
         target_container = self.create_container(account1_info)
         target_container_different_account = self.create_container(account2_info)
+        target_container_premium =  self.create_container(accountpremium_info)
 
         self.storage_cmd('storage blob upload -c {} -f "{}" -n srcBlockBlob', account1_info,
                          source_container, source_file)
@@ -223,6 +226,40 @@ class StorageBlobCopyTests(StorageScenarioMixin, LiveScenarioTest):
                                                   dst_type if (dst_type != '' and dst_type != 'Detect')
                                                   else src_type)])
 
+        # tier
+        # specify dst-blob-type BlockBlob
+        tiers = ['Cool', 'Hot', 'Archive']
+        for tier in tiers:
+            self.storage_cmd('storage blob copy start --destination-blob dsttier{} --destination-container {} '
+                             '--source-account-name {} --source-container {} --source-blob srcBlockBlob '
+                             '--destination-blob-type BlockBlob --tier {}',
+                             account1_info, tier, target_container, account1, source_container, tier)
+            self.storage_cmd('storage blob show -c {} -n {}', account1_info, target_container, 'dsttier'+tier). \
+                assert_with_checks([JMESPathCheck('properties.blobTier', tier)])
+
+        # does not specify dst-blob-type BlockBlob
+        for tier in tiers:
+            self.storage_cmd('storage blob copy start --destination-blob dsttier2{} --destination-container {} '
+                             '--source-account-name {} --source-container {} --source-blob srcBlockBlob '
+                             '--tier {}',
+                             account1_info, tier, target_container, account1, source_container, tier)
+            self.storage_cmd('storage blob show -c {} -n {}', account1_info, target_container, 'dsttier2'+tier). \
+                assert_with_checks([JMESPathCheck('properties.blobTier', tier)])
+
+        self.storage_cmd('storage blob copy start --destination-blob dstpremium --destination-container {} '
+                         '--source-account-name {} --source-container {} --source-blob srcBlockBlob '
+                         '--destination-blob-type PageBlob',
+                         accountpremium_info, target_container_premium, account1, source_container)
+
+        # does not specify dst-blob-type PageBlob Premium
+        tiers = ['P10', 'P20', 'P30', 'P40', 'P50', 'P60', 'P4', 'P6']
+        for tier in tiers:
+            self.storage_cmd('storage blob copy start --destination-blob dstpremiumtier{} --destination-container {} '
+                             '--source-account-name {} --source-container {} --source-blob dstpremium --tier {}',
+                             accountpremium_info, tier, target_container_premium, accountpremium, target_container_premium, tier)
+            self.storage_cmd('storage blob show -c {} -n {}', accountpremium_info, target_container_premium,
+                             'dstpremiumtier'+tier).assert_with_checks([JMESPathCheck('properties.blobTier', tier)])
+
         # different account
         src_type = 'BlockBlob'
         src_blob_name = 'srcBlockBlob'
@@ -267,6 +304,36 @@ class StorageBlobCopyTests(StorageScenarioMixin, LiveScenarioTest):
                                                   dst_type if (dst_type != '' and dst_type != 'Detect')
                                                   else src_type)])
 
+        # tier
+        # specify dst-blob-type BlockBlob
+        tiers = ['Cool', 'Hot', 'Archive']
+        for tier in tiers:
+            self.storage_cmd('storage blob copy start --destination-blob dsttier3{} --destination-container {} '
+                             '--source-account-name {} --source-container {} --source-blob srcBlockBlob '
+                             '--destination-blob-type BlockBlob --tier {}',
+                             account2_info, tier, target_container_different_account, account1, source_container, tier)
+            self.storage_cmd('storage blob show -c {} -n {}', account2_info, target_container_different_account, 'dsttier3'+tier). \
+                assert_with_checks([JMESPathCheck('properties.blobTier', tier)])
+
+        # does not specify dst-blob-type BlockBlob
+        for tier in tiers:
+            self.storage_cmd('storage blob copy start --destination-blob dsttier4{} --destination-container {} '
+                             '--source-account-name {} --source-container {} --source-blob srcBlockBlob '
+                             '--tier {}',
+                             account2_info, tier, target_container_different_account, account1, source_container, tier)
+            self.storage_cmd('storage blob show -c {} -n {}', account2_info, target_container_different_account, 'dsttier4'+tier). \
+                assert_with_checks([JMESPathCheck('properties.blobTier', tier)])
+
+        # does not specify dst-blob-type PageBlob Premium
+        tiers = ['P10', 'P20', 'P30', 'P40', 'P50', 'P60', 'P4', 'P6']
+        for tier in tiers:
+            self.storage_cmd('storage blob copy start --destination-blob dstpremiumtier2{} --destination-container {} '
+                             '--source-account-name {} --source-container {} --source-blob dstPageBlob --tier {}',
+                             accountpremium_info, tier, target_container_premium, account1,
+                             target_container, tier)
+            self.storage_cmd('storage blob show -c {} -n {}', accountpremium_info, target_container_premium,
+                             'dstpremiumtier' + tier).assert_with_checks([JMESPathCheck('properties.blobTier', tier)])
+
 
     @ResourceGroupPreparer()
     @StorageAccountPreparer(parameter_name='account1', kind='StorageV2', hns=True)
