@@ -22,6 +22,12 @@ class StorageImmutabilityPolicy(ScenarioTest):
                 JMESPathCheck('immutabilityPeriodSinceCreationInDays', 1),
                 JMESPathCheck('allowProtectedAppendWrites', True)
         ])
+        # test without specifying rg
+        self.cmd('az storage container immutability-policy create --account-name {} -c {} --period 1 -w'.format(
+            storage_account, container_name), checks=[
+            JMESPathCheck('immutabilityPeriodSinceCreationInDays', 1),
+            JMESPathCheck('allowProtectedAppendWrites', True)
+        ])
 
         policy_etag = self.cmd('az storage container immutability-policy show --account-name {} -c {} -g {}'.format(
             storage_account, container_name, resource_group), checks=[
