@@ -49,13 +49,13 @@ class StorageTableScenarioTests(StorageScenarioMixin, ScenarioTest):
     def verify_entity_operations(self, account_info, table_name):
         self.storage_cmd(
             'storage entity insert -t {} -e rowkey=001 partitionkey=001 name=test value=something '
-            'binaryProperty=AAECAwQF binaryProperty@odata.type=Edm.Binary',
+            'sizeInBytes=86222504922 sizeInBytes@odata.type=Edm.Int64',
             account_info, table_name)
         self.storage_cmd('storage entity show -t {} --row-key 001 --partition-key 001',
                          account_info, table_name) \
             .assert_with_checks(JMESPathCheck('name', 'test'),
                                 JMESPathCheck('value', 'something'),
-                                JMESPathCheck('binaryProperty', 'AAECAwQF'))
+                                JMESPathCheck('sizeInBytes.value', '86222504922'))
         self.storage_cmd(
             'storage entity show -t {} --row-key 001 --partition-key 001 --select name',
             account_info, table_name).assert_with_checks(JMESPathCheck('name', 'test'),
@@ -67,21 +67,20 @@ class StorageTableScenarioTests(StorageScenarioMixin, ScenarioTest):
                          account_info, table_name) \
             .assert_with_checks(JMESPathCheck('name', 'test'),
                                 JMESPathCheck('value', 'newval'),
-                                JMESPathCheck('binaryProperty', 'AAECAwQF'))
+                                JMESPathCheck('sizeInBytes.value', '86222504922'))
 
         self.storage_cmd('storage entity replace -t {} -e rowkey=001 partitionkey=001 cat=hat',
                          account_info, table_name)
         self.storage_cmd('storage entity show -t {} --row-key 001 --partition-key 001',
                          account_info, table_name) \
             .assert_with_checks(JMESPathCheck('cat', 'hat'), JMESPathCheck('name', None),
-                                JMESPathCheck('value', None), JMESPathCheck('binaryProperty', None))
+                                JMESPathCheck('value', None), JMESPathCheck('sizeInBytes', None))
 
         self.storage_cmd('storage entity delete -t {} --row-key 001 --partition-key 001',
                          account_info, table_name)
         self.storage_cmd_negative('storage entity show -t {} --row-key 001 --partition-key 001',
                                   account_info, table_name)
-        self.storage_cmd('storage entity insert -t {} -e rowkey=001 partitionkey=001 name=test value=something '
-                         'binaryProperty=AAECAwQF binaryProperty@odata.type=Edm.Binary',
+        self.storage_cmd('storage entity insert -t {} -e rowkey=001 partitionkey=001 name=test value=something',
                          account_info, table_name)
         self.storage_cmd('storage entity insert -t {} -e rowkey=002 partitionkey=002 name=test2 value=something2',
                          account_info, table_name)
