@@ -3,7 +3,7 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from azure.cli.command_modules.vm._client_factory import (cf_vm, cf_avail_set, cf_ni,
+from azure.cli.command_modules.vm._client_factory import (cf_vm, cf_avail_set,
                                                           cf_vm_ext, cf_vm_ext_image,
                                                           cf_vm_image, cf_vm_image_term, cf_usage,
                                                           cf_vmss, cf_vmss_vm,
@@ -155,11 +155,6 @@ def load_command_table(self, _):
         operation_group='virtual_machine_scale_sets'
     )
 
-    network_nic_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#NetworkInterfacesOperations.{}',
-        client_factory=cf_ni
-    )
-
     compute_galleries_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.compute.operations#GalleriesOperations.{}',
         client_factory=cf_galleries,
@@ -303,6 +298,11 @@ def load_command_table(self, _):
         g.custom_command('show-runs', 'show_build_output')
         g.command('cancel', 'begin_cancel')
 
+    with self.command_group('image builder identity', image_builder_image_templates_sdk, custom_command_type=image_builder_custom) as g:
+        g.custom_command('assign', 'assign_template_identity', supports_local_cache=True)
+        g.custom_command('remove', 'remove_template_identity', supports_local_cache=True, confirmation=True)
+        g.custom_show_command('show', 'show_template_identity', supports_local_cache=True)
+
     with self.command_group('image builder customizer', image_builder_image_templates_sdk, custom_command_type=image_builder_custom) as g:
         g.custom_command('add', 'add_template_customizer', supports_local_cache=True, validator=process_img_tmpl_customizer_add_namespace)
         g.custom_command('remove', 'remove_template_customizer', supports_local_cache=True)
@@ -466,12 +466,9 @@ def load_command_table(self, _):
 
     with self.command_group('vm host group', compute_dedicated_host_groups_sdk, client_factory=cf_dedicated_host_groups,
                             min_api='2019-03-01') as g:
-        g.show_command('show', 'get')
         g.custom_command('get-instance-view', 'get_dedicated_host_group_instance_view', min_api='2020-06-01')
         g.custom_command('create', 'create_dedicated_host_group')
-        g.custom_command('list', 'list_dedicated_host_groups')
         g.generic_update_command('update')
-        g.command('delete', 'delete', confirmation=True)
 
     with self.command_group('vmss', compute_vmss_sdk, operation_group='virtual_machine_scale_sets') as g:
         g.custom_command('identity assign', 'assign_vmss_identity', validator=process_assign_identity_namespace)
@@ -526,11 +523,6 @@ def load_command_table(self, _):
     with self.command_group('vmss extension image', compute_vm_extension_image_sdk) as g:
         g.custom_command('list', 'list_vm_extension_images')
 
-    with self.command_group('vmss nic', network_nic_sdk) as g:
-        g.command('list', 'list_virtual_machine_scale_set_network_interfaces')
-        g.command('list-vm-nics', 'list_virtual_machine_scale_set_vm_network_interfaces')
-        g.show_command('show', 'get_virtual_machine_scale_set_network_interface')
-
     with self.command_group('vmss run-command', compute_vmss_run_sdk, client_factory=cf_vmss_run_commands, min_api='2018-04-01') as g:
         g.custom_command('invoke', 'vmss_run_command_invoke')
         g.custom_command('list', 'vmss_run_command_list')
@@ -627,11 +619,8 @@ def load_command_table(self, _):
         g.command('show-shared', 'get')
 
     with self.command_group('sig gallery-application', compute_gallery_application_sdk, client_factory=cf_gallery_application, min_api='2021-07-01', operation_group='gallery_applications') as g:
-        g.command('list', 'list_by_gallery')
-        g.show_command('show', 'get')
         g.custom_command('create', 'gallery_application_create', supports_no_wait=True)
         g.custom_command('update', 'gallery_application_update', supports_no_wait=True)
-        g.command('delete', 'begin_delete', supports_no_wait=True, confirmation=True)
         g.wait_command('wait')
 
     with self.command_group('sig gallery-application version', compute_gallery_application_version_sdk, client_factory=cf_gallery_application_version, min_api='2021-07-01', operation_group='gallery_application_versions') as g:
