@@ -15,13 +15,15 @@ from azure.cli.command_modules.vm._validators import (validate_ssh_key,
                                                       _validate_admin_username,
                                                       _validate_admin_password,
                                                       _parse_image_argument,
-                                                      process_disk_or_snapshot_create_namespace,
+                                                      process_disk_create_namespace,
+                                                      process_snapshot_create_namespace,
                                                       _validate_vmss_create_subnet,
                                                       _get_next_subnet_addr_suffix,
                                                       _validate_vm_vmss_msi,
                                                       _validate_vm_vmss_accelerated_networking)
-from azure.cli.command_modules.vm._vm_utils import normalize_disk_info, update_disk_sku_info
+from azure.cli.command_modules.vm._vm_utils import normalize_disk_info
 from azure.cli.core.mock import DummyCli
+from azure.mgmt.compute.models import CachingTypes
 from knack.util import CLIError
 
 
@@ -86,15 +88,24 @@ class TestActions(unittest.TestCase):
 
     def test_figure_out_storage_source(self):
         test_data = 'https://av123images.blob.core.windows.net/images/TDAZBET.vhd'
-        src_blob_uri, src_disk, src_snapshot, _ = _figure_out_storage_source(DummyCli(), 'tg1', test_data)
+        src_blob_uri, src_disk, src_snapshot, src_restore_point, _ = _figure_out_storage_source(DummyCli(), 'tg1', test_data)
         self.assertFalse(src_disk)
         self.assertFalse(src_snapshot)
+        self.assertFalse(src_restore_point)
         self.assertEqual(src_blob_uri, test_data)
 
         test_data = '/subscriptions/0b1f6471-1bf0-4dda-aec3-cb9272f09590/resourceGroups/JAVACSMRG6017/providers/Microsoft.Compute/disks/ex.vhd'
-        src_blob_uri, src_disk, src_snapshot, _ = _figure_out_storage_source(None, 'tg1', test_data)
+        src_blob_uri, src_disk, src_snapshot, src_restore_point, _ = _figure_out_storage_source(None, 'tg1', test_data)
         self.assertEqual(src_disk, test_data)
         self.assertFalse(src_snapshot)
+        self.assertFalse(src_restore_point)
+        self.assertFalse(src_blob_uri)
+
+        test_data = '/subscriptions/0b1f6471-1bf0-4dda-aec3-cb9272f09590/resourceGroups/qinkaiwu-test/providers/Microsoft.Compute/restorePointCollections/vm_rpc/restorePoints/vm_rp'
+        src_blob_uri, src_disk, src_snapshot, src_restore_point, _ = _figure_out_storage_source(None, 'tg1', test_data)
+        self.assertFalse(src_disk)
+        self.assertFalse(src_snapshot)
+        self.assertEqual(src_restore_point, test_data)
         self.assertFalse(src_blob_uri)
 
     def test_source_storage_account_err_case(self):
@@ -108,11 +119,13 @@ class TestActions(unittest.TestCase):
         # action (should throw)
         kwargs = {'namespace': np}
         with self.assertRaises(CLIError):
-            process_disk_or_snapshot_create_namespace(cmd, **kwargs)
+            process_disk_create_namespace(cmd, **kwargs)
+            process_snapshot_create_namespace(cmd, **kwargs)
 
         # with blob uri, should be fine
         np.source = 'https://s1.blob.core.windows.net/vhds/s1.vhd'
-        process_disk_or_snapshot_create_namespace(cmd, **kwargs)
+        process_disk_create_namespace(cmd, **kwargs)
+        process_snapshot_create_namespace(cmd, **kwargs)
 
     def test_validate_admin_username_linux(self):
         # pylint: disable=line-too-long
@@ -206,7 +219,7 @@ class TestActions(unittest.TestCase):
     @mock.patch('azure.cli.command_modules.vm._validators._compute_client_factory', autospec=True)
     @mock.patch('azure.cli.command_modules.vm._validators.logger.warning', autospec=True)
     def test_parse_staging_image_argument(self, logger_mock, client_factory_mock):
-        from msrestazure.azure_exceptions import CloudError
+        from azure.core.exceptions import ResourceNotFoundError
         compute_client = mock.MagicMock()
         resp = mock.MagicMock()
         cmd = mock.MagicMock()
@@ -214,7 +227,7 @@ class TestActions(unittest.TestCase):
         resp.status_code = 404
         resp.text = '{"Message": "Not Found"}'
 
-        compute_client.virtual_machine_images.get.side_effect = CloudError(resp, error='image not found')
+        compute_client.virtual_machine_images.get.side_effect = ResourceNotFoundError('image not found')
         client_factory_mock.return_value = compute_client
 
         np = mock.MagicMock()
@@ -362,13 +375,6 @@ class TestActions(unittest.TestCase):
         mock_resolve_role_id.assert_called_with(cmd.cli_ctx, 'reader', 'foo-scope')
 
     def test_normalize_disk_info(self):
-        from azure.cli.core.profiles._shared import AZURE_API_PROFILES, ResourceType
-        from importlib import import_module
-
-        api_version = AZURE_API_PROFILES['2019-03-01-hybrid'][ResourceType.MGMT_COMPUTE].default_api_version
-        api_version = "v" + api_version.replace("-", "_")
-        CachingTypes = import_module('azure.mgmt.compute.{}.models'.format(api_version)).CachingTypes
-
         cmd = mock.MagicMock()
         cmd.get_models.return_value = CachingTypes
 
@@ -403,16 +409,6 @@ class TestActions(unittest.TestCase):
             normalize_disk_info(data_disk_cachings=['0=None', '1=foo'])
         self.assertTrue("Data disk with lun of '0' doesn't exist" in str(err.exception))
 
-        # default to "None" across for Lv/Lv2 machines
-        r = normalize_disk_info(data_disk_sizes_gb=[1], size='standard_L8s')
-        self.assertEqual(r['os']['caching'], CachingTypes.none.value)
-        self.assertEqual(r[0].get('caching'), None)
-
-        # error on lv/lv2 machines with caching mode other than "None"
-        with self.assertRaises(CLIError) as err:
-            normalize_disk_info(data_disk_cachings=['ReadWrite'], data_disk_sizes_gb=[1, 2], size='standard_L16s_v2')
-        self.assertTrue('for Lv series of machines, "None" is the only supported caching mode' in str(err.exception))
-
     @mock.patch('azure.cli.command_modules.vm._validators._compute_client_factory', autospec=True)
     def test_validate_vm_vmss_accelerated_networking(self, client_factory_mock):
         client_mock, size_mock = mock.MagicMock(), mock.MagicMock()
@@ -483,44 +479,6 @@ class TestActions(unittest.TestCase):
         _validate_vm_vmss_accelerated_networking(mock.MagicMock(), np)
         self.assertIsNone(np.accelerated_networking)
 
-    def test_update_sku_from_dict(self):
-        sku_tests = {"test_empty": ([""], {}),
-                     "test_all": (["sku"], {"os": "sku", 1: "sku", 3: "sku"}),
-                     "test_os": (["os=sku"], {"os": "sku"}),
-                     "test_lun": (["1=sku"], {1: "sku"}),
-                     "test_os_lun": (["os=sku", "1=sku_1"], {"os": "sku", 1: "sku_1"}),
-                     "test_os_mult_lun": (["1=sku_1", "os=sku_os", "2=sku_2"],
-                                          {1: "sku_1", "os": "sku_os", 2: "sku_2"}),
-                     "test_double_equ": (["os==foo"], {"os": "=foo"}),
-                     "test_err_no_eq": (["os=sku_1", "foo"], None),
-                     "test_err_lone_eq": (["foo ="], None),
-                     "test_err_float": (["2.7=foo"], None),
-                     "test_err_bad_key": (["bad=foo"], None)}
-
-        for test_sku, expected in sku_tests.values():
-            if isinstance(expected, dict):
-                # build info dict from expected values.
-                info_dict = {lun: dict(managedDisk={'storageAccountType': None}) for lun in expected if lun != "os"}
-                if "os" in expected:
-                    info_dict["os"] = {}
-
-                update_disk_sku_info(info_dict, test_sku)
-                for lun in info_dict:
-                    if lun == "os":
-                        self.assertEqual(info_dict[lun]['storageAccountType'], expected[lun])
-                    else:
-                        self.assertEqual(info_dict[lun]['managedDisk']['storageAccountType'], expected[lun])
-            elif expected is None:
-                dummy_expected = ["os", 1, 2]
-                info_dict = {lun: dict(managedDisk={'storageAccountType': None}) for lun in dummy_expected if lun != "os"}
-                if "os" in dummy_expected:
-                    info_dict["os"] = {}
-
-                with self.assertRaises(CLIError):
-                    update_disk_sku_info(info_dict, dummy_expected)
-            else:
-                self.fail("Test Expected value should be a dict or None, instead it is {}.".format(expected))
-
 
 if __name__ == '__main__':
     unittest.main()
