@@ -16,7 +16,7 @@ from azure.cli.command_modules.vm.custom import (enable_boot_diagnostics, disabl
                                                  _get_extension_instance_name,
                                                  get_boot_log)
 from azure.cli.command_modules.vm.custom import \
-    (attach_unmanaged_data_disk, detach_data_disk, get_vmss_instance_view)
+    (attach_unmanaged_data_disk, detach_unmanaged_data_disk, get_vmss_instance_view)
 
 from azure.cli.core import AzCommandsLoader
 from azure.cli.core.commands import AzCliCommand
@@ -101,18 +101,6 @@ class TestVmCustom(unittest.TestCase):
         self.assertTrue(mock_vm_get_to_update.called)
         mock_vm_set.assert_called_once_with(cmd, vm_fake, mock.ANY)
 
-    # @mock.patch('azure.cli.command_modules.vm.custom.get_vm', autospec=True)
-    # @mock.patch('azure.cli.command_modules.vm.custom.set_vm', autospec=True)
-    # def test_enable_boot_diagnostics_skip_when_enabled_already(self, mock_vm_set, mock_vm_get):
-    #     vm_fake = mock.MagicMock()
-    #     cmd = _get_test_cmd()
-    #     mock_vm_get.return_value = vm_fake
-    #     vm_fake.diagnostics_profile.boot_diagnostics.enabled = True
-    #     vm_fake.diagnostics_profile.boot_diagnostics.storage_uri = 'https://storage_uri1'
-    #     enable_boot_diagnostics(cmd, 'g1', 'vm1', 'https://storage_uri1')
-    #     self.assertTrue(mock_vm_get.called)
-    #     self.assertFalse(mock_vm_set.called)
-
     @mock.patch('azure.cli.command_modules.vm.custom.get_vm_to_update', autospec=True)
     @mock.patch('azure.cli.command_modules.vm.custom.set_vm', autospec=True)
     def test_disable_boot_diagnostics_on_vm(self, mock_vm_set, mock_vm_get_to_update):
@@ -218,7 +206,7 @@ class TestVmCustom(unittest.TestCase):
         mock_vm_get_to_update.return_value = vm
 
         # execute
-        detach_data_disk(cmd, 'rg1', 'vm1', 'd1')
+        detach_unmanaged_data_disk(cmd, 'rg1', 'vm1', 'd1')
 
         # assert
         self.assertTrue(mock_vm_get_to_update.called)
