@@ -7,10 +7,7 @@
 
 import argparse
 import unittest
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+from unittest import mock
 
 from knack.util import CLIError
 
