@@ -17,7 +17,7 @@ except ImportError:
     logger.warn("Wheel is not available, disabling bdist_wheel hook")
     cmdclass = {}
 
-VERSION = "2.44.1"
+VERSION = "2.45.0"
 # If we have source, validate that our version numbers match
 # This should prevent uploading releases with mismatched versions.
 try:
@@ -73,7 +73,7 @@ DEPENDENCIES = [
     'azure-mgmt-botservice~=2.0.0b3',
     'azure-mgmt-cdn==12.0.0',
     'azure-mgmt-cognitiveservices~=13.3.0',
-    'azure-mgmt-compute~=29.0.0',
+    'azure-mgmt-compute~=29.1.0',
     'azure-mgmt-consumption~=2.0',
     'azure-mgmt-containerinstance~=9.1.0',
     'azure-mgmt-containerregistry==10.0.0',
@@ -108,10 +108,10 @@ DEPENDENCIES = [
     'azure-mgmt-network~=21.0.1',
     'azure-mgmt-policyinsights~=1.1.0b2',
     'azure-mgmt-privatedns~=1.0.0',
-    'azure-mgmt-rdbms~=10.2.0b5',
-    'azure-mgmt-recoveryservicesbackup~=5.1.0b1',
-    'azure-mgmt-recoveryservices~=2.1.0',
-    'azure-mgmt-redhatopenshift==1.1.0',
+    'azure-mgmt-rdbms~=10.2.0b6',
+    'azure-mgmt-recoveryservicesbackup~=5.1.0',
+    'azure-mgmt-recoveryservices~=2.2.0',
+    'azure-mgmt-redhatopenshift~=1.2.0',
     'azure-mgmt-redis~=14.1.0',
     'azure-mgmt-relay~=0.1.0',
     'azure-mgmt-resource==21.1.0b1',
@@ -123,7 +123,7 @@ DEPENDENCIES = [
     'azure-mgmt-servicefabric~=1.0.0',
     'azure-mgmt-signalr==1.1.0',
     'azure-mgmt-sqlvirtualmachine==1.0.0b4',
-    'azure-mgmt-sql==4.0.0b6',
+    'azure-mgmt-sql==4.0.0b7',
     'azure-mgmt-storage~=21.0.0',
     'azure-mgmt-synapse==2.1.0b5',
     'azure-mgmt-trafficmanager~=1.0.0',
